@@ -40,10 +40,13 @@
 #include <QToolBar>
 #include <QComboBox>
 #include <QMessageBox>
-#include <QtDBus/QDBusConnection>
 #include <QStatusBar>
 #include <QWhatsThis>
 
+#ifdef QT_DBUS_SUPPORT
+#include <QtDBus/QDBusConnection>
+#endif
+
 #include "partselection.h"
 #include "functionselection.h"
 #include "stackselection.h"
@@ -57,7 +60,7 @@
 
 QCGTopLevel::QCGTopLevel()
 {
-#ifndef QT_NO_DBUS
+#ifdef QT_DBUS_SUPPORT
     QDBusConnection con = QDBusConnection::sessionBus();
     con.registerObject("/QCachegrind", this,
 		       QDBusConnection::ExportScriptableSlots);
@@ -228,7 +231,6 @@ void QCGTopLevel::sidebarMenuAboutToShow()
 
 void QCGTopLevel::recentFilesMenuAboutToShow()
 {
-    QAction* action;
     QStringList recentFiles;
     QMenu *popup = _recentFilesMenuAction->menu();
 
@@ -244,7 +246,7 @@ void QCGTopLevel::recentFilesMenuAboutToShow()
     else {
 	foreach(const QString& file, recentFiles) {
 	    // paths shown to user should use OS-native separators
-	    action = popup->addAction(QDir::toNativeSeparators(file));
+	    popup->addAction(QDir::toNativeSeparators(file));
 	}
     }
 }
@@ -336,44 +338,10 @@ void QCGTopLevel::createActions()
     _addAction->setStatusTip(tr("Add profile data to current window"));
     connect(_addAction, SIGNAL(triggered(bool)), SLOT(addTrace()));
 
-    _reloadAction = new QAction(tr("&Reload", "Reload a document"), this);
-    _reloadAction->setStatusTip(tr("Reload profile data including new parts"));
-    connect(_reloadAction, SIGNAL(triggered(bool)), SLOT(reload()));
-
     _exportAction = new QAction(tr("Export Graph"), this);
     _exportAction->setStatusTip(tr("Generate GraphViz file 'callgraph.dot'"));
     connect(_exportAction, SIGNAL(triggered(bool)), SLOT(exportGraph()));
 
-    _dumpToggleAction = new QAction(tr("Callgrind Dump"), this);
-    _dumpToggleAction->setCheckable(true);
-    _dumpToggleAction->setStatusTip(
-	tr("Trigger Callgrind to dump profile data"));
-    hint = tr("<b>Force Dump</b>"
-              "<p>This forces a dump for a Callgrind profile run "
-              "in the current directory. This action is checked while "
-              "KCachegrind looks for the dump. If the dump is "
-              "finished, it automatically reloads the current trace. "
-              "If this is the one from the running Callgrind, the new "
-              "created trace part will be loaded, too.</p>"
-              "<p>Force dump creates a file 'callgrind.cmd', and "
-              "checks every second for its existence. A running "
-              "Callgrind will detect this file, dump a trace part, "
-              "and delete 'callgrind.cmd'. "
-              "The deletion is detected by KCachegrind, "
-              "and it does a Reload. If there is <em>no</em> Callgrind "
-              "running, press 'Force Dump' again to cancel the dump "
-              "request. This deletes 'callgrind.cmd' itself and "
-              "stops polling for a new dump.</p>"
-              "<p>Note: A Callgrind run <em>only</em> detects "
-              "existence of 'callgrind.cmd' when actively running "
-              "a few milliseconds, i.e. "
-              "<em>not</em> sleeping. Tip: For a profiled GUI program, "
-              "you can awake Callgrind e.g. by resizing a window "
-              "of the program.</p>");
-    _dumpToggleAction->setWhatsThis(hint);
-    connect(_dumpToggleAction, SIGNAL(triggered(bool)),
-	    this, SLOT(forceTrace()));
-
     _recentFilesMenuAction = new QAction(tr("Open &Recent"), this);
     _recentFilesMenuAction->setMenu(new QMenu(this));
     connect(_recentFilesMenuAction->menu(), SIGNAL(aboutToShow()),
@@ -575,9 +543,7 @@ void QCGTopLevel::createMenu()
     fileMenu->addAction(_recentFilesMenuAction);
     fileMenu->addAction(_addAction);
     fileMenu->addSeparator();
-    fileMenu->addAction(_reloadAction);
     fileMenu->addAction(_exportAction);
-    fileMenu->addAction(_dumpToggleAction);
     fileMenu->addSeparator();
     fileMenu->addAction(_exitAction);
 
@@ -792,7 +758,7 @@ void QCGTopLevel::loadTrace()
     file = QFileDialog::getOpenFileName(this,
 					tr("Open Callgrind Data"),
 					_lastFile,
-					tr("Callgrind Files (callgrind.*)"));
+					tr("Callgrind Files (callgrind.*);;All Files (*)"));
     loadTrace(file);
 }
 
@@ -839,7 +805,7 @@ void QCGTopLevel::addTrace()
     file = QFileDialog::getOpenFileName(this,
 					tr("Add Callgrind Data"),
 					_lastFile,
-					tr("Callgrind Files (callgrind.*)"));
+					tr("Callgrind Files (callgrind.*);;All Files (*)"));
     addTrace(file);
 }
 
@@ -882,20 +848,6 @@ void QCGTopLevel::loadTraceDelayed()
 }
 
 
-void QCGTopLevel::reload()
-{
-    QString trace;
-    if (!_data || _data->parts().count()==0)
-	trace = "."; // open first trace found in dir
-    else
-	trace = _data->traceName();
-
-    // this also keeps sure we have the same browsing position...
-    TraceData* d = new TraceData(this);
-    d->load(trace);
-    setData(d);
-}
-
 void QCGTopLevel::exportGraph()
 {
     if (!_data || !_function) return;
@@ -1105,7 +1057,7 @@ bool QCGTopLevel::setFunction(TraceFunction* f)
 
 #if TRACE_UPDATES
   qDebug("QCGTopLevel::setFunction(%s), lastSender %s",
-         f ? f->prettyName().ascii() : "0",
+         f ? f->prettyName().toAscii() : "0",
          _lastSender ? _lastSender->name() :"0" );
 #endif
 
@@ -1157,7 +1109,7 @@ void QCGTopLevel::setGroupDelayed(TraceCostItem* g)
 {
 #if TRACE_UPDATES
   qDebug("QCGTopLevel::setGroupDelayed(%s), sender %s",
-         g ? g->prettyName().ascii() : "0",
+         g ? g->prettyName().toAscii() : "0",
          _lastSender ? _lastSender->name() :"0" );
 #endif
 
@@ -1217,7 +1169,7 @@ void QCGTopLevel::setTraceItemDelayed(CostItem* i)
 
 #if TRACE_UPDATES
   qDebug("QCGTopLevel::setTraceItemDelayed(%s), sender %s",
-         i ? i->prettyName().ascii() : "0",
+         i ? i->prettyName().toAscii() : "0",
          _lastSender ? _lastSender->name() :"0" );
 #endif
 
@@ -1656,8 +1608,8 @@ void QCGTopLevel::updateLayoutActions()
 	_layoutRemove->setEnabled(_layoutCount>1);
 
     if (_statusbar)
-	_statusbar->message(tr("Layout Count: %1").arg(_layoutCount),
-			    1000);
+        _statusbar->showMessage(tr("Layout Count: %1").arg(_layoutCount),
+                                1000);
 }
 
 
@@ -1828,40 +1780,6 @@ void QCGTopLevel::partsUnhideAllSlot()
 #endif
 }
 
-void QCGTopLevel::forceTrace()
-{
-//  qDebug("forceTrace");
-
-  // Needs Callgrind now...
-  QFile cmd("callgrind.cmd");
-  if (!cmd.exists()) {
-    cmd.open(QIODevice::WriteOnly);
-    cmd.write("DUMP\n", 5);
-    cmd.close();
-  }
-  if (_dumpToggleAction->isChecked())
-    QTimer::singleShot( 1000, this, SLOT(forceTraceReload()) );
-  else {
-    // cancel request
-    cmd.remove();
-  }
-
-}
-
-void QCGTopLevel::forceTraceReload()
-{
-//  qDebug("forceTraceReload");
-
-  QFile cmd("callgrind.cmd");
-  if (cmd.exists()) {
-    if (_dumpToggleAction->isChecked())
-      QTimer::singleShot( 1000, this, SLOT(forceTraceReload()) );
-    return;
-  }
-  _dumpToggleAction->setChecked(false);
-  reload();
-}
-
 void QCGTopLevel::forwardAboutToShow()
 {
   QMenu *popup = _forwardAction->menu();
@@ -1888,11 +1806,9 @@ void QCGTopLevel::forwardAboutToShow()
     f = hi->function();
     if (!f) break;
 
-    QString name = f->prettyName();
-    if ((int)name.length()>GlobalConfig::maxSymbolLength())
-      name = name.left(GlobalConfig::maxSymbolLength()) + "...";
+    QString name = GlobalConfig::shortenSymbol(f->prettyName());
 
-    //qDebug("forward: Adding %s", name.ascii());
+    //qDebug("forward: Adding %s", name.toAscii());
     action = popup->addAction(name);
     action->setData(count);
 
@@ -1927,11 +1843,9 @@ void QCGTopLevel::backAboutToShow()
     f = hi->function();
     if (!f) break;
 
-    QString name = f->prettyName();
-    if ((int)name.length()>GlobalConfig::maxSymbolLength())
-      name = name.left(GlobalConfig::maxSymbolLength()) + "...";
+    QString name = GlobalConfig::shortenSymbol(f->prettyName());
 
-    //qDebug("back: Adding %s", name.ascii());
+    //qDebug("back: Adding %s", name.toAscii());
     action = popup->addAction(name);
     action->setData(count);
 
@@ -1962,9 +1876,7 @@ void QCGTopLevel::upAboutToShow()
 
   int count = 1;
   while (count<GlobalConfig::maxSymbolCount() && f) {
-    QString name = f->prettyName();
-    if ((int)name.length()>GlobalConfig::maxSymbolLength())
-      name = name.left(GlobalConfig::maxSymbolLength()) + "...";
+    QString name = GlobalConfig::shortenSymbol(f->prettyName());
 
     action = popup->addAction(name);
     action->setData(count);
@@ -2026,7 +1938,7 @@ void QCGTopLevel::upTriggered(QAction* action)
     count--;
   }
 
-  //qDebug("upActivated: %s", f ? f->prettyName().ascii() : "??" );
+  //qDebug("upActivated: %s", f ? f->prettyName().toAscii() : "??" );
   if (f)
     setFunction(f);
 }
@@ -2034,7 +1946,7 @@ void QCGTopLevel::upTriggered(QAction* action)
 void QCGTopLevel::showMessage(const QString& msg, int ms)
 {
 	if (_statusbar)
-		_statusbar->message(msg, ms);
+		_statusbar->showMessage(msg, ms);
 }
 
 void QCGTopLevel::showStatus(const QString& msg, int progress)
@@ -2050,7 +1962,7 @@ void QCGTopLevel::showStatus(const QString& msg, int progress)
 		    delete _progressBar;
 		    _progressBar = 0;
 		}
-		_statusbar->clear();
+		_statusbar->clearMessage();
 		_progressMsg = msg;
 		return;
 	}
@@ -2070,7 +1982,7 @@ void QCGTopLevel::showStatus(const QString& msg, int progress)
 	if (!_progressBar) {
 		_progressBar = new QProgressBar(_statusbar);
 		_progressBar->setMaximumSize(200, _statusbar->height()-4);
-		_statusbar->addWidget(_progressBar, 1, true);
+		_statusbar->addPermanentWidget(_progressBar, 1);
 		_progressBar->show();
 		msgUpdateNeeded = true;
 	}
@@ -2078,7 +1990,7 @@ void QCGTopLevel::showStatus(const QString& msg, int progress)
 	_progressStart.restart();
 
 	if (msgUpdateNeeded) {
-		_statusbar->message(msg);
+		_statusbar->showMessage(msg);
 		msgUpdateNeeded = false;
 	}
 	_progressBar->setValue(progress);
@@ -2108,12 +2020,12 @@ void QCGTopLevel::loadProgress(int progress)
 
 void QCGTopLevel::loadError(int line, const QString& msg)
 {
-    qCritical() << "Loading" << _filename.ascii() << ":" << line << ": " << msg.ascii();
+    qCritical() << "Loading" << _filename << ":" << line << ": " << msg.toAscii();
 }
 
 void QCGTopLevel::loadWarning(int line, const QString& msg)
 {
-    qWarning() << "Loading" << _filename.ascii() << ":" << line << ": " << msg.ascii();
+    qWarning() << "Loading" << _filename.toAscii() << ":" << line << ": " << msg.toAscii();
 }
 
 #include "qcgtoplevel.moc"
