@@ -115,6 +115,7 @@ Catalog::Catalog(QObject *parent)
     connect(this,SIGNAL(signalFileSaved()),   t,SLOT(start()));
     connect(this,SIGNAL(signalFileLoaded()),  t,SLOT(start()));
     connect(this,SIGNAL(indexChanged(int)),this,SLOT(setAutoSaveDirty()));
+    connect(Project::local(),SIGNAL(configChanged()),this,SLOT(projectConfigChanged()));
 }
 
 Catalog::~Catalog()
@@ -327,12 +328,37 @@ QString Catalog::setPhase(const DocPosition& pos, const QString& phase)
 
 void Catalog::setActivePhase(const QString& phase, ProjectLocal::PersonRole role)
 {
-    //TODO approved index cache change.
     d->_phase=phase;
     d->_phaseRole=role;
+    updateApprovedEmptyIndexCache();
     emit activePhaseChanged();
 }
 
+void Catalog::updateApprovedEmptyIndexCache()
+{
+    if (KDE_ISUNLIKELY( !m_storage ))
+        return;
+    
+    //index cache TODO profile?
+    d->_nonApprovedIndex.clear();
+    d->_emptyIndex.clear();
+
+    DocPosition pos(0);
+    const int limit=m_storage->size();
+    while (pos.entry<limit)
+    {
+        if (!isApproved(pos))
+            d->_nonApprovedIndex << pos.entry;
+        if (m_storage->isEmpty(pos))
+            d->_emptyIndex << pos.entry;
+
+        ++(pos.entry);
+    }
+    
+    emit signalNumberOfFuzziesChanged();
+    emit signalNumberOfEmptyChanged();
+}
+
 QString Catalog::phase(const DocPosition& pos) const
 {
     if (KDE_ISUNLIKELY( !m_storage ))
@@ -485,14 +511,17 @@ int Catalog::loadFromUrl(const KUrl& url, const KUrl& saidUrl, int* fileSize)
             return ISNTREADABLE;
         readOnly=!info.isWritable();
     }
+    else
+      return DOESNTEXIST;
 
 
     QTime a;a.start();
 
     QString target;
-    if(KDE_ISUNLIKELY( !KIO::NetAccess::download(url,target,NULL) ))
-        return ISNTREADABLE;
-    QFile* file=new QFile(target);
+    //if(KDE_ISUNLIKELY( !KIO::NetAccess::download(url,target,NULL) ))
+    //    return ISNTREADABLE;
+    //QFile* file=new QFile(target);
+    QFile* file=new QFile(url.toLocalFile());
     file->deleteLater();//kung-fu
     if (!file->open(QIODevice::ReadOnly))
         return ISNTREADABLE;//TODO
@@ -530,25 +559,11 @@ int Catalog::loadFromUrl(const KUrl& url, const KUrl& saidUrl, int* fileSize)
     //ok...
     clear();
 
-    //index cache TODO profile?
-    d->_nonApprovedIndex.clear();
-    d->_emptyIndex.clear();
-
-    DocPosition pos(0);
-    int limit=storage->size();
-    while (pos.entry<limit)
-    {
-        if (!storage->isApproved(pos))
-            d->_nonApprovedIndex << pos.entry;
-        if (storage->isEmpty(pos))
-            d->_emptyIndex << pos.entry;
-
-        ++(pos.entry);
-    }
-
     //commit transaction
     m_storage=storage;
 
+    updateApprovedEmptyIndexCache();
+    
     d->_numberOfPluralForms = storage->numberOfPluralForms();
     d->_autoSaveDirty=true;
     d->_readOnly=readOnly;
@@ -604,8 +619,9 @@ bool Catalog::saveToUrl(KUrl url)
     else
     {
         QString localFilePath=url.toLocalFile();
-        if (!QFileInfo(QFileInfo(localFilePath).absolutePath()).exists())
-            if (!QDir::root().mkpath(QFileInfo(localFilePath).absolutePath()))
+        QString localPath=QFileInfo(localFilePath).absolutePath();
+        if (!QFileInfo(localPath).exists())
+            if (!QDir::root().mkpath(localPath))
                 return false;
         file=new QFile(localFilePath);
     }
@@ -613,7 +629,8 @@ bool Catalog::saveToUrl(KUrl url)
     if (KDE_ISUNLIKELY( !file->open(QIODevice::WriteOnly) )) //i18n("Wasn't able to open file %1",filename.ascii());
         return false;
 
-    if (KDE_ISUNLIKELY( !m_storage->save(file) ))
+    bool belongsToProject=url.path().contains(Project::instance()->poDir());
+    if (KDE_ISUNLIKELY( !m_storage->save(file, belongsToProject) ))
         return false;
 
     QString localFile=file->fileName();
@@ -666,6 +683,10 @@ void Catalog::doAutoSave()
     d->_autoSaveDirty=false;
 }
 
+void Catalog::projectConfigChanged()
+{
+    setActivePhase(activePhase(), Project::local()->role());
+}
 
 QByteArray Catalog::contents()
 {
