@@ -101,24 +101,22 @@ void TermLabel::mousePressEvent (QMouseEvent* event)
         QAction* txt=menu.exec(event->globalPos());
         if (txt)
         {
-//         if (txt->text()==i18nc("Edit term","Edit"))
-            //const TermEntry& a(Project::instance()->glossary()->termList.at(m_termIndex));
-            GlossaryWindow* glossaryWindow=new GlossaryWindow;
-            glossaryWindow->show();
-            glossaryWindow->selectEntry(m_entryId);
+            GlossaryNS::GlossaryWindow* glossaryWindow=Project::instance()->showGlossary();
+            if (glossaryWindow)
+                glossaryWindow->selectEntry(m_entryId);
         }
     }
     else
         insert();
 }
 
-void TermLabel::setText(const QString& term, const QString& entryId, bool capFirst)
+void TermLabel::setText(const QString& term, const QByteArray& entryId, bool capFirst)
 {
     m_entryId=entryId;
     m_capFirst=capFirst;
-    QLabel::setText(term + QString(m_action?(" [" + m_action->shortcut().toString()+"]  \n  "):"  \n  ")//m_shortcut
+    QLabel::setText(QString(term + QString(m_action?QString(" [" + m_action->shortcut().toString()+"]  \n  "):"  \n  ")//m_shortcut
                 + Project::instance()->glossary()->terms(m_entryId, Project::instance()->targetLangCode()).join("  \n  ")
-                    + "  \n  ");
+                    + "  \n  "));
 }
 
 
