@@ -1,14 +1,14 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2007-2009 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2011 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -133,6 +133,10 @@ EditorTab::EditorTab(QWidget* parent, bool valid)
     connect(m_view, SIGNAL(tmLookupRequested(DocPosition::Part,QString)), this, SLOT(lookupSelectionInTranslationMemory()));
 
     connect(this, SIGNAL(fileOpened()), this, SLOT(indexWordsForCompletion()),Qt::QueuedConnection);
+
+    connect (m_catalog,SIGNAL(signalFileAutoSaveFailed(QString)),this,SLOT(fileAutoSaveFailedWarning(QString)));
+
+
     //defer some work to make window appear earlier (~200 msec on my Core Duo)
     //QTimer::singleShot(0,this,SLOT(initLater()));
     //kWarning()<<chrono.elapsed();
@@ -280,7 +284,7 @@ void EditorTab::setupActions()
     connect(m_view, SIGNAL(signalChanged(uint)), m_notesView, SLOT(removeErrorNotes()));
     connect(m_notesView,SIGNAL(escaped()),this,SLOT(setProperFocus()));
 
-    action=glossary->addAction(QLatin1String("edit_addnote"),m_notesView,SLOT(addNoteUI()));
+    action=edit->addAction(QLatin1String("edit_addnote"),m_notesView,SLOT(addNoteUI()));
     //action->setShortcut(Qt::CTRL+glist[i]);
     action->setText(i18nc("@action:inmenu","Add a note"));
 
@@ -310,13 +314,13 @@ void EditorTab::setupActions()
     TM::TMView* _tmView = new TM::TMView(this,m_catalog,tmactions);
     addDockWidget(Qt::BottomDockWidgetArea, _tmView);
     tm->addAction( QLatin1String("showtmqueryview_action"), _tmView->toggleViewAction() );
-    connect (this,SIGNAL(signalNewEntryDisplayed(DocPosition)),_tmView,SLOT(slotNewEntryDisplayed(DocPosition)));
     connect (_tmView,SIGNAL(refreshRequested()),m_view,SLOT(gotoEntry()),Qt::QueuedConnection);
     connect (_tmView,SIGNAL(refreshRequested()),this,SLOT(msgStrChanged()),Qt::QueuedConnection);
     connect (_tmView,SIGNAL(textInsertRequested(QString)),m_view,SLOT(insertTerm(QString)));
     connect (_tmView,SIGNAL(fileOpenRequested(KUrl,QString,QString)),this,SIGNAL(fileOpenRequested(KUrl,QString,QString)));
     connect (this,SIGNAL(fileAboutToBeClosed()),m_catalog,SLOT(flushUpdateDBBuffer()));
     connect (this,SIGNAL(signalNewEntryDisplayed(DocPosition)),m_catalog,SLOT(flushUpdateDBBuffer()));
+    connect (this,SIGNAL(signalNewEntryDisplayed(DocPosition)),_tmView,SLOT(slotNewEntryDisplayed(DocPosition))); //do this after flushUpdateDBBuffer
 
     QVector<KAction*> gactions(GLOSSARY_SHORTCUTS);
     Qt::Key glist[GLOSSARY_SHORTCUTS]=
@@ -403,7 +407,7 @@ void EditorTab::setupActions()
     addDockWidget(Qt::BottomDockWidgetArea, _webQueryView);
     actionCollection()->addAction( QLatin1String("showwebqueryview_action"), _webQueryView->toggleViewAction() );
     connect (this,SIGNAL(signalNewEntryDisplayed(DocPosition)),_webQueryView,SLOT(slotNewEntryDisplayed(DocPosition)));
-    connect (_webQueryView,SIGNAL(textInsertRequested(const QString&)),m_view,SLOT(insertTerm(const QString&)));
+    connect (_webQueryView,SIGNAL(textInsertRequested(QString)),m_view,SLOT(insertTerm(QString)));
 #endif
 
 
@@ -515,6 +519,10 @@ void EditorTab::setupActions()
     action->setShortcut(Qt::CTRL+Qt::Key_D);
     action->setText(i18nc("@action:inmenu","Clear"));
 
+    action=edit->addAction("edit_completion",m_view,SIGNAL(doExplicitCompletion()));
+    action->setShortcut(Qt::CTRL+Qt::ALT+Qt::Key_Space);
+    action->setText(i18nc("@action:inmenu","Completion"));
+
     action=edit->addAction("edit_tagmenu",m_view->viewPort(),SLOT(tagMenu()));
     action->setShortcut(Qt::CTRL+Qt::Key_T);
     action->setText(i18nc("@action:inmenu","Insert Tag"));
@@ -539,14 +547,14 @@ void EditorTab::setupActions()
 
     action=nav->addAction(KStandardAction::Prior,this, SLOT(gotoPrev()));
     action->setText(i18nc("@action:inmenu entry","&Previous"));
-    connect( this, SIGNAL( signalFirstDisplayed(bool) ), action , SLOT( setDisabled(bool) ) );
+    connect( this, SIGNAL(signalFirstDisplayed(bool)), action , SLOT(setDisabled(bool)) );
     connect(m_view->viewPort(),SIGNAL(gotoPrevRequested()),this,SLOT(gotoPrev()));
 
     action=nav->addAction(KStandardAction::FirstPage,this, SLOT(gotoFirst()));
     connect(m_view->viewPort(),SIGNAL(gotoFirstRequested()),this,SLOT(gotoFirst()));
     action->setText(i18nc("@action:inmenu","&First Entry"));
     action->setShortcut(QKeySequence(Qt::CTRL+Qt::ALT+Qt::Key_Home));
-    connect( this, SIGNAL( signalFirstDisplayed(bool) ), action , SLOT( setDisabled(bool) ) );
+    connect( this, SIGNAL(signalFirstDisplayed(bool)), action , SLOT(setDisabled(bool)) );
 
     action=nav->addAction(KStandardAction::LastPage,this, SLOT(gotoLast()));
     connect(m_view->viewPort(),SIGNAL(gotoLastRequested()),this,SLOT(gotoLast()));
@@ -559,33 +567,33 @@ void EditorTab::setupActions()
     action->setText(i18nc("@action:inmenu","Entry by number"));
 
     ADD_ACTION_SHORTCUT_ICON("go_prev_fuzzy",i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology","Previous non-empty but not ready"),Qt::CTRL+Qt::Key_PageUp,"prevfuzzy")
-    connect( action, SIGNAL( triggered(bool) ), this, SLOT( gotoPrevFuzzy() ) );
-    connect( m_view->viewPort(), SIGNAL( gotoPrevFuzzyRequested() ), this, SLOT(gotoPrevFuzzy()) );
+    connect( action, SIGNAL(triggered(bool)), this, SLOT(gotoPrevFuzzy()) );
+    connect( m_view->viewPort(), SIGNAL(gotoPrevFuzzyRequested()), this, SLOT(gotoPrevFuzzy()) );
     connect( this, SIGNAL(signalPriorFuzzyAvailable(bool)),action,SLOT(setEnabled(bool)) );
 
     ADD_ACTION_SHORTCUT_ICON("go_next_fuzzy",i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology","Next non-empty but not ready"),Qt::CTRL+Qt::Key_PageDown,"nextfuzzy")
-    connect( action, SIGNAL( triggered(bool) ), this, SLOT( gotoNextFuzzy() ) );
-    connect( m_view->viewPort(), SIGNAL( gotoNextFuzzyRequested() ), this, SLOT(gotoNextFuzzy()) );
+    connect( action, SIGNAL(triggered(bool)), this, SLOT(gotoNextFuzzy()) );
+    connect( m_view->viewPort(), SIGNAL(gotoNextFuzzyRequested()), this, SLOT(gotoNextFuzzy()) );
     connect( this, SIGNAL(signalNextFuzzyAvailable(bool)),action,SLOT(setEnabled(bool)) );
 
     ADD_ACTION_SHORTCUT_ICON("go_prev_untrans",i18nc("@action:inmenu","Previous untranslated"),Qt::ALT+Qt::Key_PageUp,"prevuntranslated")
     connect( action, SIGNAL(triggered(bool)), this, SLOT(gotoPrevUntranslated()));
-    connect( m_view->viewPort(), SIGNAL( gotoPrevUntranslatedRequested() ), this, SLOT(gotoPrevUntranslated()) );
+    connect( m_view->viewPort(), SIGNAL(gotoPrevUntranslatedRequested()), this, SLOT(gotoPrevUntranslated()) );
     connect( this, SIGNAL(signalPriorUntranslatedAvailable(bool)),action,SLOT(setEnabled(bool)) );
 
     ADD_ACTION_SHORTCUT_ICON("go_next_untrans",i18nc("@action:inmenu","Next untranslated"),Qt::ALT+Qt::Key_PageDown,"nextuntranslated")
     connect( action, SIGNAL(triggered(bool)), this, SLOT(gotoNextUntranslated()));
-    connect( m_view->viewPort(), SIGNAL( gotoNextUntranslatedRequested() ), this, SLOT(gotoNextUntranslated()) );
+    connect( m_view->viewPort(), SIGNAL(gotoNextUntranslatedRequested()), this, SLOT(gotoNextUntranslated()) );
     connect( this, SIGNAL(signalNextUntranslatedAvailable(bool)),action,SLOT(setEnabled(bool)) );
 
     ADD_ACTION_SHORTCUT_ICON("go_prev_fuzzyUntr",i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology","Previous not ready"),Qt::CTRL+Qt::SHIFT/*ALT*/+Qt::Key_PageUp,"prevfuzzyuntrans")
-    connect( action, SIGNAL( triggered(bool) ), this, SLOT( gotoPrevFuzzyUntr() ) );
-    connect( m_view->viewPort(), SIGNAL( gotoPrevFuzzyUntrRequested() ), this, SLOT(gotoPrevFuzzyUntr()) );
+    connect( action, SIGNAL(triggered(bool)), this, SLOT(gotoPrevFuzzyUntr()) );
+    connect( m_view->viewPort(), SIGNAL(gotoPrevFuzzyUntrRequested()), this, SLOT(gotoPrevFuzzyUntr()) );
     connect( this, SIGNAL(signalPriorFuzzyOrUntrAvailable(bool)),action,SLOT(setEnabled(bool)) );
 
     ADD_ACTION_SHORTCUT_ICON("go_next_fuzzyUntr",i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology","Next not ready"),Qt::CTRL+Qt::SHIFT+Qt::Key_PageDown,"nextfuzzyuntrans")
-    connect( action, SIGNAL( triggered(bool) ), this, SLOT( gotoNextFuzzyUntr() ) );
-    connect( m_view->viewPort(), SIGNAL( gotoNextFuzzyUntrRequested() ), this, SLOT(gotoNextFuzzyUntr()) );
+    connect( action, SIGNAL(triggered(bool)), this, SLOT(gotoNextFuzzyUntr()) );
+    connect( m_view->viewPort(), SIGNAL(gotoNextFuzzyUntrRequested()), this, SLOT(gotoNextFuzzyUntr()) );
     connect( this, SIGNAL(signalNextFuzzyOrUntrAvailable(bool)),action,SLOT(setEnabled(bool)) );
 
     action=nav->addAction("go_focus_earch_line",m_transUnitsView, SLOT(setFocus()));
@@ -615,15 +623,15 @@ void EditorTab::setupActions()
     actionCategory=tm;
     // xgettext: no-c-format
     ADD_ACTION_SHORTCUT("tools_tm_batch",i18nc("@action:inmenu","Fill in all exact suggestions"),Qt::CTRL+Qt::ALT+Qt::Key_B)
-    connect( action, SIGNAL( triggered(bool) ), _tmView, SLOT( slotBatchTranslate() ) );
+    connect( action, SIGNAL(triggered(bool)), _tmView, SLOT(slotBatchTranslate()) );
 
     // xgettext: no-c-format
     ADD_ACTION_SHORTCUT("tools_tm_batch_fuzzy",i18nc("@action:inmenu","Fill in all exact suggestions and mark as fuzzy"),Qt::CTRL+Qt::ALT+Qt::Key_N)
-    connect( action, SIGNAL( triggered(bool) ), _tmView, SLOT( slotBatchTranslateFuzzy() ) );
+    connect( action, SIGNAL(triggered(bool)), _tmView, SLOT(slotBatchTranslateFuzzy()) );
 
     actionCategory=tools;
     ADD_ACTION_SHORTCUT("tools_wordcount",i18nc("@action:inmenu","Word count"),Qt::CTRL+Qt::ALT+Qt::Key_C)
-    connect( action, SIGNAL( triggered(bool) ), this, SLOT( displayWordCount() ) );
+    connect( action, SIGNAL(triggered(bool)), this, SLOT(displayWordCount()) );
 
 //MergeMode
     action = sync1->addAction("merge_open",m_syncView,SLOT(mergeOpen()));
@@ -662,6 +670,7 @@ void EditorTab::setupActions()
     action->setStatusTip(i18nc("@info:status","This changes only empty and non-ready entries in base file"));
     action->setToolTip(action->statusTip());
     action->setWhatsThis(action->statusTip());
+    action->setShortcut(Qt::CTRL+Qt::ALT+Qt::Key_A);
     m_syncView->addAction(action);
     //action->setShortcut(Qt::ALT+Qt::Key_E);
 
@@ -774,7 +783,7 @@ bool EditorTab::fileOpen(KUrl url, KUrl baseUrl, bool silent)
 {
     if (!m_catalog->isClean())
     {
-        switch (KMessageBox::warningYesNoCancel(this,
+        switch (KMessageBox::warningYesNoCancel(SettingsController::instance()->mainWindowPtr(),
                                                 i18nc("@info","The document contains unsaved changes.\n"
                                                       "Do you want to save your changes or discard them?"),i18nc("@title:window","Warning"),
                                                 KStandardGuiItem::save(),KStandardGuiItem::discard())
@@ -792,7 +801,7 @@ bool EditorTab::fileOpen(KUrl url, KUrl baseUrl, bool silent)
     {
         //Prevent crashes
         Project::instance()->model()->weaver()->suspend();
-        url=KFileDialog::getOpenFileName(baseUrl, "text/x-gettext-translation text/x-gettext-translation-template application/x-xliff",this);
+        url=KFileDialog::getOpenFileName(baseUrl, "text/x-gettext-translation text/x-gettext-translation-template application/x-xliff",SettingsController::instance()->mainWindowPtr());
         Project::instance()->model()->weaver()->resume();
         //TODO application/x-xliff, windows: just extensions
         //originalPath=url.path(); never used
@@ -831,6 +840,7 @@ bool EditorTab::fileOpen(KUrl url, KUrl baseUrl, bool silent)
         //we delay gotoEntry(pos) until project is loaded;
 
 
+        //TODO "test" for the name????
         m_catalog->setActivePhase("test",Project::local()->role());
 //Project
         if (url.isLocalFile() && !_project->isLoaded())
@@ -849,6 +859,13 @@ bool EditorTab::fileOpen(KUrl url, KUrl baseUrl, bool silent)
 
             //enforce autosync
             m_syncViewSecondary->mergeOpen(url);
+            
+            if (!_project->isLoaded() && _project->desirablePath().isEmpty())
+            {
+                _project->setDesirablePath(url.directory(KUrl::AppendTrailingSlash)+"index.lokalize");
+                //_project->setLangCode(m_catalog->targetLangCode());
+            }
+                
         }
 
         gotoEntry(pos);
@@ -896,6 +913,12 @@ bool EditorTab::saveFile(const KUrl& url)
     return false;
 }
 
+void EditorTab::fileAutoSaveFailedWarning(const QString& fileName)
+{
+    KMessageBox::information(this, i18nc("@info","Could not perform file autosaving.\n"
+                                                 "The target file was <filename>%1</filename>.", fileName) );
+}
+
 EditorState EditorTab::state()
 {
     EditorState state;
@@ -1217,7 +1240,19 @@ void EditorTab::showStatesMenu()
 {
     m_approveAction->menu()->clear();
     if (!(m_catalog->capabilities()&ExtendedStates))
+    {
+        QAction* a=m_approveAction->menu()->addAction(i18nc("@info:status 'fuzzy' in gettext terminology","Needs review"));
+        a->setData(QVariant(-1));
+        a->setCheckable(true);
+        a->setChecked(!m_catalog->isApproved(m_currentPos));
+
+        a=m_approveAction->menu()->addAction(i18nc("@info:status 'non-fuzzy' in gettext terminology","Ready"));
+        a->setData(QVariant(-2));
+        a->setCheckable(true);
+        a->setChecked(m_catalog->isApproved(m_currentPos));
+
         return;
+    }
 
     TargetState state=m_catalog->state(m_currentPos);
 
@@ -1236,7 +1271,11 @@ void EditorTab::showStatesMenu()
 
 void EditorTab::setState(QAction* a)
 {
-    m_view->setState(TargetState(a->data().toInt()));
+    if (!(m_catalog->capabilities()&ExtendedStates))
+        m_view->toggleApprovement();
+    else
+        m_view->setState(TargetState(a->data().toInt()));
+
     m_approveAction->menu()->clear();
 }
 
@@ -1278,15 +1317,26 @@ KUrl EditorWindow::mergeFile()
 }
 */
 
+//HACK to prevent redundant repaintings when widget isn't visible
+void EditorTab::paintEvent(QPaintEvent* event)
+{
+    if (QMdiSubWindow* sw=qobject_cast<QMdiSubWindow*>(parent()))
+    {
+        if (sw->mdiArea()->currentSubWindow()!=sw)
+           return;
+    }
+    LokalizeSubwindowBase2::paintEvent(event);
+}
+
 void EditorTab::indexWordsForCompletion()
 {
     CompletionStorage::instance()->scanCatalog(m_catalog);
 }
 
-
 //see also termlabel.h
 void EditorTab::defineNewTerm()
 {
+    //TODO just a word under cursor?
     QString en(m_view->selectionInSource().toLower());
     if (en.isEmpty())
         en=m_catalog->msgid(m_currentPos).toLower();
@@ -1364,6 +1414,18 @@ void EditorTab::addTemporaryEntryNote(int entry, const QString& note){m_notesVie
 
 void EditorTab::attachAlternateTranslationFile(const QString& path){m_altTransView->attachAltTransFile(path);}
 
+void EditorTab::setEntryTarget(int entry, int form, const QString& content)
+{
+    DocPosition pos(entry,form);
+    //TODO uncomment when trunk is open for new strings
+    //m_catalog->beginMacro(i18nc("@item Undo action item","Set unit text"));
+    removeTargetSubstring(m_catalog, pos);
+    insertCatalogString(m_catalog, pos, CatalogString(content));
+    //m_catalog->endMacro();
+    if (m_currentPos==pos)
+        m_view->gotoEntry();
+}
+
 //END DBus interface
 
 
