@@ -1,7 +1,7 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2007-2009 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2011 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -26,11 +26,9 @@
 #include "project.h"
 #include "dbfilesmodel.h"
 #include "tmscanapi.h"
+#include "qaview.h"
 
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <kxmlguifactory.h>
-#include <threadweaver/ThreadWeaver.h>
+#include <iostream>
 
 #include <QApplication>
 #include <QDesktopWidget>
@@ -44,9 +42,20 @@
 #include <QShortcut>
 #include <QDragEnterEvent>
 #include <QSortFilterProxyModel>
+#include <QStyledItemDelegate>
+#include <QStringBuilder>
+#include <QPainter>
+#include <QTextDocument>
+#include <QDomDocument>
+#include <QStringBuilder>
 
-#include <iostream>
-
+#include <KColorScheme>
+#include <kactioncategory.h>
+#include <kaction.h>
+#include <klocale.h>
+#include <kstandarddirs.h>
+#include <kxmlguifactory.h>
+#include <threadweaver/ThreadWeaver.h>
 
 
 using namespace TM;
@@ -54,27 +63,93 @@ using namespace TM;
 
 //TODO do things for case when user explicitly wants to find & accel mark
 
-
-class FastSizeHintItemDelegate: public QItemDelegate
+void FastSizeHintItemDelegate::reset()
 {
-  //Q_OBJECT
+    cache.clear();
+}
 
-public:
-    FastSizeHintItemDelegate(int columnCount, QObject *parent)
-        : QItemDelegate(parent)
-    {Q_UNUSED(columnCount);}
-    ~FastSizeHintItemDelegate(){}
-
-/*    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
+QSize FastSizeHintItemDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
+{
+    int lineCount=1;
+    int nPos=20;
+    if (index.column()!=TMDBModel::Filepath && index.column()!=TMDBModel::TransationStatus)
     {
-        return QSize(100,30);
-    }*/
-};
+        QString text=index.data().toString();
+        nPos=text.indexOf('\n');
+        if (nPos==-1)
+            nPos=text.size();
+        else
+            lineCount+=text.count('\n');
+    }
+    static QFontMetrics metrics(option.font);
+    return QSize(metrics.averageCharWidth()*nPos, metrics.height()*lineCount);
+}
+
+void FastSizeHintItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
+{
+    painter->save();
+
+    const KColorScheme& scheme=activeScheme;
+    //painter->save();
+    painter->setClipping(true);
+    painter->setClipRect(option.rect);
+    QBrush bgBrush;
+    if (option.state&QStyle::State_MouseOver)
+        bgBrush=scheme.background(KColorScheme::LinkBackground);
+    else if (index.row()%2)
+        bgBrush=scheme.background(KColorScheme::AlternateBackground);
+    else
+        bgBrush=scheme.background(KColorScheme::NormalBackground);
+    
+    painter->fillRect(option.rect, bgBrush);
+    painter->setClipRect(option.rect.adjusted(0,0,-2,0));
+    //painter->setFont(option.font);
+
+    RowColumnUnion rc;
+    rc.index.row=index.row();
+    rc.index.column=index.column();
+    //TMDBModel* m=static_cast<const TMDBModel*>(index.model());
+    if (!cache.contains(rc.v))
+    {
+        QString text=index.data(TMDBModel::HtmlDisplayRole).toString();
+        cache.insert(rc.v, new QStaticText(text));
+        cache.object(rc.v)->setTextFormat(index.column()<TMDBModel::Context?Qt::RichText:Qt::PlainText);
+    }
+    int rectWidth=option.rect.width();
+    QStaticText* staticText=cache.object(rc.v);
+    //staticText->setTextWidth(rectWidth-4);
+    QPoint textStartPoint=option.rect.topLeft();
+    textStartPoint.rx()+=2;
+    painter->drawStaticText(textStartPoint, *staticText);
+
+
+    if (staticText->size().width()<=rectWidth-4)
+    {
+        painter->restore();
+        return;
+    }
+
+    painter->setPen(bgBrush.color());
+    QPoint p1=option.rect.topRight();
+    QPoint p2=option.rect.bottomRight();
+    int limit=qMin(8, rectWidth-2);
+    int i=limit;
+    while(--i>0)
+    {
+        painter->setOpacity(float(i)/limit);
+        painter->drawLine(p1, p2);
+        p1.rx()--;
+        p2.rx()--;
+    }
+    painter->restore();
+}
+
 
 //BEGIN TMDBModel
 TMDBModel::TMDBModel(QObject* parent)
     : QSqlQueryModel(parent)
     , m_queryType(WordOrder)
+    , m_totalResultCount(0)
 {
     setHeaderData(TMDBModel::Source,            Qt::Horizontal, i18nc("@title:column Original text","Source"));
     setHeaderData(TMDBModel::Target,            Qt::Horizontal, i18nc("@title:column Text in target language","Target"));
@@ -112,9 +187,9 @@ void TMDBModel::setFilter(const QString& source, const QString& target,
         escapedSource.replace('%',"\b%");escapedSource.replace('_',"\b_");
         escapedTarget.replace('%',"\b%");escapedTarget.replace('_',"\b_");
         if (!escapedSource.isEmpty())
-            sourceQuery="AND source_strings.source "+invertSourceStr+"LIKE '%"+escapedSource+"%' ESCAPE '\b' ";
+            sourceQuery="AND source_strings.source "%invertSourceStr%"LIKE '%"+escapedSource+"%' ESCAPE '\b' ";
         if (!escapedTarget.isEmpty())
-            targetQuery="AND target_strings.target "+invertTargetStr+"LIKE '%"+escapedTarget+"%' ESCAPE '\b' ";
+            targetQuery="AND target_strings.target "%invertTargetStr%"LIKE '%"+escapedTarget+"%' ESCAPE '\b' ";
     }
     else if (m_queryType==WordOrder)
     {
@@ -131,37 +206,50 @@ void TMDBModel::setFilter(const QString& source, const QString& target,
     else
     {
         if (!escapedSource.isEmpty())
-            sourceQuery="AND source_strings.source "+invertSourceStr+"GLOB '"+escapedSource+"' ";
+            sourceQuery="AND source_strings.source "%invertSourceStr%"GLOB '"%escapedSource%"' ";
         if (!escapedTarget.isEmpty())
-            targetQuery="AND target_strings.target "+invertTargetStr+"GLOB '"+escapedTarget+"' ";
+            targetQuery="AND target_strings.target "%invertTargetStr%"GLOB '"%escapedTarget%"' ";
 
     }
     if (!filemask.isEmpty())
-        fileQuery="AND files.path GLOB '"+escapedFilemask+"' ";
+        fileQuery="AND files.path GLOB '"%escapedFilemask%"' ";
 
+    QString fromPart="FROM main JOIN source_strings ON (source_strings.id=main.source) "
+                     "JOIN target_strings ON (target_strings.id=main.target), files "
+                     "WHERE files.id=main.file "
+                     +sourceQuery
+                     +targetQuery
+                     +fileQuery;
 
     ExecQueryJob* job=new ExecQueryJob(
                 "SELECT source_strings.source, target_strings.target, "
                 "main.ctxt, files.path, "
                 "source_strings.source_accel, target_strings.target_accel, main.bits "
-                "FROM main JOIN source_strings ON (source_strings.id==main.source) "
-                "JOIN target_strings ON (target_strings.id==main.target), files "
-                "WHERE files.id==main.file "
-                +sourceQuery
-                +targetQuery
-                +fileQuery,m_dbName);
-
+                +fromPart,m_dbName);
 
     connect(job,SIGNAL(done(ThreadWeaver::Job*)),job,SLOT(deleteLater()));
     connect(job,SIGNAL(done(ThreadWeaver::Job*)),this,SLOT(slotQueryExecuted(ThreadWeaver::Job*)));
     ThreadWeaver::Weaver::instance()->enqueue(job);
 
-    //kWarning()<<"TEST"<<BIG_COUNTER;
+
+    job=new ExecQueryJob("SELECT count(*) "+fromPart,m_dbName);
+    connect(job,SIGNAL(done(ThreadWeaver::Job*)),job,SLOT(deleteLater()));
+    connect(job,SIGNAL(done(ThreadWeaver::Job*)),this,SLOT(slotQueryExecuted(ThreadWeaver::Job*)));
+    ThreadWeaver::Weaver::instance()->enqueue(job);
+    
+    m_totalResultCount=0;
 }
 
 void TMDBModel::slotQueryExecuted(ThreadWeaver::Job* j)
 {
     ExecQueryJob* job=static_cast<ExecQueryJob*>(j);
+    if (job->query->lastQuery().startsWith("SELECT count(*) "))
+    {
+        job->query->next();
+        m_totalResultCount=job->query->value(0).toInt();
+        emit finalResultCountFetched(m_totalResultCount);
+        return;
+    }
     setQuery(*(job->query));
     emit resultsFetched();
 }
@@ -183,16 +271,18 @@ int TMDBModel::translationStatus(const QModelIndex& item) const
 #define TM_DELIMITER '\v'
 QVariant TMDBModel::data(const QModelIndex& item, int role) const
 {
-    //TODO Qt::ForegroundRole -- brush for orphaned entries
-    if (role==Qt::FontRole && item.column()==TMDBModel::Target)
+    bool doHtml=(role==HtmlDisplayRole);
+    if (doHtml)
+        role=Qt::DisplayRole;
+    else if (role==Qt::FontRole && item.column()==TMDBModel::Target) //TODO Qt::ForegroundRole -- brush for orphaned entries
     {
         QFont font=QApplication::font();
         font.setItalic(!rowIsApproved(item.row()));
         return font;
     }
-    else if (role==FullPath && item.column()==TMDBModel::Filepath)
+    else if (role==FullPathRole && item.column()==TMDBModel::Filepath)
         return QSqlQueryModel::data(item, Qt::DisplayRole);
-    else if (role==TransState)
+    else if (role==TransStateRole)
         return translationStatus(item);
 
     QVariant result=QSqlQueryModel::data(item, role);
@@ -208,15 +298,13 @@ QVariant TMDBModel::data(const QModelIndex& item, int role) const
         if (pos!=-1)
             result=r.remove(pos, r.size());
     }
-    else if (item.column()<TMDBModel::Context)//source, target
+    else if (item.column()<TMDBModel::Context && !record(item.row()).isNull(TMDBModel::_SourceAccel+item.column()) )//source, target
     {
         const QVariant& posVar=record(item.row()).value(TMDBModel::_SourceAccel+item.column());
         int pos=-1;
         bool ok;
         if (posVar.isValid())
             pos=posVar.toInt(&ok);
-        //std::cout<<"ok "<<ok<<"; pos "<<pos<<"; column "<<item.column()<<" "<<TMDBModel::ColumnCount+item.column()<<std::endl;
-        //kWarning()<<QSqlQueryModel::data(QSqlQueryModel::index(item.row(),TMDBModel::TMDBModelColumnCount+item.column()));
         if (ok && pos!=-1)
         {
             QString r=result.toString();
@@ -238,8 +326,20 @@ QVariant TMDBModel::data(const QModelIndex& item, int role) const
                                    i18nc("@info:status","Untranslated")};
         return statuses[translationStatus(item)];
     }
-    return result;
+    if (doHtml && item.column()<TMDBModel::Context)
+    {
+        QString r=result.toString();
+        if (r.isEmpty())
+            return r;
+        r=Qt::convertFromPlainText(r); //FIXME use another routine (this has bugs)
+        if (item.column()==TMDBModel::Target && !rowIsApproved(item.row()))
+            r="<p><i>" % r.mid(3, r.length()-3) % "</i></p>";
+        return r;
+    }
+    else
+        return result;
 }
+
 //END TMDBModel
 
 //BEGIN TMResultsSortFilterProxyModel
@@ -249,21 +349,109 @@ public:
     TMResultsSortFilterProxyModel(QObject *parent)
         : QSortFilterProxyModel(parent)
     {}
+    void setRules(const QVector<Rule>& rules);
+    void fetchMore(const QModelIndex& parent);
+    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
+
 protected:
     bool lessThan(const QModelIndex& left, const QModelIndex& right) const;
+    bool filterAcceptsRow(int source_row, const QModelIndex& source_parent) const;
+
+private:
+    QVector<Rule> m_rules;
+    mutable QMap<int,int> m_matchingRulesForSourceRow;
 };
 
 bool TMResultsSortFilterProxyModel::lessThan(const QModelIndex& left, const QModelIndex& right) const
 {
     if (left.column()==TMDBModel::TransationStatus)
     {
-        int l=left.data(TMDBModel::TransState).toInt();
-        int r=right.data(TMDBModel::TransState).toInt();
-        if (l!=r)
-            return l<r;
+        int l=left.data(TMDBModel::TransStateRole).toInt();
+        int r=right.data(TMDBModel::TransStateRole).toInt();
+        return l<r;
     }
     return QSortFilterProxyModel::lessThan(left, right);
 }
+
+void TMResultsSortFilterProxyModel::fetchMore(const QModelIndex& parent)
+{
+    int oldSourceRowCount=sourceModel()->rowCount();
+    int oldRowCount=rowCount();
+    QSortFilterProxyModel::fetchMore(parent);
+
+    if (m_rules.isEmpty())
+        return;
+
+    while (oldRowCount==rowCount())
+    {
+        QSortFilterProxyModel::fetchMore(parent);
+        if (sourceModel()->rowCount()==oldSourceRowCount)
+            break;
+        oldSourceRowCount=sourceModel()->rowCount();
+    }
+    qDebug()<<"row count"<<sourceModel()->rowCount()<<"   filtered:"<<rowCount();
+    emit layoutChanged();
+}
+
+void TMResultsSortFilterProxyModel::setRules(const QVector<Rule>& rules)
+{
+    m_rules=rules;
+    invalidateFilter();
+}
+
+QVariant TMResultsSortFilterProxyModel::data(const QModelIndex& index, int role) const
+{
+    QVariant result=QSortFilterProxyModel::data(index, role);
+
+    if (m_rules.isEmpty() || role!=TMDBModel::HtmlDisplayRole)
+        return result;
+
+    if (index.column()!=TMDBModel::Source && index.column()!=TMDBModel::Target)
+        return result;
+
+    int source_row=mapToSource(index).row();
+    QString string=result.toString();
+    QVector<QRegExp> regExps;
+    if (index.column()==TMDBModel::Source)
+        regExps=m_rules[m_matchingRulesForSourceRow[source_row]].sources;
+    else
+        regExps=m_rules[m_matchingRulesForSourceRow[source_row]].falseFriends;
+
+    foreach(const QRegExp& re, regExps)
+    {
+        int pos=re.indexIn(string);
+        if (pos!=-1)
+            return string.replace(pos, re.matchedLength(), "<b>" % re.cap(0) % "</b>");
+    }
+
+    return result;
+}
+    
+bool TMResultsSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex& source_parent) const
+{
+    if (m_rules.isEmpty())
+        return true;
+
+    QString source=sourceModel()->index(source_row, TMDBModel::Source, source_parent).data().toString();
+    QString target=sourceModel()->index(source_row, TMDBModel::Target, source_parent).data().toString();
+
+    bool accept=false;
+    int i=0;
+    for(QVector<Rule>::const_iterator it=m_rules.constBegin();it!=m_rules.constEnd();it++)
+    {
+        if (it->sources.first().indexIn(source)!=-1)
+        {
+            if (it->falseFriends.first().indexIn(target)!=-1)
+            {
+                accept=true;
+                m_matchingRulesForSourceRow[source_row]=i;
+                break;
+            }
+        }
+        i++;
+    }
+    return accept;
+}
 //END TMResultsSortFilterProxyModel
 
 //BEGIN TMWindow
@@ -275,6 +463,7 @@ TMTab::TMTab(QWidget *parent)
 {
     //setCaption(i18nc("@title:window","Translation Memory"),false);
     setWindowTitle(i18nc("@title:window","Translation Memory"));
+    setAcceptDrops(true);
 
     ui_queryOptions=new Ui_QueryOptions;
     QWidget* w=new QWidget(this);
@@ -290,13 +479,9 @@ TMTab::TMTab(QWidget *parent)
 
     QShortcut* sh=new QShortcut(Qt::CTRL+Qt::Key_L, this);
     connect(sh,SIGNAL(activated()),ui_queryOptions->querySource,SLOT(setFocus()));
-
+    setFocusProxy(ui_queryOptions->querySource);
 
     QTreeView* view=ui_queryOptions->treeView;
-    //QueryResultDelegate* delegate=new QueryResultDelegate(this);
-    //view->setItemDelegate(delegate);
-    //view->setSelectionBehavior(QAbstractItemView::SelectItems);
-    //connect(delegate,SIGNAL(fileOpenRequested(KUrl)),this,SIGNAL(fileOpenRequested(KUrl)));
     view->setContextMenuPolicy(Qt::ActionsContextMenu);
 
     QAction* a=new QAction(i18n("Copy source to clipboard"),view);
@@ -331,12 +516,19 @@ TMTab::TMTab(QWidget *parent)
     view->setModel(m_proxyModel);
     view->sortByColumn(TMDBModel::Filepath,Qt::AscendingOrder);
     view->setSortingEnabled(true);
-    //view->setItemDelegate(new FastSizeHintItemDelegate(4,this));
     view->setColumnHidden(TMDBModel::_SourceAccel,true);
     view->setColumnHidden(TMDBModel::_TargetAccel,true);
     view->setColumnHidden(TMDBModel::_Bits,true);
+    view->setItemDelegate(new FastSizeHintItemDelegate(this));
+    connect(m_model,SIGNAL(resultsFetched()),view->itemDelegate(),SLOT(reset()));
+    connect(m_model,SIGNAL(modelReset()),view->itemDelegate(),SLOT(reset()));
+    //connect(m_model,SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),view->itemDelegate(),SLOT(reset()));
+    connect(m_proxyModel,SIGNAL(layoutChanged()),view->itemDelegate(),SLOT(reset()));
+    connect(m_proxyModel,SIGNAL(layoutChanged()),this,SLOT(displayTotalResultCount()));
+
 
     connect(m_model,SIGNAL(resultsFetched()),this,SLOT(handleResults()));
+    connect(m_model,SIGNAL(finalResultCountFetched(int)),this,SLOT(displayTotalResultCount()));
 
     QButtonGroup* btnGrp=new QButtonGroup(this);
     btnGrp->addButton(ui_queryOptions->substr,(int)TMDBModel::SubStr);
@@ -344,24 +536,42 @@ TMTab::TMTab(QWidget *parent)
     btnGrp->addButton(ui_queryOptions->glob,(int)TMDBModel::Glob);
     connect(btnGrp,SIGNAL(buttonClicked(int)),m_model,SLOT(setQueryType(int)));
 
-    setAcceptDrops(true);
-    /*
-    ui_queryOptions.db->setModel(DBFilesModel::instance());
-    ui_queryOptions.db->setCurrentIndex(ui_queryOptions.db->findText(Project::instance()->projectID()));
-    connect(ui_queryOptions.db,SIGNAL(currentIndexChanged(QString)),
-            m_model,SLOT(setDB(QString)));
-    */
-
-    //m_dbCombo->setCurrentIndex(m_dbCombo->findText(Project::instance()->projectID()));
+    ui_queryOptions->dbName->setModel(DBFilesModel::instance());
+    ui_queryOptions->dbName->setRootModelIndex(DBFilesModel::instance()->rootIndex());
+    QPersistentModelIndex* pi=DBFilesModel::instance()->projectDBIndex();
+    if (pi)
+    {
+        ui_queryOptions->dbName->setCurrentIndex(pi->row());
+        ui_queryOptions->dbName->view()->setCurrentIndex(*pi);
+    }
+    connect(ui_queryOptions->dbName, SIGNAL(activated(QString)), m_model, SLOT(setDB(QString)));
+    //connect(ui_queryOptions->dbName, SIGNAL(activated(QString)), this, SLOT(performQuery()));
 
+    
     int i=6;
     while (--i>ID_STATUS_PROGRESS)
-        statusBarItems.insert(i,"");
+        statusBarItems.insert(i,QString());
 
     setXMLFile("translationmemoryrui.rc",true);
     dbusObjectPath();
 
 
+    KAction *action;
+    KActionCollection* ac=actionCollection();
+    KActionCategory* tm=new KActionCategory(i18nc("@title actions category","Translation Memory"), ac);
+
+    action = tm->addAction("tools_tm_manage",Project::instance(),SLOT(showTMManager()));
+    action->setText(i18nc("@action:inmenu","Manage translation memories"));
+
+    m_qaView = new QaView(this);
+    m_qaView->hide();
+    addDockWidget(Qt::RightDockWidgetArea, m_qaView);
+    tm->addAction( QLatin1String("showqa_action"), m_qaView->toggleViewAction() );
+
+
+    connect(m_qaView, SIGNAL(rulesChanged()), this, SLOT(setQAMode()));
+    connect(m_qaView->toggleViewAction(), SIGNAL(toggled(bool)), this, SLOT(setQAMode(bool)));
+
 
     KConfig config;
     KConfigGroup cg(&config,"MainWindow");
@@ -378,12 +588,6 @@ TMTab::~TMTab()
     ids.removeAll(m_dbusId);
 }
 
-void TMTab::selectDB(int i)
-{
-    Q_UNUSED(i);
-    //m_dbCombo->setCurrentIndex(i);
-}
-
 void TMTab::updateTM()
 {
     QList<QUrl> urls;
@@ -443,11 +647,11 @@ void TMTab::handleResults()
 //BEGIN resizeColumnToContents
     QTreeView* view=ui_queryOptions->treeView;
     static const int maxInitialWidths[4]={QApplication::desktop()->availableGeometry().width()/3,QApplication::desktop()->availableGeometry().width()/3, 50, 200};
-    int column=4;//sizeof(maxInitialWidths);
+    int column=sizeof(maxInitialWidths)/sizeof(int);
     while (--column>=0)
     {
         //view->resizeColumnToContents(i);
-        int sum=0;
+        /*
         int max=0;
         int count=qMin(rowCount, 32);
         for (int row=0;row<count;++row)
@@ -455,23 +659,26 @@ void TMTab::handleResults()
             int w = view->itemDelegate()->sizeHint(QStyleOptionViewItemV2(),m_model->index(row,column)).width();
             if (w>max)
                 max=w;
-            sum+=w;
-            //qWarning()<<row<<column<<m_model->index(row,column).isValid();
-            //qWarning()<<view->sizeHintForIndex(m_model->index(row,column));
-            //qWarning()<<m_model->data(m_model->index(row,column), Qt::SizeHintRole).toSize();
-            //qWarning()<<m_model->span(m_model->index(row,column));
         }
         if (count) //qWarning()<<(sum/count);
-            //view->setColumnWidth(column, max);
-            //view->setColumnWidth(column, maxInitialWidths[column]);
             view->setColumnWidth(column, qMin(max, maxInitialWidths[column]));
+        */
+        view->setColumnWidth(column, maxInitialWidths[column]);
     }
     view->setFocus();
 //END resizeColumnToContents
-
-    statusBarItems.insert(1,i18nc("@info:status message entries","Total: %1",rowCount));
 }
 
+void TMTab::displayTotalResultCount()
+{
+    int total=m_model->totalResultCount();
+    int filtered=m_proxyModel->rowCount();
+    if (filtered==m_model->rowCount())
+        statusBarItems.insert(1,i18nc("@info:status message entries","Total: %1",total));
+    else
+        statusBarItems.insert(1,i18nc("@info:status message entries","Total: %1 (%2)",filtered,total));
+}
+    
 static void copy(Ui_QueryOptions* ui_queryOptions, int column)
 {
     QApplication::clipboard()->setText( ui_queryOptions->treeView->currentIndex().sibling(ui_queryOptions->treeView->currentIndex().row(),column).data().toString());
@@ -495,11 +702,31 @@ void TMTab::openFile()
                            item.sibling(item.row(),TMDBModel::Context).data().toString());
 }
 
-/*
-void TMWindow::setOptions(int i)
-{
 
-}*/
+
+void TMTab::setQAMode(bool enable)
+{
+    if (!enable)
+    {
+        m_proxyModel->setRules(QVector<Rule>());
+        return;
+    }
+
+    m_proxyModel->setRules(m_qaView->rules());
+    static_cast<FastSizeHintItemDelegate*>(ui_queryOptions->treeView->itemDelegate())->reset();
+
+    /*QDomElement docElem = m_categories.at(0).toElement();
+
+    QDomNode n = docElem.firstChildElement();
+    while(!n.isNull())
+    {
+        QDomElement e = n.toElement();
+        qDebug() << e.tagName();
+        n = n.nextSiblingElement();
+    }*/
+    
+    performQuery();
+}
 
 
 //END TMWindow
