@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -402,10 +402,10 @@ void TMView::slotSuggestionsCame(ThreadWeaver::Job* j)
 
 
     //BEGIN query other DBs handling
-    Project* p=Project::instance();
-    const QString& pID=p->projectID();
+    Project* project=Project::instance();
+    const QString& projectID=project->projectID();
     //check if this is an additional query, from secondary DBs
-    if (job.m_dbName!=pID)
+    if (job.m_dbName!=projectID)
     {
         job.m_entries+=m_entries;
         qSort(job.m_entries.begin(), job.m_entries.end(), qGreater<TMEntry>());
@@ -417,16 +417,16 @@ void TMView::slotSuggestionsCame(ThreadWeaver::Job* j)
     else if (job.m_entries.isEmpty()||job.m_entries.first().score<8500)
     {
         //be careful, as we switched to QDirModel!
-        const DBFilesModel& model=*(DBFilesModel::instance());
-        QModelIndex root=model.rootIndex();
-        int i=model.rowCount(root);
-        kWarning()<<"query other DBs,"<<i<<"total";
+        const DBFilesModel& dbFilesModel=*(DBFilesModel::instance());
+        QModelIndex root=dbFilesModel.rootIndex();
+        int i=dbFilesModel.rowCount(root);
+        //kWarning()<<"query other DBs,"<<i<<"total";
         while (--i>=0)
         {
-            const QString& db=model.data(model.index(i,0,root)).toString();
-            if (pID!=db)
+            const QString& dbName=dbFilesModel.data(dbFilesModel.index(i,0,root)).toString();
+            if (projectID!=dbName && dbFilesModel.m_configurations.value(dbName).targetLangCode==catalog.targetLangCode())
             {
-                SelectJob* j=initSelectJob(m_catalog, m_pos, db);
+                SelectJob* j=initSelectJob(m_catalog, m_pos, dbName);
                 connect(j,SIGNAL(done(ThreadWeaver::Job*)),this,SLOT(slotSuggestionsCame(ThreadWeaver::Job*)));
                 m_jobs.append(j);
             }
@@ -545,24 +545,28 @@ void TMView::slotSuggestionsCame(ThreadWeaver::Job* j)
 /*
 void TMView::slotPaletteChanged()
 {
-    
+
 }*/
 bool TMView::event(QEvent *event)
 {
     if (event->type()==QEvent::ToolTip)
     {
         QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
-        int block1=m_browser->cursorForPosition(m_browser->viewport()->mapFromGlobal(helpEvent->globalPos())).blockNumber();
-        int block=*m_entryPositions.lowerBound(m_browser->cursorForPosition(m_browser->viewport()->mapFromGlobal(helpEvent->globalPos())).anchor());
-        if (block1!=block)
-            kWarning()<<"block numbers don't match";
-        if (block<m_entries.size())
+        //int block1=m_browser->cursorForPosition(m_browser->viewport()->mapFromGlobal(helpEvent->globalPos())).blockNumber();
+        QMap<int,int>::const_iterator block=m_entryPositions.lowerBound(m_browser->cursorForPosition(m_browser->viewport()->mapFromGlobal(helpEvent->globalPos())).anchor());
+        if (block!=m_entryPositions.constEnd() && *block<m_entries.size())
         {
-            QString file=m_entries.at(block).file;
+            const TMEntry& tmEntry=m_entries.at(*block);
+            QString file=tmEntry.file;
             if (file==m_catalog->url().toLocalFile())
                 file=i18nc("File argument in tooltip, when file is current file", "this");
-            QString tooltip=i18nc("@info:tooltip","File: %1<br />Date: %2",file,m_entries.at(block).date);
-            if (m_entries.at(block).obsolete)
+            QString tooltip=i18nc("@info:tooltip","File: %1<br />Addition date: %2",file, tmEntry.date.toString(Qt::ISODate));
+            if (!tmEntry.changeDate.isNull() && tmEntry.changeDate!=tmEntry.date)
+                tooltip+=i18nc("@info:tooltip on TM entry continues","<br />Last change date: %1", tmEntry.changeDate.toString(Qt::ISODate));
+            if (!tmEntry.changeAuthor.isEmpty())
+                tooltip+=i18nc("@info:tooltip on TM entry continues","<br />Last change author: %1", tmEntry.changeAuthor);
+            tooltip+=i18nc("@info:tooltip on TM entry continues","<br />TM: %1", tmEntry.dbName);
+            if (tmEntry.obsolete)
                 tooltip+=i18nc("@info:tooltip on TM entry continues","<br />Is not present in the file anymore");
             QToolTip::showText(helpEvent->globalPos(),tooltip);
             return true;
@@ -588,7 +592,8 @@ void TMView::contextMenu(const QPoint& pos)
     if (!r)
         return;
     if ((r->data().toInt()==Remove) &&
-        KMessageBox::Yes==KMessageBox::questionYesNo(this, i18n("Do you really want to remove this entry from translation memory?"),i18nc("@title:window","Translation Memory Entry Removal")))
+        KMessageBox::Yes==KMessageBox::questionYesNo(this, i18n("<html>Do you really want to remove this entry:<br/><i>%1</i><br/>from translation memory %2?</html>",  Qt::escape(e.target.string), e.dbName),
+                                                           i18nc("@title:window","Translation Memory Entry Removal")))
     {
         RemoveJob* job=new RemoveJob(e);
         connect(job,SIGNAL(done(ThreadWeaver::Job*)),job,SLOT(deleteLater()));
@@ -914,7 +919,7 @@ nono
 //         }
 
         //this is for the case when +'s preceed -'s:
-        while ((--startPos>=0) 
+        while ((--startPos>=0)
                   &&(d.diffIndex.at(startPos)=='+')
                   //&&(-1!=nextPlacableIn(QString(d.diffClean.at(d.old2DiffClean.at(pos))),0,_))
               )
