@@ -34,6 +34,7 @@
 
 #include <kcompletionbox.h>
 
+#include <QStringBuilder>
 #include <QPixmap>
 #include <QPushButton>
 #include <QPainter>
@@ -142,6 +143,7 @@ void XliffTextEditSpellInterface::setSpellCheckingEnabled(bool enable)
 TranslationUnitTextEdit::TranslationUnitTextEdit(Catalog* catalog, DocPosition::Part part, QWidget* parent)
     : KTextEdit(parent)
     , m_currentUnicodeNumber(0)
+    , m_langUsesSpaces(true)
     , m_catalog(catalog)
     , m_part(part)
     , m_highlighter(new SyntaxHighlighter(this))
@@ -166,18 +168,29 @@ TranslationUnitTextEdit::TranslationUnitTextEdit(Catalog* catalog, DocPosition::
 void TranslationUnitTextEdit::fileLoaded()
 {
     QString langCode=m_part==DocPosition::Source? m_catalog->sourceLangCode():m_catalog->targetLangCode();
-    m_highlighter->setCurrentLanguage(langCode);
+
+    QLocale langLocale(langCode);
+    m_highlighter->setCurrentLanguage(langLocale.name());
 
     //"i use an english locale while translating kde pot files from english to hebrew" Bug #181989
-    QLocale langLocale(langCode);
     Qt::LayoutDirection targetLanguageDirection=Qt::LeftToRight;
-    QLocale::Language rtlLanguages[]={QLocale::Arabic, QLocale::Hebrew, QLocale::Urdu, QLocale::Persian, QLocale::Pashto};
-    int i=sizeof (rtlLanguages);
+    static QLocale::Language rtlLanguages[]={QLocale::Arabic, QLocale::Hebrew, QLocale::Urdu, QLocale::Persian, QLocale::Pashto};
+    int i=sizeof(rtlLanguages)/sizeof(QLocale::Arabic);
     while (--i>=0 && langLocale.language()!=rtlLanguages[i])
         ;
     if (i!=-1)
         targetLanguageDirection=Qt::RightToLeft;
     setLayoutDirection(targetLanguageDirection);
+
+    if (m_part==DocPosition::Source)
+        return;
+
+    //"Some language do not need space between words. For example Chinese."
+    static QLocale::Language noSpaceLanguages[]={QLocale::Chinese};
+    i=sizeof(noSpaceLanguages)/sizeof(QLocale::Chinese);
+    while (--i>=0 && langLocale.language()!=noSpaceLanguages[i])
+        ;
+    m_langUsesSpaces=(i==-1);
 }
 
 void TranslationUnitTextEdit::reflectApprovementState()
@@ -435,6 +448,15 @@ void TranslationUnitTextEdit::contentsChanged(int offset, int charsRemoved, int
         return;
     }
 
+    //ktextedit spellcheck handling:
+    if (charsRemoved==0 && editText.isEmpty() && _oldMsgstr.length())
+        charsRemoved=_oldMsgstr.length();
+    if (charsAdded && editText.isEmpty())
+        charsAdded=0;
+    if (charsRemoved && _oldMsgstr.isEmpty())
+        charsRemoved=0;
+
+
     DocPosition pos=m_currentPos;
     pos.offset=offset;
     //kWarning()<<"offset"<<offset<<"charsRemoved"<<charsRemoved<<"_oldMsgstr"<<_oldMsgstr;
@@ -509,7 +531,7 @@ void TranslationUnitTextEdit::contentsChanged(int offset, int charsRemoved, int
 
     if (charsAdded==1)
     {
-        int sp=target.lastIndexOf(CompletionStorage::instance()->rxSplit,offset);
+        int sp=target.lastIndexOf(CompletionStorage::instance()->rxSplit,offset-1);
         int len=(offset-sp);
         int wordCompletionLength=Settings::self()->wordCompletionLength();
         if (wordCompletionLength>=3 && len>=wordCompletionLength)
@@ -800,7 +822,8 @@ void TranslationUnitTextEdit::keyPressEvent(QKeyEvent *keyEvent)
         }
         else if(!(keyEvent->modifiers()&Qt::ControlModifier))
         {
-            if(pos>0
+            if(m_langUsesSpaces
+               &&pos>0
                &&!str.isEmpty()
                &&!str.at(pos-1).isSpace())
             {
@@ -922,7 +945,7 @@ void TranslationUnitTextEdit::insertTag(InlineTag tag)
     setFocus();
 }
 
-int TranslationUnitTextEdit::strForMicePosIfUnderTag(QPoint mice, CatalogString& str)
+int TranslationUnitTextEdit::strForMicePosIfUnderTag(QPoint mice, CatalogString& str, bool tryHarder)
 {
     QTextCursor cursor=cursorForPosition(mice);
     int pos=cursor.position();
@@ -940,13 +963,9 @@ int TranslationUnitTextEdit::strForMicePosIfUnderTag(QPoint mice, CatalogString&
 
     if (str.string.at(pos)!=TAGRANGE_IMAGE_SYMBOL)
     {
-//         //try harder
-//         if (--pos>=0 && str.string.at(pos)==TAGRANGE_IMAGE_SYMBOL)
-//         {
-//
-//         }
-
-        return -1;
+        bool cont=tryHarder && --pos>=0 && str.string.at(pos)==TAGRANGE_IMAGE_SYMBOL;
+        if (!cont)
+            return -1;
     }
 
     int result=str.tags.size();
@@ -1099,13 +1118,22 @@ bool TranslationUnitTextEdit::event(QEvent *event)
     {
         QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
         CatalogString str;
-        int pos=strForMicePosIfUnderTag(helpEvent->pos(),str);
+        int pos=strForMicePosIfUnderTag(helpEvent->pos(),str,true);
         if (pos!=-1)
         {
             QString tooltip=str.tags.at(pos).displayName();
             QToolTip::showText(helpEvent->globalPos(),tooltip);
             return true;
         }
+
+        QString langCode=m_highlighter->currentLanguage();
+        bool nospell=langCode.isEmpty();
+        if (nospell)
+            langCode=m_part==DocPosition::Source?m_catalog->sourceLangCode():m_catalog->targetLangCode();
+        QString tip=KGlobal::locale()->languageCodeToName(langCode)%" ("%langCode%")";
+        if (nospell)
+            tip+=" - "%i18n("no spellcheck available");
+        QToolTip::showText(helpEvent->globalPos(), tip);
     }
     return KTextEdit::event(event);
 }
@@ -1236,7 +1264,6 @@ void TranslationUnitTextEdit::source2target()
 
     else {
         m_catalog->beginMacro(i18nc("@item Undo action item","Copy source to target"));
-        DocPosition pos=m_currentPos;pos.offset=0;
         removeTargetSubstring(0,-1,/*refresh*/false);
         insertCatalogString(sourceWithTags,0,/*refresh*/false);
         m_catalog->endMacro();
