@@ -28,8 +28,8 @@
 
 // Program
 static const char ProgramId[] =          "okteta";
-static const char ProgramVersion[] =     "0.8.3";
-static const char ProgramHomepage[] =    "http://utils.kde.org/projects/okteta";
+static const char ProgramVersion[] =     "0.8.5";
+static const char ProgramHomepage[] =    "http://userbase.kde.org/Okteta";
 // Author
 static const char FWHKEmailAddress[] =   "kossebau@kde.org";
 static const char AREmailAddress[] =     "alex.richardson@gmx.de";
