@@ -18,6 +18,7 @@ options = OpenStruct.new
 options.help  = false
 options.https = false
 options.ask   = true
+options.translations = true
 
 opts = OptionParser.new do |opts|
   opts.on("-u", "--user USERNAME", "svn account") do |u|
@@ -42,6 +43,9 @@ opts = OptionParser.new do |opts|
   opts.on("-r", "--revision REV", "Use a specific revision of the repository") do |r|
     options.rev = r
   end
+  opts.on("-t", "--no-translations", "Don't include translations") do |t|
+    options.translations = false
+  end
 end
 
 begin
@@ -91,7 +95,6 @@ end
 
 ############# START #############
 
-svnroot    = "#{svnbase}/trunk"
 kde_version  = `svn ls svn://anonsvn.kde.org/home/kde/tags/KDE | sort | tail -n1 | cut -d "/" -f1`.chomp
 #kde_version = '4.0.4'
 
@@ -199,24 +202,36 @@ apps.each do |app|
     if appdata["addPo"] && appdata["addPo"].length > 0
         temp = { "addPo" =>  (appdata["addPo"]+" "+app).split(" ") }
     else
-        temp = { "addPo" =>  app }
+        temp = { "addPo" =>  [app] }
     end
     appdata = appdata.merge(temp)
 
     if appdata["addDocs"] && appdata["addDocs"].length > 0
         temp = { "addDocs" =>  (appdata["addDocs"]+" "+app).split(" ") }
     else
-        temp = { "addDocs" =>  app }
+        temp = { "addDocs" =>  [app] }
     end
     appdata = appdata.merge(temp)
 
+    tmpl10nmodule = appdata["l10nmodule"]
+
     if appdata["submodule"] && appdata["submodule"].length > 0
-        temp = { "submodulepath" => appdata["submodule"] + "/", "l10nmodule" => appdata["mainmodule"] + "-" + appdata["submodule"] }
+        if appdata["mainmodule"] == "extragear" || appdata["mainmodule"] == "playground" 
+          temp = { "submodulepath" => appdata["submodule"] + "/", "l10nmodule" => appdata["mainmodule"] + "-" + appdata["submodule"] }
+        else
+          temp = { "submodulepath" => appdata["submodule"] + "/", "l10nmodule" => appdata["submodule"] }
+        end
     else
         temp = { "submodulepath" => "", "l10nmodule" => appdata["mainmodule"] }
     end
     appdata = appdata.merge(temp)
 
+    # if l10nmodule is specified in the config file, then use it
+    if tmpl10nmodule
+      temp = { "l10nmodule" => tmpl10nmodule }
+      appdata = appdata.merge(temp)
+    end
+
     if !appdata["customlang"]
         temp = { "customlang" => [] }
     end
@@ -230,36 +245,66 @@ apps.each do |app|
       revString = " Rev " + options.rev
     end
 
-    puts "-> Fetching " + appdata["mainmodule"] + "/" + appdata["submodulepath"] + app + revString + " into " + appdata["folder"] + "..."
+    if appdata["gitModule"]
+        if !appdata["gitTag"]
+            temp = { "gitTag" => "HEAD" }
+            appdata = appdata.merge(temp)
+        end
+        puts "-> Fetching git://anongit.kde.org/" + app + ".git " +  appdata["gitTag"] + " into " + appdata["folder"] + "..."
+    else
+        puts "-> Fetching " + appdata["mainmodule"] + "/" + appdata["submodulepath"] + app + revString + " into " + appdata["folder"] + "..."
+    end
     # Remove old folder, if exists
     `rm -rf #{appdata["folder"]} 2> /dev/null`
     `rm -rf #{appdata["folder"]}.tar.bz2 2> /dev/null`
     Dir.mkdir( appdata["folder"] )
     Dir.chdir( appdata["folder"] )
 
-    # Do the main checkouts.
-    if appdata["wholeModule"]
-        `svn co #{svnroot}/#{appdata["mainmodule"]}/#{appdata["submodulepath"]} #{rev} #{app}-tmp`
+    if appdata["mainmodule"][0,5] == "trunk" || appdata["mainmodule"][0,8] == "branches" 
+        svnroot = "#{svnbase}/"
     else
-        `svn co #{svnroot}/#{appdata["mainmodule"]}/#{appdata["submodulepath"]}#{app} #{rev} #{app}-tmp`
-    end
-    Dir.chdir( app + "-tmp" )
-
-    if appdata["docs"] != "no"
-        `svn co #{svnroot}/#{appdata["mainmodule"]}/#{appdata["submodulepath"]}doc/#{app} #{rev} doc`
+        #trunk is assumed for all mainmodules that don't start with "trunk" or "branches"
+	svnroot = "#{svnbase}/trunk/"
     end
 
-    # Move them to the toplevel
-    `/bin/mv * ..`
-    Dir.chdir( ".." )
+    if !appdata["l10npath"]
+        temp = { "l10npath" => "." }
+        appdata = appdata.merge(temp)
+    end
 
-    `find -name ".svn" | xargs rm -rf`
-    `rm -rf #{app}-tmp`
+    # Do the main checkouts.
+    if appdata["gitModule"]
+        `mkdir #{app}`
+        `git archive --remote git://anongit.kde.org/#{app}.git #{appdata["gitTag"]} | tar -x`
+    else
+        if appdata["wholeModule"]
+            `svn co #{svnroot}/#{appdata["mainmodule"]}/#{appdata["submodulepath"]} #{rev} #{app}-tmp`
+        else
+            `svn co #{svnroot}/#{appdata["mainmodule"]}/#{appdata["submodulepath"]}#{app} #{rev} #{app}-tmp`
+        end
+        Dir.chdir( app + "-tmp" )
 
-    if appdata["translations"] != "no"
+        if appdata["docs"] != "no"
+            if !appdata["docpath"]
+                temp = { "docpath" => "doc/#{app}" }
+                appdata = appdata.merge(temp)
+            end
+            `svn co #{svnroot}/#{appdata["mainmodule"]}/#{appdata["submodulepath"]}/#{appdata["docpath"]} #{rev} doc`
+        end
+
+        # Move them to the toplevel
+        `/bin/mv * ..`
+        Dir.chdir( ".." )
+
+        `find -name ".svn" | xargs rm -rf`
+        `rm -rf #{app}-tmp`
+    end
+
+    # translations
+    if appdata["translations"] != "no" && options.translations
         puts "-> Fetching l10n docs for #{appdata["submodulepath"]}#{app} #{revString}..."
 
-        i18nlangs = `svn cat #{svnroot}/l10n-kde4/subdirs #{rev}`.split
+        i18nlangs = `svn cat #{svnroot}/#{appdata["l10npath"]}/l10n-kde4/subdirs #{rev}`.split
         i18nlangsCleaned = []
         for lang in i18nlangs
             l = lang.chomp
@@ -279,10 +324,10 @@ apps.each do |app|
         for lang in i18nlangs
             lang.chomp!
 
-            for dg in appdata["addDocs"].split
+            for dg in appdata["addDocs"]
                 dg.chomp!
                 `rm -rf #{dg}`
-                docdirname = "l10n-kde4/#{lang}/docs/#{appdata["l10nmodule"]}/#{dg}"
+                docdirname = "#{appdata["l10npath"]}/l10n-kde4/#{lang}/docs/#{appdata["l10nmodule"]}/#{dg}"
                 if ( appdata["docs"] != "no" )
                     puts "  -> Checking if #{lang} has translated documentation...\n"
                     `svn co -q #{rev} #{svnroot}/#{docdirname} > /dev/null 2>&1`
@@ -332,11 +377,11 @@ apps.each do |app|
             lang.chomp!
             dest = "po/#{lang}"
 
-            for dg in appdata["addPo"].split
+            for dg in appdata["addPo"]
                 dg.chomp!
                 if appdata["wholeModule"]
                     print "  -> Copying #{lang}'s over ..\n"
-                    pofolder = "l10n-kde4/#{lang}/messages/#{appdata["l10nmodule"]}"
+                    pofolder = "#{appdata["l10npath"]}/l10n-kde4/#{lang}/messages/#{appdata["l10nmodule"]}"
                     `svn co #{svnroot}/#{pofolder} #{dest}`
                     if FileTest.exist?( dest )
                       topmakefile << "add_subdirectory( #{lang} )\n"
@@ -346,7 +391,7 @@ apps.each do |app|
                 elsif appdata["custompo"]
 		                valid = false
                     for sp in appdata["custompo"].split(/,/)
-		    	              pofilename = "l10n-kde4/#{lang}/messages/#{appdata["l10nmodule"]}/#{sp}.po"
+		    	              pofilename = "#{appdata["l10npath"]}/l10n-kde4/#{lang}/messages/#{appdata["l10nmodule"]}/#{sp}.po"
                     	  `svn cat #{svnroot}/#{pofilename} #{rev} 2> /dev/null | tee l10n/#{sp}.po`
                     	  if not FileTest.size( "l10n/#{sp}.po" ) == 0
 	   		                valid=true
@@ -360,7 +405,7 @@ apps.each do |app|
                 end
 		            next if not valid
                 else
-                    pofilename = "l10n-kde4/#{lang}/messages/#{appdata["l10nmodule"]}/#{dg}.po"
+                    pofilename = "#{appdata["l10npath"]}/l10n-kde4/#{lang}/messages/#{appdata["l10nmodule"]}/#{dg}.po"
                     `svn cat #{svnroot}/#{pofilename} #{rev} 2> /dev/null | tee l10n/#{dg}.po`
                     next if FileTest.size( "l10n/#{dg}.po" ) == 0
                     
@@ -390,10 +435,14 @@ apps.each do |app|
         `echo "add_subdirectory( po )" >> CMakeLists.txt`
         if appdata["docs"] != "no"
             `echo "add_subdirectory( doc-translations )" >> CMakeLists.txt`
-            `echo "add_subdirectory( doc )" >> CMakeLists.txt`
         end
     end
 
+    # add doc generation to compilation
+    if (appdata["docs"] != "no") && (!appdata["gitModule"])
+        `echo "add_subdirectory( doc )" >> CMakeLists.txt`
+    end
+
     # Remove cruft 
     `find -name ".svn" | xargs rm -rf`
     if ( appdata["remove"] != "")
@@ -402,7 +451,7 @@ apps.each do |app|
 
     print "-> Compressing ..  "
     Dir.chdir( ".." ) # root folder
-    `tar -jcf #{appdata["folder"]}.tar.bz2 #{appdata["folder"]}`
+    `tar -jcf #{appdata["folder"]}.tar.bz2 --group=root --owner=root  #{appdata["folder"]}`
     #`rm -rf #{appdata["folder"]}`
     puts " done."
 end 
