@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2009                                               *
+ *   copyright (C) 2003-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -12,6 +12,7 @@
 #include "association.h"
 
 // app includes
+#include "debug_utils.h"
 #include "classifier.h"
 #include "folder.h"
 #include "uml.h"
@@ -22,7 +23,6 @@
 #include "cmds.h"
 
 // kde includes
-#include <kdebug.h>
 #include <klocale.h>
 
 // qt includes
@@ -30,42 +30,14 @@
 
 using namespace Uml;
 
-// static members
-const Uml::Association_Type UMLAssociation::atypeFirst = Uml::at_Generalization;
-const Uml::Association_Type UMLAssociation::atypeLast = Uml::at_Relationship;
-const unsigned UMLAssociation::nAssocTypes = (unsigned)atypeLast - (unsigned)atypeFirst + 1;
-const QString UMLAssociation::assocTypeStr[UMLAssociation::nAssocTypes] = {
-            // Elements must be listed in the same order as in the Uml::Association_Type.
-            i18n("Generalization"),             // at_Generalization
-            i18n("Aggregation"),                // at_Aggregation
-            i18n("Dependency"),                 // at_Dependency
-            i18n("Association"),                // at_Association
-            i18n("Self Association"),           // at_Association_Self
-            i18n("Collaboration Message"),      // at_Coll_Message
-            i18n("Sequence Message"),           // at_Seq_Message
-            i18n("Collaboration Self Message"), // at_Coll_Message_Self
-            i18n("Sequence Self Message"),      // at_Seq_Message_Self
-            i18n("Containment"),                // at_Containment
-            i18n("Composition"),                // at_Composition
-            i18n("Realization"),                // at_Realization
-            i18n("Uni Association"),            // at_UniAssociation
-            i18n("Anchor"),                     // at_Anchor
-            i18n("State Transition"),           // at_State
-            i18n("Activity"),                   // at_Activity
-            i18n("Exception"),                  // at_Activity
-            i18n("Category to Parent"),         // at_Category2Parent
-            i18n("Child to Category"),          // at_Child2Category
-            i18n("Relationship" )               // at_Relationship
-        };
-
 /**
  * Sets up an association.
  * A new unique ID is assigned internally.
- * @param type    The Uml::Association_Type to construct.
+ * @param type    The AssociationType to construct.
  * @param roleA   Pointer to the UMLObject in role A.
  * @param roleB   Pointer to the UMLObject in role B.
  */
-UMLAssociation::UMLAssociation( Uml::Association_Type type,
+UMLAssociation::UMLAssociation( Uml::AssociationType type,
                                 UMLObject * roleA, UMLObject * roleB )
   : UMLObject("")
 {
@@ -79,10 +51,10 @@ UMLAssociation::UMLAssociation( Uml::Association_Type type,
  * Constructs an association - for loading only.
  * This constructor should not normally be used as it constructs
  * an incomplete association (i.e. the role objects are missing.)
- * @param type   The Uml::Association_Type to construct.
- *               Default: Uml::at_Unknown.
+ * @param type   The AssociationType to construct.
+ *               Default: Unknown.
  */
-UMLAssociation::UMLAssociation( Uml::Association_Type type)
+UMLAssociation::UMLAssociation( Uml::AssociationType type)
   : UMLObject("", Uml::id_Reserved)
 {
     init(type, NULL, NULL);
@@ -110,7 +82,7 @@ UMLAssociation::~UMLAssociation( )
 /**
  * Overloaded '==' operator
  */
-bool UMLAssociation::operator==(const UMLAssociation &rhs)
+bool UMLAssociation::operator==(const UMLAssociation &rhs) const
 {
     if (this == &rhs) {
         return true;
@@ -123,10 +95,10 @@ bool UMLAssociation::operator==(const UMLAssociation &rhs)
 }
 
 /**
- * Returns the Association_Type of the UMLAssociation.
- * @return  The Association_Type of the UMLAssociation.
+ * Returns the AssociationType of the UMLAssociation.
+ * @return  The AssociationType of the UMLAssociation.
  */
-Uml::Association_Type UMLAssociation::getAssocType() const
+Uml::AssociationType UMLAssociation::getAssocType() const
 {
     return m_AssocType;
 }
@@ -139,52 +111,20 @@ QString UMLAssociation::toString() const
     QString string;
     if(m_pRole[A])
     {
-        string += m_pRole[A]->getObject()->getName();
+        string += m_pRole[A]->object()->name();
         string += ':';
-        string += m_pRole[A]->getName();
+        string += m_pRole[A]->name();
     }
-    string += ':' + toString(m_AssocType) + ':';
+    string += ':' + m_AssocType.toStringI18n() + ':';
     if(m_pRole[B])
     {
-        string += m_pRole[B]->getObject( )->getName();
+        string += m_pRole[B]->object( )->name();
         string += ':';
-        string += m_pRole[B]->getName();
+        string += m_pRole[B]->name();
     }
     return string;
 }
 
-/**
- * Converts a Uml::Association_Type to its string representation.
- *
- * @param atype   The Association_Type enum value to convert.
- * @return  The string representation of the Association_Type.
- */
-QString UMLAssociation::toString (Uml::Association_Type atype)
-{
-    if (atype < atypeFirst || atype > atypeLast)
-        return QString();
-    return assocTypeStr[(unsigned)atype - (unsigned)atypeFirst];
-}
-
-/**
- * Returns true if the given Association_Type has a representation as a
- * UMLAssociation.
- */
-bool UMLAssociation::assocTypeHasUMLRepresentation(Uml::Association_Type atype)
-{
-    return (atype == Uml::at_Generalization ||
-            atype == Uml::at_Realization ||
-            atype == Uml::at_Association ||
-            atype == Uml::at_Association_Self ||
-            atype == Uml::at_UniAssociation ||
-            atype == Uml::at_Aggregation ||
-            atype == Uml::at_Relationship ||
-            atype == Uml::at_Composition ||
-            atype == Uml::at_Dependency ||
-            atype == Uml::at_Category2Parent ||
-            atype == Uml::at_Child2Category);
-}
-
 /**
  * Resolve types. Required when dealing with foreign XMI files.
  * Needs to be called after all UML objects are loaded from file.
@@ -197,11 +137,11 @@ bool UMLAssociation::resolveRef()
     bool successA = getUMLRole(A)->resolveRef();
     bool successB = getUMLRole(B)->resolveRef();
     if (successA && successB) {
-        UMLObject *objA = getUMLRole(A)->getObject();
-        UMLObject *objB = getUMLRole(B)->getObject();
+        UMLObject *objA = getUMLRole(A)->object();
+        UMLObject *objB = getUMLRole(B)->object();
         // Check if need to change the assoc type to Realization
         if (isRealization(objA, objB)) {
-            m_AssocType = Uml::at_Realization;
+            m_AssocType = Uml::AssociationType::Realization;
         }
         m_pUMLPackage->addAssocToConcepts(this);
         return true;
@@ -215,7 +155,7 @@ bool UMLAssociation::resolveRef()
  */
 void UMLAssociation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
 {
-    if (m_AssocType == Uml::at_Generalization) {
+    if (m_AssocType == Uml::AssociationType::Generalization) {
         QDomElement assocElement = UMLObject::save("UML:Generalization", qDoc);
         assocElement.setAttribute( "discriminator", "" );
         assocElement.setAttribute( "child", ID2STR(getObjectId(A)) );
@@ -223,28 +163,28 @@ void UMLAssociation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
         qElement.appendChild( assocElement );
         return;
     }
-    if (m_AssocType == Uml::at_Realization) {
+    if (m_AssocType == Uml::AssociationType::Realization) {
         QDomElement assocElement = UMLObject::save("UML:Abstraction", qDoc);
         assocElement.setAttribute( "client", ID2STR(getObjectId(A)) );
         assocElement.setAttribute( "supplier", ID2STR(getObjectId(B)) );
         qElement.appendChild( assocElement );
         return;
     }
-    if (m_AssocType == Uml::at_Dependency) {
+    if (m_AssocType == Uml::AssociationType::Dependency) {
         QDomElement assocElement = UMLObject::save("UML:Dependency", qDoc);
         assocElement.setAttribute( "client", ID2STR(getObjectId(A)) );
         assocElement.setAttribute( "supplier", ID2STR(getObjectId(B)) );
         qElement.appendChild( assocElement );
         return;
     }
-    if (m_AssocType == Uml::at_Child2Category ) {
+    if (m_AssocType == Uml::AssociationType::Child2Category ) {
         QDomElement assocElement = UMLObject::save("UML:Child2Category", qDoc);
         assocElement.setAttribute( "client", ID2STR(getObjectId(A)) );
         assocElement.setAttribute( "supplier", ID2STR(getObjectId(B)) );
         qElement.appendChild( assocElement );
         return;
     }
-    if (m_AssocType == Uml::at_Category2Parent ) {
+    if (m_AssocType == Uml::AssociationType::Category2Parent ) {
         QDomElement assocElement = UMLObject::save("UML:Category2Parent", qDoc);
         assocElement.setAttribute( "client", ID2STR(getObjectId(A)) );
         assocElement.setAttribute( "supplier", ID2STR(getObjectId(B)) );
@@ -266,19 +206,19 @@ void UMLAssociation::saveToXMI( QDomDocument & qDoc, QDomElement & qElement )
  */
 bool UMLAssociation::load( QDomElement & element )
 {
-    if (getID() == Uml::id_None)
+    if (id() == Uml::id_None)
         return false; // old style XMI file. No real info in this association.
 
-    UMLDoc * doc = UMLApp::app()->getDocument();
+    UMLDoc * doc = UMLApp::app()->document();
     UMLObject * obj[2] = { NULL, NULL };
-    if (m_AssocType == Uml::at_Generalization ||
-        m_AssocType == Uml::at_Realization    ||
-        m_AssocType == Uml::at_Dependency     ||
-        m_AssocType == Uml::at_Child2Category ||
-        m_AssocType == Uml::at_Category2Parent
+    if (m_AssocType == Uml::AssociationType::Generalization ||
+        m_AssocType == Uml::AssociationType::Realization    ||
+        m_AssocType == Uml::AssociationType::Dependency     ||
+        m_AssocType == Uml::AssociationType::Child2Category ||
+        m_AssocType == Uml::AssociationType::Category2Parent
         ) {
         for (unsigned r = Uml::A; r <= Uml::B; ++r) {
-            const QString fetch = (m_AssocType == Uml::at_Generalization ?
+            const QString fetch = (m_AssocType == Uml::AssociationType::Generalization ?
                                    r == Uml::A ? "child" : "parent"
                        : r == Uml::A ? "client" : "supplier");
             QString roleIdStr = element.attribute(fetch, "");
@@ -295,8 +235,8 @@ bool UMLAssociation::load( QDomElement & element )
             } else {
                 m_pRole[role]->setObject(obj[r]);
                 if (m_pUMLPackage == NULL) {
-                    Uml::Model_Type mt = Model_Utils::convert_OT_MT(obj[r]->getBaseType());
-                    m_pUMLPackage = doc->getRootFolder(mt);
+                    Uml::ModelType mt = Model_Utils::convert_OT_MT(obj[r]->baseType());
+                    m_pUMLPackage = doc->rootFolder(mt);
                     uDebug() << "assoctype " << m_AssocType
                         << ": setting model type " << mt;
                 }
@@ -326,13 +266,13 @@ bool UMLAssociation::load( QDomElement & element )
                 }
                 if (idStr.isEmpty()) {
                     uError() << "type " << m_AssocType
-                        << ", id " << ID2STR(getID()) << ": "
+                        << ", id " << ID2STR(id()) << ": "
                         << "xmi id not given for " << tag;
                     continue;
                 }
                 // Since we know for sure that we're dealing with a non
                 // umbrello file, use deferred resolution unconditionally.
-                if (tagEq(tag, "child") || tagEq(tag, "subtype") || tagEq(tag, "client")) {
+                if (UMLDoc::tagEq(tag, "child") || UMLDoc::tagEq(tag, "subtype") || UMLDoc::tagEq(tag, "client")) {
                     getUMLRole(A)->setSecondaryId(idStr);
                 } else {
                     getUMLRole(B)->setSecondaryId(idStr);
@@ -342,7 +282,7 @@ bool UMLAssociation::load( QDomElement & element )
 
         // it is a realization if either endpoint is an interface
         if (isRealization(obj[A], obj[B])) {
-            m_AssocType = Uml::at_Realization;
+            m_AssocType = Uml::AssociationType::Realization;
         }
         return true;
     }
@@ -356,41 +296,41 @@ bool UMLAssociation::load( QDomElement & element )
         QString tag = tempElement.tagName();
         if (Model_Utils::isCommonXMIAttribute(tag))
             continue;
-        if (!tagEq(tag, "Association.connection") &&
-                !tagEq(tag, "Namespace.ownedElement") &&
-                !tagEq(tag, "Namespace.contents")) {
+        if (!UMLDoc::tagEq(tag, "Association.connection") &&
+                !UMLDoc::tagEq(tag, "Namespace.ownedElement") &&
+                !UMLDoc::tagEq(tag, "Namespace.contents")) {
             uWarning() << "unknown child node " << tag;
             continue;
         }
         // Load role A.
-        node = tempElement.firstChild();
-        while (node.isComment())
-            node = node.nextSibling();
-        tempElement = node.toElement();
+        QDomNode nodeA = tempElement.firstChild();
+        while (nodeA.isComment())
+            nodeA = nodeA.nextSibling();
+        tempElement = nodeA.toElement();
         if (tempElement.isNull()) {
             uWarning() << "UML:Association : element (A) is Null";
             return false;
         }
         tag = tempElement.tagName();
-        if (!tagEq(tag, "AssociationEndRole") &&
-                !tagEq(tag, "AssociationEnd")) {
+        if (!UMLDoc::tagEq(tag, "AssociationEndRole") &&
+                !UMLDoc::tagEq(tag, "AssociationEnd")) {
             uWarning() << "unknown child (A) tag " << tag;
             return false;
         }
         if (! getUMLRole(A)->loadFromXMI(tempElement))
             return false;
         // Load role B.
-        node = node.nextSibling();
-        while (node.isComment())
-            node = node.nextSibling();
-        tempElement = node.toElement();
+        QDomNode nodeB = nodeA.nextSibling();
+        while (nodeB.isComment())
+            nodeB = nodeB.nextSibling();
+        tempElement = nodeB.toElement();
         if (tempElement.isNull()) {
             uWarning() << "UML:Association : element (B) is Null";
             return false;
         }
         tag = tempElement.tagName();
-        if (!tagEq(tag, "AssociationEndRole") &&
-                !tagEq(tag, "AssociationEnd")) {
+        if (!UMLDoc::tagEq(tag, "AssociationEndRole") &&
+                !UMLDoc::tagEq(tag, "AssociationEnd")) {
             uWarning() << "unknown child (B) tag " << tag;
             return false;
         }
@@ -398,8 +338,8 @@ bool UMLAssociation::load( QDomElement & element )
             return false;
 
         if (m_pUMLPackage == NULL) {
-            Uml::Model_Type mt = Model_Utils::convert_OT_MT(getObject(B)->getBaseType());
-            m_pUMLPackage = doc->getRootFolder(mt);
+            Uml::ModelType mt = Model_Utils::convert_OT_MT(getObject(B)->baseType());
+            m_pUMLPackage = doc->rootFolder(mt);
             uDebug() << "setting model type " << mt;
         }
 
@@ -413,12 +353,12 @@ bool UMLAssociation::load( QDomElement & element )
         // is not complete, so we need to finish the analysis here.
 
         // find self-associations
-        if (m_AssocType == Uml::at_Association && getObjectId(A) == getObjectId(B))
-            m_AssocType = Uml::at_Association_Self;
+        if (m_AssocType == Uml::AssociationType::Association && getObjectId(A) == getObjectId(B))
+            m_AssocType = Uml::AssociationType::Association_Self;
 
         // fall-back default type
-        if (m_AssocType == Uml::at_Unknown) {
-            m_AssocType = Uml::at_Association;
+        if (m_AssocType == Uml::AssociationType::Unknown) {
+            m_AssocType = Uml::AssociationType::Association;
         }
 
         return true;
@@ -426,52 +366,56 @@ bool UMLAssociation::load( QDomElement & element )
 
     // From here on it's old-style stuff.
     QString assocTypeStr = element.attribute( "assoctype", "-1" );
-    Uml::Association_Type assocType = Uml::at_Unknown;
+    Uml::AssociationType assocType = Uml::AssociationType::Unknown;
     if (assocTypeStr[0] >= 'a' && assocTypeStr[0] <= 'z') {
         // In an earlier version, the natural assoctype names were saved.
-        const QString assocTypeString[nAssocTypes] = {
-                    "generalization",   // at_Generalization
-                    "aggregation",      // at_Aggregation
-                    "dependency",       // at_Dependency
-                    "association",      // at_Association
-                    "associationself",  // at_Association_Self
-                    "collmessage",      // at_Coll_Message
-                    "seqmessage",       // at_Seq_Message
-                    "collmessageself",  // at_Coll_Message_Self
-                    "seqmessageself",   // at_Seq_Message_Self
-                    "implementation",   // at_Implementation
-                    "composition",      // at_Composition
-                    "realization",      // at_Realization
-                    "uniassociation",   // at_UniAssociation
-                    "anchor",           // at_Anchor
-                    "state",            // at_State
-                    "activity",         // at_Activity
-                    "exception",        // at_Exception
-                    "category2parent"   // at_Category2Parent
-                    "child2category"    // at_Child2Category
-                    "relationship"      // at_Relationship
+        const QString assocTypeString[] = {
+                    "generalization",   // Uml::AssociationType::Generalization
+                    "aggregation",      // Uml::AssociationType::Aggregation
+                    "dependency",       // Uml::AssociationType::Dependency
+                    "association",      // Uml::AssociationType::Association
+                    "associationself",  // Uml::AssociationType::Association_Self
+                    "collmessage",      // Uml::AssociationType::Coll_Message
+                    "seqmessage",       // Uml::AssociationType::Seq_Message
+                    "collmessageself",  // Uml::AssociationType::Coll_Message_Self
+                    "seqmessageself",   // Uml::AssociationType::Seq_Message_Self
+                    "implementation",   // Uml::AssociationType::Implementation
+                    "composition",      // Uml::AssociationType::Composition
+                    "realization",      // Uml::AssociationType::Realization
+                    "uniassociation",   // Uml::AssociationType::UniAssociation
+                    "anchor",           // Uml::AssociationType::Anchor
+                    "state",            // Uml::AssociationType::State
+                    "activity",         // Uml::AssociationType::Activity
+                    "exception",        // Uml::AssociationType::Exception
+                    "category2parent"   // Uml::AssociationType::Category2Parent
+                    "child2category"    // Uml::AssociationType::Child2Category
+                    "relationship"      // Uml::AssociationType::Relationship
         };
+        const int arraySize = sizeof(assocTypeString)/sizeof(QString);
+        uDebug() << "AssociationType string array size = " << arraySize;
 
-        unsigned index;
-        for (index = 0; index < nAssocTypes; ++index)
+        int index;
+        for (index = 0; index < arraySize; ++index)
             if (assocTypeStr == assocTypeString[index])
                 break;
-        if (index < nAssocTypes)
-            assocType = (Uml::Association_Type)index;
+        if (index < arraySize)
+            assocType = Uml::AssociationType::Value(index);
     } else {
         int assocTypeNum = assocTypeStr.toInt();
-        if (assocTypeNum < (int)atypeFirst || assocTypeNum > (int)atypeLast) {
-            uWarning() << "bad assoctype of UML:Association " << ID2STR(getID());
+        if (assocTypeNum < (int)Uml::AssociationType::Generalization ||   // first enum
+            assocTypeNum > (int)Uml::AssociationType::Relationship) {     // last enum
+            uWarning() << "bad assoctype of UML:AssociationType " << ID2STR(id());
             return false;
         }
-        assocType = (Uml::Association_Type)assocTypeNum;
+        assocType = Uml::AssociationType::Value(assocTypeNum);
     }
-    setAssocType( assocType );
+    setAssociationType( assocType );
 
     Uml::IDType roleAObjID = STR2ID(element.attribute( "rolea", "-1" ));
     Uml::IDType roleBObjID = STR2ID(element.attribute( "roleb", "-1" ));
-    if (assocType == at_Aggregation || assocType == at_Composition) {
-        // Flip roles to compensate for changed diamond logic in LinePath.
+    if (assocType == Uml::AssociationType::Aggregation ||
+        assocType == Uml::AssociationType::Composition) {
+        // Flip roles to compensate for changed diamond logic in AssociationLine.
         // For further explanations see AssociationWidget::loadFromXMI.
         Uml::IDType tmp = roleAObjID;
         roleAObjID = roleBObjID;
@@ -516,9 +460,9 @@ bool UMLAssociation::load( QDomElement & element )
     QString changeabilityA = element.attribute( "changeabilitya", "0");
     QString changeabilityB = element.attribute( "changeabilityb", "0");
     if (changeabilityA.toInt() > 0)
-        setChangeability ( (Uml::Changeability_Type) changeabilityA.toInt(), A);
+        setChangeability(Uml::Changeability(Uml::Changeability::Value(changeabilityA.toInt())), A);
     if (changeabilityB.toInt() > 0)
-        setChangeability ( (Uml::Changeability_Type) changeabilityB.toInt(), B);
+        setChangeability(Uml::Changeability(Uml::Changeability::Value(changeabilityB.toInt())), B);
 
     return true;
 }
@@ -531,7 +475,7 @@ UMLObject* UMLAssociation::getObject(Uml::Role_Type role) const
 {
     if (m_pRole[role] == NULL)
         return NULL;
-    return m_pRole[role]->getObject();
+    return m_pRole[role]->object();
 }
 
 /**
@@ -542,9 +486,9 @@ UMLObject* UMLAssociation::getObject(Uml::Role_Type role) const
 Uml::IDType UMLAssociation::getObjectId(Uml::Role_Type role) const
 {
     UMLRole *roleObj = m_pRole[role];
-    UMLObject *o = roleObj->getObject();
+    UMLObject *o = roleObj->object();
     if (o == NULL) {
-        QString auxID = roleObj->getSecondaryId();
+        QString auxID = roleObj->secondaryId();
         if (auxID.isEmpty()) {
             uError() << "role " << role << ": getObject returns NULL";
             return Uml::id_None;
@@ -553,7 +497,7 @@ Uml::IDType UMLAssociation::getObjectId(Uml::Role_Type role) const
             return STR2ID(auxID);
         }
     }
-    return o->getID();
+    return o->id();
 }
 
 /**
@@ -563,15 +507,15 @@ Uml::IDType UMLAssociation::getObjectId(Uml::Role_Type role) const
  */
 Uml::IDType UMLAssociation::getRoleId(Role_Type role) const
 {
-    return m_pRole[role]->getID();
+    return m_pRole[role]->id();
 }
 
 /**
  * Returns the changeability.
  */
-Uml::Changeability_Type UMLAssociation::getChangeability(Uml::Role_Type role) const
+Uml::Changeability UMLAssociation::changeability(Uml::Role_Type role) const
 {
-    return m_pRole[role]->getChangeability();
+    return m_pRole[role]->changeability();
 }
 
 /**
@@ -580,7 +524,7 @@ Uml::Changeability_Type UMLAssociation::getChangeability(Uml::Role_Type role) co
  */
 Uml::Visibility UMLAssociation::getVisibility(Uml::Role_Type role) const
 {
-    return m_pRole[role]->getVisibility();
+    return m_pRole[role]->visibility();
 }
 
 /**
@@ -589,7 +533,7 @@ Uml::Visibility UMLAssociation::getVisibility(Uml::Role_Type role) const
  */
 QString UMLAssociation::getMulti(Uml::Role_Type role) const
 {
-    return m_pRole[role]->getMultiplicity();
+    return m_pRole[role]->multiplicity();
 }
 
 /**
@@ -598,7 +542,7 @@ QString UMLAssociation::getMulti(Uml::Role_Type role) const
  */
 QString UMLAssociation::getRoleName(Uml::Role_Type role) const
 {
-    return m_pRole[role]->getName();
+    return m_pRole[role]->name();
 }
 
 /**
@@ -607,7 +551,7 @@ QString UMLAssociation::getRoleName(Uml::Role_Type role) const
  */
 QString UMLAssociation::getRoleDoc(Uml::Role_Type role) const
 {
-    return m_pRole[role]->getDoc();
+    return m_pRole[role]->doc();
 }
 
 /**
@@ -638,12 +582,12 @@ bool UMLAssociation::getOldLoadMode() const
 
 /**
  * Sets the assocType of the UMLAssociation.
- * @param assocType The Association_Type of the UMLAssociation.
+ * @param assocType The AssociationType of the UMLAssociation.
  */
-void UMLAssociation::setAssocType(Uml::Association_Type assocType)
+void UMLAssociation::setAssociationType(Uml::AssociationType assocType)
 {
     m_AssocType = assocType;
-    if (m_AssocType == at_UniAssociation)
+    if (m_AssocType == Uml::AssociationType::UniAssociation)
     {
         // In this case we need to auto-set the multiplicity/rolenames
         // of the roles
@@ -679,7 +623,7 @@ void UMLAssociation::setVisibility(Uml::Visibility value, Uml::Role_Type role)
  * @param value     Changeability_Type of the given role.
  * @param role      The Uml::Role_Type to which the changeability is being set
  */
-void UMLAssociation::setChangeability(Uml::Changeability_Type value, Uml::Role_Type role)
+void UMLAssociation::setChangeability(Uml::Changeability value, Uml::Role_Type role)
 {
     m_pRole[role]->setChangeability(value);
 }
@@ -715,26 +659,6 @@ void UMLAssociation::setRoleDoc(const QString &doc, Uml::Role_Type role)
     m_pRole[role]->setDoc(doc);
 }
 
-/**
- * Convert Changeability_Type value into QString representation.
- * @param type   The Changeability_Type enum value to convert.
- */
-QString UMLAssociation::toString(Uml::Changeability_Type type)
-{
-    switch (type) {
-    case Uml::chg_Frozen:
-        return "frozen";
-        break;
-    case Uml::chg_AddOnly:
-        return "addOnly";
-        break;
-    case Uml::chg_Changeable:
-    default:
-        return "changeable";
-        break;
-    }
-}
-
 /**
  * When the association type is "Generalization" and at least one of the
  * given objects an interface, then it is a "Realization".
@@ -745,32 +669,32 @@ QString UMLAssociation::toString(Uml::Changeability_Type type)
 bool UMLAssociation::isRealization(UMLObject* objA, UMLObject* objB) const
 {
     bool aIsInterface = false;
-    if (objA && (objA->getBaseType() == Uml::ot_Interface)) {
+    if (objA && (objA->baseType() == UMLObject::ot_Interface)) {
         aIsInterface = true;
     }
     bool bIsInterface = false;
-    if (objB && (objB->getBaseType() == Uml::ot_Interface)) {
+    if (objB && (objB->baseType() == UMLObject::ot_Interface)) {
         bIsInterface = true;
     }
-    return (m_AssocType == Uml::at_Generalization) &&
+    return (m_AssocType == Uml::AssociationType::Generalization) &&
            (aIsInterface || bIsInterface);
 }
 
 /**
  * Common initializations at construction time.
- * @param type      The Association_Type to represent.
+ * @param type      The AssociationType to represent.
  * @param roleAObj  Pointer to the role A UMLObject.
  * @param roleBObj  Pointer to the role B UMLObject.
  */
-void UMLAssociation::init(Uml::Association_Type type, UMLObject *roleAObj, UMLObject *roleBObj)
+void UMLAssociation::init(Uml::AssociationType type, UMLObject *roleAObj, UMLObject *roleBObj)
 {
     m_AssocType = type;
     m_BaseType = ot_Association;
     m_Name = "";
     m_bOldLoadMode = false;
     nrof_parent_widgets = -1;
-    if (!UMLApp::app()->getDocument()->loading()) {
-        m_pUMLPackage = UMLApp::app()->getDocument()->currentRoot();
+    if (!UMLApp::app()->document()->loading()) {
+        m_pUMLPackage = UMLApp::app()->document()->currentRoot();
     }
     m_pRole[Uml::A] = new UMLRole (this, roleAObj, Uml::A);
     m_pRole[Uml::B] = new UMLRole (this, roleBObj, Uml::B);
