@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -14,16 +14,17 @@
 
 // kde includes
 #include <klocale.h>
-#include <kdebug.h>
 
 namespace Uml
 {
 
     CmdHandleRename::CmdHandleRename(FloatingTextWidget* ftw, QString& txt)
-      : m_ftw(ftw), m_newstring(txt)
+      : QUndoCommand(),
+        m_ftw(ftw),
+        m_newstring(txt)
     {
-        setText(i18n("Change text"));
         m_oldstring = ftw->text();
+        setText(i18n("Change text : %1 to %2", m_oldstring, txt));
     }
 
     CmdHandleRename::~CmdHandleRename()
