@@ -4,18 +4,18 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include "cmd_set_txt.h"
 
 // app includes
+#include "debug_utils.h"
 #include "floatingtextwidget.h"
 
 // kde includes
 #include <klocale.h>
-#include <kdebug.h>
 
 namespace Uml
 {
@@ -23,6 +23,7 @@ namespace Uml
     CmdSetTxt::CmdSetTxt(FloatingTextWidget* ftw, const QString& txt)
       : m_ftw(ftw), m_newstring(txt)
     {
+        setText(i18n("Set text : %1 to %2", ftw->name(), txt));
         m_oldstring = ftw->text();
         uDebug() << "oldstring: "<< m_oldstring << ", newstring: "<< m_newstring;
     }
