@@ -5,12 +5,13 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002    Oliver Kellogg <okellogg@users.sourceforge.net> *
- *   copyright (C) 2003-2010                                               *
+ *   copyright (C) 2003-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include "adawriter.h"
 
+#include "debug_utils.h"
 #include "umldoc.h"
 #include "uml.h"
 #include "classifier.h"
@@ -23,9 +24,7 @@
 #include "attribute.h"
 #include "operation.h"
 #include "template.h"
-#include "umlnamespace.h"
 
-#include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
@@ -39,6 +38,7 @@ const QString AdaWriter::defaultPackageSuffix = "_Holder";
  * Basic Constructor
  */
 AdaWriter::AdaWriter()
+ : SimpleCodeGenerator()
 {
 }
 
@@ -53,9 +53,9 @@ AdaWriter::~AdaWriter()
  * Returns "Ada".
  * @return   the programming language identifier
  */
-Uml::Programming_Language AdaWriter::language() const
+Uml::ProgrammingLanguage AdaWriter::language() const
 {
-    return Uml::pl_Ada;
+    return Uml::ProgrammingLanguage::Ada;
 }
 
 /**
@@ -63,16 +63,16 @@ Uml::Programming_Language AdaWriter::language() const
  */
 bool AdaWriter::isOOClass(UMLClassifier *c)
 {
-    Uml::Object_Type ot = c->getBaseType();
-    if (ot == Uml::ot_Interface)
+    UMLObject::ObjectType ot = c->baseType();
+    if (ot == UMLObject::ot_Interface)
         return true;
-    if (ot == Uml::ot_Enum)
+    if (ot == UMLObject::ot_Enum)
         return false;
-    if (ot != Uml::ot_Class) {
-        uDebug() << "unknown object type " << ot;
+    if (ot != UMLObject::ot_Class) {
+        uDebug() << "unknown object type " << UMLObject::toString(ot);
         return false;
     }
-    QString stype = c->getStereotype();
+    QString stype = c->stereotype();
     if (stype == "CORBAConstant" || stype == "CORBATypedef" ||
             stype == "CORBAStruct" || stype == "CORBAUnion")
         return false;
@@ -91,15 +91,15 @@ QString AdaWriter::className(UMLClassifier *c, bool inOwnScope)
     // enclosing package then the class name acts as the Ada package
     // name.
     QString retval;
-    QString className = cleanName(c->getName());
-    UMLPackage *umlPkg = c->getUMLPackage();
-    if (umlPkg == UMLApp::app()->getDocument()->getRootFolder(Uml::mt_Logical)) {
+    QString className = cleanName(c->name());
+    UMLPackage *umlPkg = c->umlPackage();
+    if (umlPkg == UMLApp::app()->document()->rootFolder(Uml::ModelType::Logical)) {
         if (! inOwnScope)
             retval = className + '.';
         retval.append("Object");
     } else {
         if (! inOwnScope)
-            retval = umlPkg->getFullyQualifiedName(".") + '.';
+            retval = umlPkg->fullyQualifiedName(".") + '.';
         retval.append(className);
     }
     return retval;
@@ -114,11 +114,11 @@ QString AdaWriter::packageName(UMLPackage *p)
     // the class name is the type name; if the class does not have an
     // enclosing package then the class name acts as the Ada package
     // name.
-    UMLPackage *umlPkg = p->getUMLPackage();
-    QString className = cleanName(p->getName());
+    UMLPackage *umlPkg = p->umlPackage();
+    QString className = cleanName(p->name());
     QString retval;
 
-    if (umlPkg == UMLApp::app()->getDocument()->getRootFolder(Uml::mt_Logical))
+    if (umlPkg == UMLApp::app()->document()->rootFolder(Uml::ModelType::Logical))
         umlPkg = NULL;
 
     UMLClassifier *c = dynamic_cast<UMLClassifier*>(p);
@@ -127,7 +127,7 @@ QString AdaWriter::packageName(UMLPackage *p)
         if (c == NULL || !isOOClass(c))
             retval.append(defaultPackageSuffix);
     } else {
-        retval = umlPkg->getFullyQualifiedName(".");
+        retval = umlPkg->fullyQualifiedName(".");
     }
     return retval;
 }
@@ -147,17 +147,17 @@ void AdaWriter::computeAssocTypeAndRole(UMLClassifier *c,
     UMLClassifier* assocEnd = dynamic_cast<UMLClassifier*>(a->getObject(Uml::B));
     if (assocEnd == NULL)
         return;
-    const Uml::Association_Type assocType = a->getAssocType();
-    if (assocType != Uml::at_Aggregation && assocType != Uml::at_Composition)
+    const Uml::AssociationType assocType = a->getAssocType();
+    if (assocType != Uml::AssociationType::Aggregation && assocType != Uml::AssociationType::Composition)
         return;
     const QString multi = a->getMulti(Uml::B);
     bool hasNonUnityMultiplicity = (!multi.isEmpty() && multi != "1");
     hasNonUnityMultiplicity &= !multi.contains(QRegExp("^1 *\\.\\. *1$"));
     roleName = cleanName(a->getRoleName(Uml::B));
     if (roleName.isEmpty())
-        roleName = cleanName(a->getName());
+        roleName = cleanName(a->name());
     if (roleName.isEmpty()) {
-        QString artificialName = cleanName(assocEnd->getName());
+        QString artificialName = cleanName(assocEnd->name());
         if (hasNonUnityMultiplicity) {
             roleName = artificialName;
             roleName.append("_Vector");
@@ -169,7 +169,7 @@ void AdaWriter::computeAssocTypeAndRole(UMLClassifier *c,
     typeName = className(assocEnd, (assocEnd == c));
     if (hasNonUnityMultiplicity)
         typeName.append("_Array_Ptr");
-    else if (assocType == Uml::at_Aggregation)
+    else if (assocType == Uml::AssociationType::Aggregation)
         typeName.append("_Ptr");
 }
 
@@ -185,7 +185,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
     }
 
     const bool isClass = !c->isInterface();
-    QString classname = cleanName(c->getName());
+    QString classname = cleanName(c->name());
     QString fileName = packageName(c).toLower();
     fileName.replace('.', '-');
 
@@ -219,7 +219,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
     findObjectsRelated(c, imports);
     if (imports.count()) {
         foreach (UMLPackage* con, imports ) {
-            if (con->getBaseType() != Uml::ot_Datatype)
+            if (con->baseType() != UMLObject::ot_Datatype)
                 ada << "with " << packageName(con) << "; " << m_endl;
         }
         ada << m_endl;
@@ -231,7 +231,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
         ada << indent() << "generic" << m_endl;
         m_indentLevel++;
         foreach (UMLTemplate* t, template_params ) {
-            QString formalName = t->getName();
+            QString formalName = t->name();
             QString typeName = t->getTypeName();
             if (typeName == "class") {
                 ada << indent() << "type " << formalName << " is tagged private;"
@@ -244,7 +244,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
                     ada << indent() << "type " << formalName << " is new " << typeName
                     << " with private;  -- CHECK: codegen error"
                     << m_endl;
-                } else if (typeObj->getBaseType() == Uml::ot_Datatype) {
+                } else if (typeObj->baseType() == UMLObject::ot_Datatype) {
                     ada << indent() << formalName << " : " << typeName << ";"
                     << m_endl;
                 } else {
@@ -260,14 +260,14 @@ void AdaWriter::writeClass(UMLClassifier *c)
     QString pkg = packageName(c);
     ada << indent() << "package " << pkg << " is" << m_endl << m_endl;
     m_indentLevel++;
-    if (c->getBaseType() == Uml::ot_Enum) {
+    if (c->baseType() == UMLObject::ot_Enum) {
         UMLEnum *ue = static_cast<UMLEnum*>(c);
-        UMLClassifierListItemList litList = ue->getFilteredList(Uml::ot_EnumLiteral);
+        UMLClassifierListItemList litList = ue->getFilteredList(UMLObject::ot_EnumLiteral);
         uint i = 0;
         ada << indent() << "type " << classname << " is (" << m_endl;
         m_indentLevel++;
         foreach (UMLClassifierListItem* lit, litList ) {
-            QString enumLiteral = cleanName(lit->getName());
+            QString enumLiteral = cleanName(lit->name());
             ada << indent() << enumLiteral;
             if (++i < ( uint )litList.count())
                 ada << "," << m_endl;
@@ -279,7 +279,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
         return;
     }
     if (! isOOClass(c)) {
-        QString stype = c->getStereotype();
+        QString stype = c->stereotype();
         if (stype == "CORBAConstant") {
             ada << indent() << "-- " << stype << " is Not Yet Implemented" << m_endl << m_endl;
         } else if(stype == "CORBAStruct") {
@@ -288,7 +288,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
                 ada << indent() << "type " << classname << " is record" << m_endl;
                 m_indentLevel++;
                 foreach (UMLAttribute* at,  atl ) {
-                    QString name = cleanName(at->getName());
+                    QString name = cleanName(at->name());
                     QString typeName = at->getTypeName();
                     ada << indent() << name << " : " << typeName;
                     QString initialVal = at->getInitialValue();
@@ -312,10 +312,10 @@ void AdaWriter::writeClass(UMLClassifier *c)
     }
 
     // Write class Documentation if non-empty or if force option set.
-    if (forceDoc() || !c->getDoc().isEmpty()) {
+    if (forceDoc() || !c->doc().isEmpty()) {
         ada << "--" << m_endl;
         ada << "-- class " << classname << endl;
-        ada << formatDoc(c->getDoc(), "-- ");
+        ada << formatDoc(c->doc(), "-- ");
         ada << m_endl;
     }
 
@@ -323,7 +323,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
 
     const QString name = className(c);
     ada << indent() << "type " << name << " is ";
-    if (c->getAbstract())
+    if (c->isAbstract())
         ada << "abstract ";
     if (superclasses.isEmpty()) {
         ada << "tagged ";
@@ -345,23 +345,22 @@ void AdaWriter::writeClass(UMLClassifier *c)
         atl = c->getAttributeList();
 
         foreach (UMLAttribute* at, atl ) {
-            if (at->getVisibility() == Uml::Visibility::Public)
+            if (at->visibility() == Uml::Visibility::Public)
                 atpub.append(at);
         }
         if (forceSections() || atpub.count())
             ada << indent() << "-- Accessors for public attributes:" << m_endl << m_endl;
 
         foreach (UMLAttribute* at, atpub ) {
-            QString member = cleanName(at->getName());
+            QString member = cleanName(at->name());
             ada << indent() << "procedure Set_" << member << " (";
-            if (! at->getStatic())
+            if (! at->isStatic())
                 ada << "Self : access " << name << "; ";
             ada << "To : " << at->getTypeName() << ");" << m_endl;
             ada << indent() << "function  Get_" << member;
-            if (! at->getStatic())
+            if (! at->isStatic())
                 ada << " (Self : access " << name << ")";
-            ada << " return " << at->getTypeName() << ";" << m_endl
-            << m_endl;
+            ada << " return " << at->getTypeName() << ";" << m_endl << m_endl;
         }
     }
 
@@ -369,7 +368,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
     UMLOperationList opl(c->getOpList());
     UMLOperationList oppub;
     foreach (UMLOperation* op, opl ) {
-        if (op->getVisibility() == Uml::Visibility::Public)
+        if (op->visibility() == Uml::Visibility::Public)
             oppub.append(op);
     }
     if (forceSections() || oppub.count())
@@ -387,7 +386,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
     UMLAssociationList compositions = c->getCompositions();
 
     ada << indent() << "type " << name << " is ";
-    if (c->getAbstract())
+    if (c->isAbstract())
         ada << "abstract ";
     if (superclasses.isEmpty()) {
         ada << "tagged ";
@@ -425,9 +424,9 @@ void AdaWriter::writeClass(UMLClassifier *c)
     if (isClass && (forceSections() || atl.count())) {
         ada << indent() << "-- Attributes:" << m_endl;
         foreach (UMLAttribute* at, atl ) {
-            if (at->getStatic())
+            if (at->isStatic())
                 continue;
-            ada << indent() << cleanName(at->getName()) << " : "
+            ada << indent() << cleanName(at->name()) << " : "
             << at->getTypeName();
             if (at && ! at->getInitialValue().isEmpty() && ! at->getInitialValue().toLatin1().isEmpty())
                 ada << " := " << at->getInitialValue();
@@ -442,16 +441,16 @@ void AdaWriter::writeClass(UMLClassifier *c)
     if (haveAttrs) {
         bool seen_static_attr = false;
         foreach (UMLAttribute* at, atl ) {
-            if (! at->getStatic())
+            if (! at->isStatic())
                 continue;
             if (! seen_static_attr) {
                 ada << indent() << "-- Static attributes:" << m_endl;
                 seen_static_attr = true;
             }
             ada << indent();
-            if (at->getVisibility() == Uml::Visibility::Private)
+            if (at->visibility() == Uml::Visibility::Private)
                 ada << "-- Private:  ";
-            ada << cleanName(at->getName()) << " : " << at->getTypeName();
+            ada << cleanName(at->name()) << " : " << at->getTypeName();
             if (at && ! at->getInitialValue().isEmpty() && ! at->getInitialValue().toLatin1().isEmpty() )
                 ada << " := " << at->getInitialValue();
             ada << ";" << m_endl;
@@ -462,7 +461,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
     // Generate protected operations.
     UMLOperationList opprot;
     foreach (UMLOperation* op,  opl ) {
-        if (op->getVisibility() == Uml::Visibility::Protected)
+        if (op->visibility() == Uml::Visibility::Protected)
             opprot.append(op);
     }
     if (forceSections() || opprot.count())
@@ -479,7 +478,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
     // into the package body.
     UMLOperationList oppriv;
     foreach (UMLOperation* op, opl ) {
-        const Uml::Visibility::Value vis = op->getVisibility();
+        const Uml::Visibility::Value vis = op->visibility();
         if (vis == Uml::Visibility::Private ||
             vis == Uml::Visibility::Implementation)
         oppriv.append(op);
@@ -494,6 +493,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
     ada << indent() << "end " << pkg << ";" << m_endl << m_endl;
     file.close();
     emit codeGenerated(c, true);
+    emit showGeneratedFile(file.fileName());
 }
 
 /**
@@ -515,11 +515,11 @@ void AdaWriter::writeOperation(UMLOperation *op, QTextStream &ada, bool is_comme
         ada << "procedure ";
     else
         ada << "function ";
-    ada << cleanName(op->getName()) << " ";
-    if (! (op->getStatic() && atl.count() == 0))
+    ada << cleanName(op->name()) << " ";
+    if (! (op->isStatic() && atl.count() == 0))
         ada << "(";
-    UMLClassifier *parentClassifier = static_cast<UMLClassifier*>(op->getUMLPackage());
-    if (! op->getStatic()) {
+    UMLClassifier *parentClassifier = static_cast<UMLClassifier*>(op->umlPackage());
+    if (! op->isStatic()) {
         ada << "Self : access " << className(parentClassifier);
         if (atl.count())
             ada << ";" << m_endl;
@@ -531,7 +531,7 @@ void AdaWriter::writeOperation(UMLOperation *op, QTextStream &ada, bool is_comme
             ada << indent();
             if (is_comment)
                 ada << "-- ";
-            ada << cleanName(at->getName()) << " : ";
+            ada << cleanName(at->name()) << " : ";
             Uml::Parameter_Direction pk = at->getParmKind();
             if (pk == Uml::pd_Out)
                 ada << "out ";
@@ -547,11 +547,11 @@ void AdaWriter::writeOperation(UMLOperation *op, QTextStream &ada, bool is_comme
         }
         m_indentLevel--;
     }
-    if (! (op->getStatic() && atl.count() == 0))
+    if (! (op->isStatic() && atl.count() == 0))
         ada << ")";
     if (! use_procedure)
         ada << " return " << rettype;
-    if (op->getAbstract())
+    if (op->isAbstract())
         ada << " is abstract";
     ada << ";" << m_endl << m_endl;
 }
