@@ -6,31 +6,33 @@
  *                                                                         *
  *   copyright (C) 2003       Brian Thomas                                 *
  *                            <brian.thomas@gsfc.nasa.gov>                 *
- *   copyright (C) 2004-2010  Umbrello UML Modeller Authors                *
+ *   copyright (C) 2004-2012  Umbrello UML Modeller Authors                *
  *                            <uml-devel@uml.sf.net>                       *
  ***************************************************************************/
 
 // own header
 #include "cppwriter.h"
-// qt/kde includes
-#include <QtCore/QFile>
-#include <QtCore/QTextStream>
-#include <QtCore/QRegExp>
-#include <kdebug.h>
+
 // app includes
-#include "codegen_utils.h"
-#include "uml.h"
-#include "umldoc.h"
 #include "association.h"
 #include "classifier.h"
+#include "codegen_utils.h"
+#include "debug_utils.h"
+#include "model_utils.h"
+#include "uml.h"
+#include "umldoc.h"
 #include "operation.h"
 #include "template.h"
 #include "umltemplatelist.h"
 #include "umlclassifierlistitemlist.h"
 #include "classifierlistitem.h"
-#include "model_utils.h"
 #include "codegenerationpolicy.h"
 
+// qt includes
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtCore/QRegExp>
+
 // 3-14-2003: this code developed from the javawriter with parts of the
 // original cppwriter by Luis De la Parra Blum
 
@@ -71,9 +73,9 @@ CppWriter::~CppWriter()
  * Returns "C++".
  * @return   the programming language identifier
  */
-Uml::Programming_Language CppWriter::language() const
+Uml::ProgrammingLanguage CppWriter::language() const
 {
-    return Uml::pl_Cpp;
+    return Uml::ProgrammingLanguage::Cpp;
 }
 
 /**
@@ -81,7 +83,7 @@ Uml::Programming_Language CppWriter::language() const
  */
 CPPCodeGenerationPolicy *CppWriter::policyExt()
 {
-    return static_cast<CPPCodeGenerationPolicy*>(UMLApp::app()->getPolicyExt());
+    return static_cast<CPPCodeGenerationPolicy*>(UMLApp::app()->policyExt());
 }
 
 /**
@@ -104,9 +106,9 @@ void CppWriter::writeClass(UMLClassifier *c)
         return;
     }
 
-    className_ = cleanName(c->getName());
+    className_ = cleanName(c->name());
 
-    if (c->getVisibility() != Uml::Visibility::Implementation) {
+    if (c->visibility() != Uml::Visibility::Implementation) {
         if( !openFile(fileh, fileName_)) {
             emit codeGenerated(c, false);
             return;
@@ -119,7 +121,7 @@ void CppWriter::writeClass(UMLClassifier *c)
     // Determine whether the implementation file is required.
     // (It is not required if the class is an enumeration.)
     bool need_impl = true;
-    if (c->getBaseType() == Uml::ot_Enum) {
+    if (c->baseType() == UMLObject::ot_Enum) {
         need_impl = false;
     }
     if (need_impl) {
@@ -174,14 +176,14 @@ void CppWriter::writeHeaderAccessorMethodDecl(UMLClassifier *c, Uml::Visibility
     writeHeaderAttributeAccessorMethods(c, permitScope, false, stream);
 
     // associations
-    writeAssociationMethods(c->getSpecificAssocs(Uml::at_Association), permitScope,
-                            true, INLINE_ASSOCIATION_METHODS, true, c->getID(), stream);
+    writeAssociationMethods(c->getSpecificAssocs(Uml::AssociationType::Association), permitScope,
+                            true, INLINE_ASSOCIATION_METHODS, true, c->id(), stream);
     writeAssociationMethods(c->getUniAssociationToBeImplemented(), permitScope,
-                            true, INLINE_ASSOCIATION_METHODS, true, c->getID(), stream);
+                            true, INLINE_ASSOCIATION_METHODS, true, c->id(), stream);
     writeAssociationMethods(c->getAggregations(), permitScope,
-                            true,  INLINE_ASSOCIATION_METHODS, true, c->getID(), stream);
+                            true,  INLINE_ASSOCIATION_METHODS, true, c->id(), stream);
     writeAssociationMethods(c->getCompositions(), permitScope,
-                            true, INLINE_ASSOCIATION_METHODS, false, c->getID(), stream);
+                            true, INLINE_ASSOCIATION_METHODS, false, c->id(), stream);
 
     writeBlankLine(stream);
 }
@@ -197,10 +199,10 @@ void CppWriter::writeHeaderFieldDecl(UMLClassifier *c, Uml::Visibility permitSco
     writeAttributeDecls(c, permitScope, false, stream);
 
     // associations
-    writeAssociationDecls(c->getSpecificAssocs(Uml::at_Association), permitScope, c->getID(), stream);
-    writeAssociationDecls(c->getUniAssociationToBeImplemented(), permitScope, c->getID(), stream);
-    writeAssociationDecls(c->getAggregations(), permitScope, c->getID(), stream);
-    writeAssociationDecls(c->getCompositions(), permitScope, c->getID(), stream);
+    writeAssociationDecls(c->getSpecificAssocs(Uml::AssociationType::Association), permitScope, c->id(), stream);
+    writeAssociationDecls(c->getUniAssociationToBeImplemented(), permitScope, c->id(), stream);
+    writeAssociationDecls(c->getAggregations(), permitScope, c->id(), stream);
+    writeAssociationDecls(c->getCompositions(), permitScope, c->id(), stream);
 }
 
 /**
@@ -230,7 +232,7 @@ void CppWriter::writeSourceFile(UMLClassifier *c, QFile &file)
     cpp << "#include \"" << className_ << ".h\"" << m_endl;
     writeBlankLine(cpp);
 
-    if (c->getVisibility() == Uml::Visibility::Implementation) {
+    if (c->visibility() == Uml::Visibility::Implementation) {
         writeClassDecl(c, cpp);
     }
 
@@ -275,34 +277,34 @@ void CppWriter::writeSourceFile(UMLClassifier *c, QFile &file)
     // accessor methods for associations
 
     // public
-    writeAssociationMethods(c->getSpecificAssocs(Uml::at_Association), Uml::Visibility::Public, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+    writeAssociationMethods(c->getSpecificAssocs(Uml::AssociationType::Association), Uml::Visibility::Public, false,
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
     writeAssociationMethods(c->getUniAssociationToBeImplemented(), Uml::Visibility::Public, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
     writeAssociationMethods(c->getAggregations(), Uml::Visibility::Public, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
     writeAssociationMethods(c->getCompositions(), Uml::Visibility::Public, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
 
     // protected
-    writeAssociationMethods(c->getSpecificAssocs(Uml::at_Association), Uml::Visibility::Protected, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+    writeAssociationMethods(c->getSpecificAssocs(Uml::AssociationType::Association), Uml::Visibility::Protected, false,
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
     writeAssociationMethods(c->getUniAssociationToBeImplemented(), Uml::Visibility::Protected, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
     writeAssociationMethods(c->getAggregations(), Uml::Visibility::Protected, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
     writeAssociationMethods(c->getCompositions(), Uml::Visibility::Protected, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
 
     // private
-    writeAssociationMethods(c->getSpecificAssocs(Uml::at_Association), Uml::Visibility::Private, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+    writeAssociationMethods(c->getSpecificAssocs(Uml::AssociationType::Association), Uml::Visibility::Private, false,
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
     writeAssociationMethods(c->getUniAssociationToBeImplemented(), Uml::Visibility::Private, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
     writeAssociationMethods(c->getAggregations(), Uml::Visibility::Private, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
     writeAssociationMethods(c->getCompositions(), Uml::Visibility::Private, false,
-                            !INLINE_ASSOCIATION_METHODS, true, c->getID(), cpp);
+                            !INLINE_ASSOCIATION_METHODS, true, c->id(), cpp);
     writeBlankLine(cpp);
 
     // Other operation methods -- all other operations are now written
@@ -352,35 +354,35 @@ void CppWriter::writeClassDecl(UMLClassifier *c, QTextStream &cpp)
     if (c->hasAssociations())
     {
         // write all includes we need to include other classes, that arent us.
-        printAssociationIncludeDecl (c->getSpecificAssocs(Uml::at_Association), c->getID(), cpp);
-        printAssociationIncludeDecl (c->getUniAssociationToBeImplemented(), c->getID(), cpp);
-        printAssociationIncludeDecl (c->getAggregations(), c->getID(), cpp);
-        printAssociationIncludeDecl (c->getCompositions(), c->getID(), cpp);
+        printAssociationIncludeDecl (c->getSpecificAssocs(Uml::AssociationType::Association), c->id(), cpp);
+        printAssociationIncludeDecl (c->getUniAssociationToBeImplemented(), c->id(), cpp);
+        printAssociationIncludeDecl (c->getAggregations(), c->id(), cpp);
+        printAssociationIncludeDecl (c->getCompositions(), c->id(), cpp);
 
         writeBlankLine(cpp);
     }
 
     foreach (UMLClassifier* classifier, superclasses ) {
-        if (classifier->getPackage()!=c->getPackage() && !classifier->getPackage().isEmpty()) {
-            cpp << "using " << cleanName(classifier->getPackage()) << "::" << cleanName(classifier->getName()) << ";" << m_endl;
+        if (classifier->package()!=c->package() && !classifier->package().isEmpty()) {
+            cpp << "using " << cleanName(classifier->package()) << "::" << cleanName(classifier->name()) << ";" << m_endl;
         }
     }
 
-    if (!c->getPackage().isEmpty() && policyExt()->getPackageIsNamespace())
-        cpp << m_endl << "namespace " << cleanName(c->getPackage()) << " {" << m_endl << m_endl;
+    if (!c->package().isEmpty() && policyExt()->getPackageIsNamespace())
+        cpp << m_endl << "namespace " << cleanName(c->package()) << " {" << m_endl << m_endl;
 
     //Write class Documentation if there is somthing or if force option
-    if (forceDoc() || !c->getDoc().isEmpty()) {
+    if (forceDoc() || !c->doc().isEmpty()) {
         cpp << m_endl << "/**" << m_endl;
         cpp << "  * class " << className_ << m_endl;
-        cpp << formatDoc(c->getDoc(),"  * ");
+        cpp << formatDoc(c->doc(),"  * ");
         cpp << "  */";
         writeBlankLine(cpp);
         writeBlankLine(cpp);
     }
 
     //check if class is abstract and / or has abstract methods
-    if ((c->getAbstract() || c->isInterface())
+    if ((c->isAbstract() || c->isInterface())
             && !hasAbstractOps(c))
         cpp << "/******************************* Abstract Class ****************************" << m_endl
         << className_ << " does not have any pure virtual methods, but its author" << m_endl
@@ -388,19 +390,19 @@ void CppWriter::writeClassDecl(UMLClassifier *c, QTextStream &cpp)
         << "  Inherit from it instead and create only objects from the derived classes" << m_endl
         << "*****************************************************************************/" << m_endl << m_endl;
 
-    if (c->getBaseType() == Uml::ot_Enum) {
-        UMLClassifierListItemList litList = c->getFilteredList(Uml::ot_EnumLiteral);
+    if (c->baseType() == UMLObject::ot_Enum) {
+        UMLClassifierListItemList litList = c->getFilteredList(UMLObject::ot_EnumLiteral);
         uint i = 0;
         cpp << "enum " << className_ << " {" << m_endl;
         foreach (UMLClassifierListItem* lit, litList ) {
-            QString enumLiteral = cleanName(lit->getName());
+            QString enumLiteral = cleanName(lit->name());
             cpp << indent() << enumLiteral;
             if (++i < ( uint )litList.count())
                 cpp << ",";
             cpp << m_endl;
         }
         cpp << m_endl << "};" << m_endl;  // end of class header
-        if (!c->getPackage().isEmpty() && policyExt()->getPackageIsNamespace())
+        if (!c->package().isEmpty() && policyExt()->getPackageIsNamespace())
             cpp << "}  // end of package namespace" << m_endl;
         return;
     }
@@ -411,7 +413,7 @@ void CppWriter::writeClassDecl(UMLClassifier *c, QTextStream &cpp)
         cpp << "template<";
         for (UMLTemplateListIt tlit( template_params ); tlit.hasNext(); ) {
             UMLTemplate* t = tlit.next();
-            QString formalName = t->getName();
+            QString formalName = t->name();
             QString typeName = t->getTypeName();
             cpp << typeName << " " << formalName;
             if ( tlit.hasNext() ) {
@@ -429,9 +431,9 @@ void CppWriter::writeClassDecl(UMLClassifier *c, QTextStream &cpp)
     uint i = 0;
     foreach (UMLClassifier* superClass, c->getSuperClasses()) {
         i++;
-        if (superClass->getAbstract() || superClass->isInterface())
+        if (superClass->isAbstract() || superClass->isInterface())
             cpp << "virtual ";
-        cpp << "public " << cleanName(superClass->getName());
+        cpp << "public " << cleanName(superClass->name());
         if (i < numOfSuperClasses)
             cpp << ", ";
     }
@@ -470,7 +472,7 @@ void CppWriter::writeClassDecl(UMLClassifier *c, QTextStream &cpp)
     cpp << m_endl << "};" << m_endl;
 
     // end of class namespace, if any
-    if(!c->getPackage().isEmpty() && policyExt()->getPackageIsNamespace())
+    if(!c->package().isEmpty() && policyExt()->getPackageIsNamespace())
         cpp << "}; // end of package namespace" << m_endl;
 
 }
@@ -506,23 +508,23 @@ void CppWriter::writeAttributeDecls (UMLClassifier *c, Uml::Visibility visibilit
     if (list.count() > 0) {
 
         // write attrib declarations now
-        bool isFirstAttrib = true;
+        // bool isFirstAttrib = true;
         QString documentation;
         foreach (UMLAttribute* at, list ) {
 
             //                  bool noPriorDocExists = documentation.isEmpty();
-            documentation = at->getDoc();
+            documentation = at->doc();
 
             // add a line for code clarity IF PRIOR attrib has comment on it
             // OR this line has documentation
             //                  if(!isFirstAttrib && (!documentation.isEmpty()||!noPriorDocExists))
             //                          writeBlankLine(stream);
 
-            isFirstAttrib = false;
+            // isFirstAttrib = false;
 
             QString varName = getAttributeVariableName(at);
 
-            QString staticValue = at->getStatic() ? "static " : "";
+            QString staticValue = at->isStatic() ? "static " : "";
             QString typeName = fixTypeName(at->getTypeName());
             if(!documentation.isEmpty())
                 writeComment(documentation, indent(), stream);
@@ -586,7 +588,7 @@ void CppWriter::writeAttributeMethods(UMLAttributeList attribs,
 
     foreach (UMLAttribute* at, attribs ) {
         QString varName = getAttributeVariableName(at);
-        QString methodBaseName = cleanName(at->getName());
+        QString methodBaseName = cleanName(at->name());
 
         // force capitalizing the field name, this is silly,
         // from what I can tell, this IS the default behavior for
@@ -595,8 +597,8 @@ void CppWriter::writeAttributeMethods(UMLAttributeList attribs,
         methodBaseName.replace(0,1,methodBaseName.at(0).toUpper());
 
         writeSingleAttributeAccessorMethods(at->getTypeName(), varName,
-                                            methodBaseName, at->getDoc(), Uml::chg_Changeable, isHeaderMethod,
-                                            at->getStatic(), writeMethodBody, stream);
+                                            methodBaseName, at->doc(), Uml::Changeability::Changeable, isHeaderMethod,
+                                            at->isStatic(), writeMethodBody, stream);
     }
 }
 
@@ -663,8 +665,8 @@ void CppWriter::writeAssociationDecls(UMLAssociationList associations, Uml::Visi
                 printRoleA = true;
 
             // First: we insert documentaion for association IF it has either role AND some documentation (!)
-            if ((printRoleA || printRoleB) && !(a->getDoc().isEmpty()))
-                writeComment(a->getDoc(), indent(), h);
+            if ((printRoleA || printRoleB) && !(a->doc().isEmpty()))
+                writeComment(a->doc(), indent(), h);
 
             // print RoleB decl
             if (printRoleB && a->getVisibility(Uml::B) == permitScope)
@@ -768,7 +770,7 @@ void CppWriter::writeAssociationMethods (UMLAssociationList associations,
                                                writeMethodBody,
                                                a->getRoleName(Uml::B),
                                                a->getMulti(Uml::B), a->getRoleDoc(Uml::B),
-                                               a->getChangeability(Uml::B), stream);
+                                               a->changeability(Uml::B), stream);
                 }
             }
 
@@ -783,7 +785,7 @@ void CppWriter::writeAssociationMethods (UMLAssociationList associations,
                                                a->getRoleName(Uml::A),
                                                a->getMulti(Uml::A),
                                                a->getRoleDoc(Uml::A),
-                                               a->getChangeability(Uml::A),
+                                               a->changeability(Uml::A),
                                                stream);
                 }
             }
@@ -801,7 +803,7 @@ void CppWriter::writeAssociationRoleMethod (const QString &fieldClassName,
         bool isHeaderMethod,
         bool writeMethodBody,
         const QString &roleName, const QString &multi,
-        const QString &description, Uml::Changeability_Type change,
+        const QString &description, Uml::Changeability change,
         QTextStream &stream)
 {
     if (multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
@@ -824,7 +826,7 @@ void CppWriter::writeAssociationRoleMethod (const QString &fieldClassName,
 void CppWriter::writeVectorAttributeAccessorMethods (
         const QString &fieldClassName, const QString &fieldVarName,
         const QString &fieldName, const QString &description,
-        Uml::Changeability_Type changeType,
+        Uml::Changeability changeType,
         bool isHeaderMethod,
         bool writeMethodBody,
         QTextStream &stream)
@@ -834,7 +836,7 @@ void CppWriter::writeVectorAttributeAccessorMethods (
     QString indnt = indent();
 
     // ONLY IF changeability is NOT Frozen
-    if (changeType != Uml::chg_Frozen)
+    if (changeType != Uml::Changeability::Frozen)
     {
         writeDocumentation("Add a " + fldName + " object to the " + fieldVarName + " List",description,"",stream);
         stream << indnt << "void ";
@@ -856,7 +858,7 @@ void CppWriter::writeVectorAttributeAccessorMethods (
     }
 
     // ONLY IF changeability is Changeable
-    if (changeType == Uml::chg_Changeable)
+    if (changeType == Uml::Changeability::Changeable)
     {
         writeDocumentation("Remove a " + fldName + " object from " + fieldVarName + " List",
                            description, "", stream);
@@ -906,7 +908,7 @@ void CppWriter::writeVectorAttributeAccessorMethods (
 void CppWriter::writeSingleAttributeAccessorMethods(
         const QString& fieldClassName, const QString& fieldVarName,
         const QString& fieldName, const QString &description,
-        Uml::Changeability_Type change,
+        Uml::Changeability change,
         bool isHeaderMethod,
         bool isStatic,
         bool writeMethodBody,
@@ -921,7 +923,7 @@ void CppWriter::writeSingleAttributeAccessorMethods(
     QString indnt = indent();
 
     // set method
-    if (change == Uml::chg_Changeable && !isStatic) {
+    if (change == Uml::Changeability::Changeable && !isStatic) {
         writeDocumentation("Set the value of " + fieldVarName,description,policyExt()->getDocToolTag() + "param new_var the new value of " + fieldVarName,stream);
         stream << indnt << "void ";
         if(!isHeaderMethod)
@@ -971,7 +973,7 @@ void CppWriter::writeSingleAttributeAccessorMethods(
 void CppWriter::writeConstructorDecls(QTextStream &stream)
 {
     const bool generateEmptyConstructors =
-        UMLApp::app()->getCommonPolicy()->getAutoGenerateConstructors();
+        UMLApp::app()->commonPolicy()->getAutoGenerateConstructors();
     if (forceDoc() || generateEmptyConstructors)
     {
         writeComment("Constructors/Destructors", indent(), stream);
@@ -994,7 +996,7 @@ void CppWriter::writeConstructorDecls(QTextStream &stream)
  */
 void CppWriter::writeInitAttributeDecl(UMLClassifier * c, QTextStream &stream)
 {
-    if (UMLApp::app()->getCommonPolicy()->getAutoGenerateConstructors() &&
+    if (UMLApp::app()->commonPolicy()->getAutoGenerateConstructors() &&
         c->hasAttributes())
         stream << indent() << "void initAttributes ( ) ;" << m_endl;
 }
@@ -1005,7 +1007,7 @@ void CppWriter::writeInitAttributeDecl(UMLClassifier * c, QTextStream &stream)
 void CppWriter::writeInitAttributeMethod(UMLClassifier * c, QTextStream &stream)
 {
     // only need to do this under certain conditions
-    if (!UMLApp::app()->getCommonPolicy()->getAutoGenerateConstructors() ||
+    if (!UMLApp::app()->commonPolicy()->getAutoGenerateConstructors() ||
         !c->hasAttributes())
         return;
 
@@ -1060,7 +1062,7 @@ void CppWriter::writeInitAttributeMethod(UMLClassifier * c, QTextStream &stream)
 void CppWriter::writeConstructorMethods(UMLClassifier * c, QTextStream &stream)
 {
     const bool generateEmptyConstructors =
-        UMLApp::app()->getCommonPolicy()->getAutoGenerateConstructors();
+        UMLApp::app()->commonPolicy()->getAutoGenerateConstructors();
 
     if (forceDoc() || generateEmptyConstructors) {
         writeComment("Constructors/Destructors", indent(), stream);
@@ -1110,7 +1112,7 @@ void CppWriter::writeOperations(UMLClassifier *c, bool isHeaderMethod,
     //sort operations by scope first and see if there are abstract methods
     UMLOperationList inputlist = c->getOpList();
     foreach (UMLOperation* op, inputlist ) {
-        if (op->getVisibility() == permitScope) {
+        if (op->visibility() == permitScope) {
             oplist.append(op);
         }
     }
@@ -1137,7 +1139,7 @@ void CppWriter::writeOperations(UMLClassifier *c, bool isHeaderMethod,
 void CppWriter::writeOperations(UMLClassifier *c, UMLOperationList &oplist, bool isHeaderMethod, QTextStream &cpp)
 {
     const bool generateEmptyConstructors =
-        UMLApp::app()->getCommonPolicy()->getAutoGenerateConstructors();
+        UMLApp::app()->commonPolicy()->getAutoGenerateConstructors();
 
     // generate method decl for each operation given
     foreach (UMLOperation* op, oplist  ) {
@@ -1158,7 +1160,7 @@ void CppWriter::writeOperations(UMLClassifier *c, UMLOperationList &oplist, bool
         }
 
         QString str;
-        if (op->getAbstract() || c->isInterface()) {
+        if (op->isAbstract() || c->isInterface()) {
             if (isHeaderMethod) {
                 // declare abstract method as 'virtual'
                 str += "virtual ";
@@ -1166,7 +1168,7 @@ void CppWriter::writeOperations(UMLClassifier *c, UMLOperationList &oplist, bool
         }
 
         // static declaration for header file
-        if (isHeaderMethod && op->getStatic())
+        if (isHeaderMethod && op->isStatic())
             str += "static ";
 
         // returntype of method
@@ -1175,21 +1177,21 @@ void CppWriter::writeOperations(UMLClassifier *c, UMLOperationList &oplist, bool
         if (!isHeaderMethod)
             str += className_ + "::";
 
-        str += cleanName(op->getName()) + " (";
+        str += cleanName(op->name()) + " (";
 
         // generate parameters
         uint j = 0;
         for (UMLAttributeListIt atlIt( atl ); atlIt.hasNext() ; ++j) {
             UMLAttribute* at = atlIt.next();
             QString typeName = fixTypeName(at->getTypeName());
-            QString atName = cleanName(at->getName());
+            QString atName = cleanName(at->name());
             str += typeName + ' ' + atName;
             const QString initVal = at->getInitialValue();
             if (! initVal.isEmpty())
                 str += " = " + initVal;
             if (j < ( uint )( atl.count() - 1 ))
                 str += ", ";
-            doc += policyExt()->getDocToolTag() + "param  " + atName + ' ' + at->getDoc() + m_endl;
+            doc += policyExt()->getDocToolTag() + "param  " + atName + ' ' + at->doc() + m_endl;
         }
         doc = doc.remove(doc.size() - 1, 1);  // remove last endl of comment
         str += " )";
@@ -1214,7 +1216,7 @@ void CppWriter::writeOperations(UMLClassifier *c, UMLOperationList &oplist, bool
         }
 
         // write it out
-        writeDocumentation("", op->getDoc(), doc, cpp);
+        writeDocumentation("", op->doc(), doc, cpp);
         cpp << indent() << str << m_endl;
         writeBlankLine(cpp);
     }
@@ -1247,9 +1249,9 @@ void CppWriter::printAssociationIncludeDecl(UMLAssociationList list, Uml::IDType
         // how to declare some associations.
         if (current) {
             if( !isFirstClass && !a->getRoleName(Uml::A).isEmpty() && !a->getRoleName(Uml::B).isEmpty())
-                stream << "class " << current->getName() << ";" << m_endl; // special case: use forward declaration
+                stream << "class " << current->name() << ";" << m_endl; // special case: use forward declaration
             else
-                stream << "#include \"" << current->getName() << ".h\"" << m_endl; // just the include statement
+                stream << "#include \"" << current->name() << ".h\"" << m_endl; // just the include statement
         }
     }
 }
@@ -1277,7 +1279,7 @@ QString CppWriter::fixInitialStringDeclValue(const QString &value, const QString
  */
 QString CppWriter::umlObjectName(UMLObject *obj)
 {
-    return(obj!=0)?obj->getName():QString("NULL");
+    return(obj!=0)?obj->name():QString("NULL");
 }
 
 /**
@@ -1309,7 +1311,7 @@ void CppWriter::printTextAsSeparateLinesWithIndent(const QString &text, const QS
  */
 QString CppWriter::getAttributeVariableName(UMLAttribute *at)
 {
-    QString fieldName = cleanName(at->getName());
+    QString fieldName = cleanName(at->name());
     return fieldName;
 }
 
