@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2007 Jari-Matti Mäkelä <jmjm@iki.fi>                    *
- *   copyright (C) 2008                                                    *
+ *   copyright (C) 2008-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -21,10 +21,6 @@
 // own header
 #include "dclassifiercodedocument.h"
 
-// qt/kde includes
-#include <kdebug.h>
-#include <QtCore/QRegExp>
-
 // local includes
 #include "dcodegenerator.h"
 #include "dcodecomment.h"
@@ -33,8 +29,12 @@
 #include "codegen_utils.h"
 #include "classifier.h"
 #include "codegenerationpolicy.h"
+#include "debug_utils.h"
 #include "uml.h"
 
+// qt includes
+#include <QtCore/QRegExp>
+
 DClassifierCodeDocument::DClassifierCodeDocument ( UMLClassifier * concept )
         : ClassifierCodeDocument (concept)
 {
@@ -48,7 +48,7 @@ DClassifierCodeDocument::~DClassifierCodeDocument ( )
 // Make it easier on ourselves
 DCodeGenerationPolicy * DClassifierCodeDocument::getDPolicy()
 {
-    CodeGenPolicyExt *pe = UMLApp::app()->getPolicyExt();
+    CodeGenPolicyExt *pe = UMLApp::app()->policyExt();
     DCodeGenerationPolicy * policy = dynamic_cast<DCodeGenerationPolicy*>(pe);
     return policy;
 }
@@ -61,7 +61,7 @@ CodeDocumentDialog DClassifierCodeDocument::getDialog ( )
 
 bool DClassifierCodeDocument::forceDoc ()
 {
-    return UMLApp::app()->getCommonPolicy()->getCodeVerboseDocumentComments();
+    return UMLApp::app()->commonPolicy()->getCodeVerboseDocumentComments();
 }
 
 // We overwritten by D language implementation to get lowercase path
@@ -203,7 +203,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode ( QDomElement & root)
                                         if( name == "codeoperation" ) {
                                             // find the code operation by id
                                             QString id = element.attribute("parent_id","-1");
-                                            UMLObject * obj = UMLApp::app()->getDocument()->findObjectById(STR2ID(id));
+                                            UMLObject * obj = UMLApp::app()->document()->findObjectById(STR2ID(id));
                                             UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
                                             if(op) {
                                                 CodeOperation * block = new DCodeOperation(this, op);
@@ -294,8 +294,8 @@ void DClassifierCodeDocument::updateContent( )
 {
     // Gather info on the various fields and parent objects of this class...
     UMLClassifier * c = getParentClassifier();
-    CodeGenerationPolicy * commonPolicy = UMLApp::app()->getCommonPolicy();
-    CodeGenPolicyExt * pe = UMLApp::app()->getPolicyExt();
+    CodeGenerationPolicy * commonPolicy = UMLApp::app()->commonPolicy();
+    CodeGenPolicyExt * pe = UMLApp::app()->policyExt();
     DCodeGenerationPolicy * policy = dynamic_cast<DCodeGenerationPolicy*>(pe);
 
     // first, set the global flag on whether or not to show classfield info
@@ -339,9 +339,9 @@ void DClassifierCodeDocument::updateContent( )
     //
     QString pkgs = getPackage();
     pkgs.replace(QRegExp("::"), ".");
-    QString packageText = getPackage().isEmpty() ? "" : "package "+pkgs+';'+endLine;
+    QString packageText = getPackage().isEmpty() ? "" : QString("package "+pkgs+';'+endLine);
     CodeBlockWithComments * pblock = addOrUpdateTaggedCodeBlockWithComments("packages", packageText, "", 0, false);
-    if(packageText.isEmpty() && pblock->getContentType() == CodeBlock::AutoGenerated)
+    if(packageText.isEmpty() && pblock->contentType() == CodeBlock::AutoGenerated)
         pblock->setWriteOutText(false);
     else
         pblock->setWriteOutText(true);
@@ -365,25 +365,25 @@ void DClassifierCodeDocument::updateContent( )
         // NO (default) datatypes in the import statement.. use defined
         // ones whould be possible, but no idea how to do that...at least for now.
         // Dynamic casting is slow..not an optimal way to do this.
-        if (!packageMap.contains(con) && con->getBaseType() != Uml::ot_Datatype)
+        if (!packageMap.contains(con) && con->baseType() != UMLObject::ot_Datatype)
         {
-            packageMap.insert(con, con->getPackage());
+            packageMap.insert(con, con->package());
 
             // now, we DON'T need to import classes that are already in our own package
             // (that is, IF a package is specified). Otherwise, we should have a declaration.
-            if (con->getPackage() != c->getPackage() ||
-                    (c->getPackage().isEmpty() && con->getPackage().isEmpty()))
+            if (con->package() != c->package() ||
+                    (c->package().isEmpty() && con->package().isEmpty()))
             {
                 importStatement.append(endLine+"import ");
-                if(!con->getPackage().isEmpty())
-                    importStatement.append(con->getPackage()+'.');
-                importStatement.append(CodeGenerator::cleanName(con->getName())+';');
+                if(!con->package().isEmpty())
+                    importStatement.append(con->package()+'.');
+                importStatement.append(CodeGenerator::cleanName(con->name())+';');
             }
         }
     }
     // now, add/update the imports codeblock
     CodeBlockWithComments * iblock = addOrUpdateTaggedCodeBlockWithComments("imports", importStatement, "", 0, false);
-    if(importStatement.isEmpty() && iblock->getContentType() == CodeBlock::AutoGenerated)
+    if(importStatement.isEmpty() && iblock->contentType() == CodeBlock::AutoGenerated)
         iblock->setWriteOutText(false);
     else
         iblock->setWriteOutText(true);
@@ -488,14 +488,14 @@ void DClassifierCodeDocument::updateContent( )
     // special condiions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * constComment = constBlock->getComment();
-    CodeGenerationPolicy *pol = UMLApp::app()->getCommonPolicy();
+    CodeGenerationPolicy *pol = UMLApp::app()->commonPolicy();
     if (!forceDoc() && (isInterface || !pol->getAutoGenerateConstructors()))
         constComment->setWriteOutText(false);
     else
         constComment->setWriteOutText(true);
 
     // add/get the empty constructor
-    QString DClassName = getDClassName(c->getName());
+    QString DClassName = getDClassName(c->name());
     QString emptyConstStatement = "public "+DClassName+" ( ) { }";
     CodeBlockWithComments * emptyConstBlock =
         constBlock->addOrUpdateTaggedCodeBlockWithComments("emptyconstructor", emptyConstStatement, "Empty Constructor", 1, false);
