@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2005-2008                                               *
+ *   copyright (C) 2005-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -12,23 +12,25 @@
 #include "import_utils.h"
 
 // app includes
+#include "association.h"
+#include "artifact.h"
+#include "attribute.h"
+#include "classifier.h"
+#include "debug_utils.h"
+#include "folder.h"
+#include "enum.h"
+#include "model_utils.h"
+#include "object_factory.h"
+#include "operation.h"
+#include "package.h"
+#include "template.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umlobject.h"
-#include "package.h"
-#include "folder.h"
-#include "enum.h"
-#include "classifier.h"
-#include "operation.h"
-#include "attribute.h"
-#include "template.h"
-#include "association.h"
-#include "object_factory.h"
-#include "model_utils.h"
+#include "umbrellosettings.h"
 
 // kde includes
 #include <kmessagebox.h>
-#include <kdebug.h>
 #include <klocale.h>
 
 // qt includes
@@ -126,6 +128,9 @@ QString formatComment(const QString &comment)
         else
             lines.pop_front();  // nothing interesting on this line
     }
+    if (! lines.count())
+        return QString();
+
     QString& last = lines.last();
     int endpos = last.indexOf("*/");
     if (endpos != -1) {
@@ -146,7 +151,7 @@ QString formatComment(const QString &comment)
 }
 
 /*
-UMLObject* findUMLObject(QString name, Uml::Object_Type type)
+UMLObject* findUMLObject(QString name, UMLObject::ObjectType type)
 {
     // Why an extra wrapper? See comment at addMethodParameter()
     UMLObject * o = umldoc->findUMLObject(name, type);
@@ -157,19 +162,33 @@ UMLObject* findUMLObject(QString name, Uml::Object_Type type)
 /**
  * Find or create a document object.
  */
-UMLObject *createUMLObject(Uml::Object_Type type,
+UMLObject *createUMLObject(UMLObject::ObjectType type,
                            const QString& inName,
                            UMLPackage *parentPkg,
                            const QString& comment,
                            const QString& stereotype)
 {
     QString name = inName;
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
-    UMLFolder *logicalView = umldoc->getRootFolder(Uml::mt_Logical);
-    const Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
+    UMLDoc *umldoc = UMLApp::app()->document();
+    if (type == UMLObject::ot_Artifact) {
+        if (!Settings::optionState().codeImportState.createArtifacts)
+            return 0;
+        QFileInfo fi(name);
+        UMLFolder *componentView = umldoc->rootFolder(Uml::ModelType::Component);
+        UMLObject *o = umldoc->findUMLObjectRaw(componentView, fi.fileName(), type);
+        if (o)
+            return o;
+        o = Object_Factory::createUMLObject(type, fi.fileName(), componentView, false);
+        UMLArtifact *a = static_cast<UMLArtifact*>(o);
+        a->setDrawAsType(UMLArtifact::file);
+        a->setDoc(comment);
+        uDebug() << name << comment;
+        return o;
+    }
+    UMLFolder *logicalView = umldoc->rootFolder(Uml::ModelType::Logical);
     if (parentPkg == NULL) {
         // uDebug() << "Import_Utils::createUMLObject(" << name
-        //     << "): parentPkg is NULL, assuming Logical View" << endl;
+        //     << "): parentPkg is NULL, assuming Logical View";
         parentPkg = logicalView;
     }
     UMLObject * o = umldoc->findUMLObject(name, type, parentPkg);
@@ -179,12 +198,12 @@ UMLObject *createUMLObject(Uml::Object_Type type,
         const bool isConst = name.contains(QRegExp("^const "));
         name.remove(QRegExp("^const\\s+"));
         QString typeName(name);
-        const bool isAdorned = typeName.contains( QRegExp("[^\\w:\\. ]") );
+        bool isAdorned = typeName.contains( QRegExp("[^\\w:\\. ]") );
         const bool isPointer = typeName.contains('*');
         const bool isRef = typeName.contains('&');
         typeName.remove(QRegExp("[^\\w:\\. ].*$"));
         typeName = typeName.simplified();
-        UMLObject *origType = umldoc->findUMLObject(typeName, Uml::ot_UMLObject, parentPkg);
+        UMLObject *origType = umldoc->findUMLObject(typeName, UMLObject::ot_UMLObject, parentPkg);
         if (origType == NULL) {
             // Still not found. Create the stripped down type.
             if (bPutAtGlobalScope)
@@ -193,6 +212,11 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             QStringList components;
             if (typeName.contains("::")) {
                 components = typeName.split("::");
+            } else if (typeName.contains("...")) {
+                // Java variable length arguments
+                type = UMLObject::ot_Datatype;
+                parentPkg = umldoc->datatypeFolder();
+                isAdorned = false;
             } else if (typeName.contains(".")) {
                 components = typeName.split('.');
             }
@@ -202,14 +226,15 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                 while ( components.count() ) {
                     QString scopeName = components.front();
                     components.pop_front();
-                    o = umldoc->findUMLObject(scopeName, Uml::ot_UMLObject, parentPkg);
+                    o = umldoc->findUMLObject(scopeName, UMLObject::ot_UMLObject, parentPkg);
                     if (o) {
                         parentPkg = static_cast<UMLPackage*>(o);
                         continue;
                     }
                     int wantNamespace = KMessageBox::Yes;
-                    if (pl == Uml::pl_Cpp) {
-                        /* We know std and Qt are namespaces */
+                    const Uml::ProgrammingLanguage pl = UMLApp::app()->activeLanguage();
+                    if (pl == Uml::ProgrammingLanguage::Cpp) {
+                        // We know std and Qt are namespaces.
                         if (scopeName != "std" && scopeName != "Qt") {
                             wantNamespace = KMessageBox::questionYesNo(NULL,
                                         i18n("Is the scope %1 a namespace or a class?", scopeName),
@@ -217,7 +242,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                                         KGuiItem(i18nc("namespace scope", "Namespace")), KGuiItem(i18nc("class scope", "Class")));
                         }
                     }
-                    Uml::Object_Type ot = (wantNamespace == KMessageBox::Yes ? Uml::ot_Package : Uml::ot_Class);
+                    UMLObject::ObjectType ot = (wantNamespace == KMessageBox::Yes ? UMLObject::ot_Package : UMLObject::ot_Class);
                     o = Object_Factory::createUMLObject(ot, scopeName, parentPkg);
                     parentPkg = static_cast<UMLPackage*>(o);
                     Model_Utils::treeViewSetCurrentItem(o);
@@ -225,9 +250,9 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                 // All scope qualified datatypes live in the global scope.
                 bPutAtGlobalScope = true;
             }
-            Uml::Object_Type t = type;
-            if (type == Uml::ot_UMLObject || isAdorned)
-                t = Uml::ot_Class;
+            UMLObject::ObjectType t = type;
+            if (type == UMLObject::ot_UMLObject || isAdorned)
+                t = UMLObject::ot_Class;
             origType = Object_Factory::createUMLObject(t, typeName, parentPkg, false);
             bNewUMLObjectWasCreated = true;
             bPutAtGlobalScope = false;
@@ -236,8 +261,8 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             // Create the full given type (including adornments.)
             if (isConst)
                 name.prepend("const ");
-            o = Object_Factory::createUMLObject(Uml::ot_Datatype, name,
-                                                umldoc->getDatatypeFolder(),
+            o = Object_Factory::createUMLObject(UMLObject::ot_Datatype, name,
+                                                umldoc->datatypeFolder(),
                                                 false); //solicitNewName
             UMLClassifier *dt = static_cast<UMLClassifier*>(o);
             UMLClassifier *c = dynamic_cast<UMLClassifier*>(origType);
@@ -245,12 +270,12 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                 dt->setOriginType(c);
             else
                 uError() << "createUMLObject(" << name << "): "
-                << "origType " << typeName << " is not a UMLClassifier";
+                    << "origType " << typeName << " is not a UMLClassifier";
             if (isRef || isPointer)
                 dt->setIsReference();
             /*
             if (isPointer) {
-                UMLObject *pointerDecl = Object_Factory::createUMLObject(Uml::ot_Datatype, type);
+                UMLObject *pointerDecl = Object_Factory::createUMLObject(UMLObject::ot_Datatype, type);
                 UMLClassifier *dt = static_cast<UMLClassifier*>(pointerDecl);
                 dt->setOriginType(classifier);
                 dt->setIsReference();
@@ -260,8 +285,8 @@ UMLObject *createUMLObject(Uml::Object_Type type,
             o = origType;
         }
     } else if (parentPkg && !bPutAtGlobalScope) {
-        UMLPackage *existingPkg = o->getUMLPackage();
-        if (existingPkg != umldoc->getDatatypeFolder()) {
+        UMLPackage *existingPkg = o->umlPackage();
+        if (existingPkg != umldoc->datatypeFolder()) {
             if (existingPkg)
                 existingPkg->removeObject(o);
             else
@@ -291,17 +316,20 @@ UMLObject *createUMLObject(Uml::Object_Type type,
         return o;
     QStringList::ConstIterator end(params.end());
     for (QStringList::ConstIterator it(params.begin()); it != end; ++it) {
-        UMLObject *p = umldoc->findUMLObject(*it, Uml::ot_UMLObject, parentPkg);
-        if (p == NULL || p->getBaseType() == Uml::ot_Datatype)
+        UMLObject *p = umldoc->findUMLObject(*it, UMLObject::ot_UMLObject, parentPkg);
+        if (p == NULL || p->baseType() == UMLObject::ot_Datatype)
             continue;
-        const Uml::Association_Type at = Uml::at_Dependency;
+        const Uml::AssociationType at = Uml::AssociationType::Dependency;
         UMLAssociation *assoc = umldoc->findAssociation(at, gRelatedClassifier, p);
         if (assoc)
             continue;
         assoc = new UMLAssociation(at, gRelatedClassifier, p);
-        assoc->setUMLPackage(umldoc->getRootFolder(Uml::mt_Logical));
+        assoc->setUMLPackage(umldoc->rootFolder(Uml::ModelType::Logical));
         umldoc->addAssociation(assoc);
     }
+    if (o == NULL) {
+        uError() << "is NULL!";
+    }
     return o;
 }
 
@@ -331,14 +359,15 @@ UMLObject* insertAttribute(UMLClassifier *owner,
                            const QString& comment /* ="" */,
                            bool isStatic /* =false */)
 {
-    Uml::Object_Type ot = owner->getBaseType();
-    Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
-    if (! (ot == Uml::ot_Class || (ot == Uml::ot_Interface && pl == Uml::pl_Java))) {
+    UMLObject::ObjectType ot = owner->baseType();
+    Uml::ProgrammingLanguage pl = UMLApp::app()->activeLanguage();
+    if (! (ot == UMLObject::ot_Class ||
+           (ot == UMLObject::ot_Interface && pl == Uml::ProgrammingLanguage::Java))) {
         uDebug() << "insertAttribute: Don not know what to do with "
-                 << owner->getName() << " (object type " << ot << ")";
+                 << owner->name() << " (object type " << UMLObject::toString(ot) << ")";
         return NULL;
     }
-    UMLObject *o = owner->findChildObject(name, Uml::ot_Attribute);
+    UMLObject *o = owner->findChildObject(name, UMLObject::ot_Attribute);
     if (o) {
         return o;
     }
@@ -350,7 +379,7 @@ UMLObject* insertAttribute(UMLClassifier *owner,
         attr->setDoc(strippedComment);
     }
 
-    UMLApp::app()->getDocument()->setModified(true);
+    UMLApp::app()->document()->setModified(true);
     return attr;
 }
 
@@ -367,7 +396,7 @@ UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility scope,
     if (attrType == NULL) {
         bPutAtGlobalScope = true;
         gRelatedClassifier = owner;
-        attrType = createUMLObject(Uml::ot_UMLObject, type, owner);
+        attrType = createUMLObject(UMLObject::ot_UMLObject, type, owner);
         gRelatedClassifier = NULL;
         bPutAtGlobalScope = false;
     }
@@ -403,14 +432,14 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
     op->setVisibility(scope);
     if (!type.isEmpty()     // return type may be missing (constructor/destructor)
         && type != "void") {
-        if (type == klass->getName()) {
+        if (type == klass->name()) {
             op->setType(klass);
         } else {
             UMLObject *typeObj = klass->findTemplate(type);
             if (typeObj == NULL) {
                 bPutAtGlobalScope = true;
                 gRelatedClassifier = klass;
-                typeObj = createUMLObject(Uml::ot_UMLObject, type, klass);
+                typeObj = createUMLObject(UMLObject::ot_UMLObject, type, klass);
                 gRelatedClassifier = NULL;
                 bPutAtGlobalScope = false;
                 op->setType(typeObj);
@@ -434,7 +463,7 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
     }
 
     UMLAttributeList params = op->getParmList();
-    UMLOperation *exist = klass->checkOperationSignature(op->getName(), params);
+    UMLOperation *exist = klass->checkOperationSignature(op->name(), params);
     if (exist) {
         // copy contents to existing operation
         exist->setVisibility(scope);
@@ -445,11 +474,11 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
         UMLAttributeList exParams = exist->getParmList();
         for (UMLAttributeListIt it(params), exIt( exParams ) ; it.hasNext() ;) {
             UMLAttribute *param = it.next() , *exParam = exIt.next();
-            exParam->setName(param->getName());
-            exParam->setVisibility(param->getVisibility());
-            exParam->setStatic(param->getStatic());
-            exParam->setAbstract(param->getAbstract());
-            exParam->setDoc(param->getDoc());
+            exParam->setName(param->name());
+            exParam->setVisibility(param->visibility());
+            exParam->setStatic(param->isStatic());
+            exParam->setAbstract(param->isAbstract());
+            exParam->setDoc(param->doc());
             exParam->setInitialValue(param->getInitialValue());
             exParam->setParmKind(param->getParmKind());
         }
@@ -475,7 +504,7 @@ UMLAttribute* addMethodParameter(UMLOperation *method,
     if (typeObj == NULL) {
         bPutAtGlobalScope = true;
         gRelatedClassifier = owner;
-        typeObj = createUMLObject(Uml::ot_UMLObject, type, owner);
+        typeObj = createUMLObject(UMLObject::ot_UMLObject, type, owner);
         gRelatedClassifier = NULL;
         bPutAtGlobalScope = false;
     }
@@ -501,18 +530,18 @@ void createGeneralization(UMLClassifier *child, UMLClassifier *parent)
 {
     // if the child is an interface, so is the parent.
     if (child->isInterface())
-        parent->setBaseType(Uml::ot_Interface);
-    Uml::Association_Type association = Uml::at_Generalization;
+        parent->setBaseType(UMLObject::ot_Interface);
+    Uml::AssociationType association = Uml::AssociationType::Generalization;
 
     if (parent->isInterface() && !child->isInterface()) {
         // if the parent is an interface, but the child is not, then
         // this is really realization.
         //
-        association = Uml::at_Realization;
+        association = Uml::AssociationType::Realization;
     }
     UMLAssociation *assoc = new UMLAssociation(association, child, parent);
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
-    assoc->setUMLPackage(umldoc->getRootFolder(Uml::mt_Logical));
+    UMLDoc *umldoc = UMLApp::app()->document();
+    assoc->setUMLPackage(umldoc->rootFolder(Uml::ModelType::Logical));
     umldoc->addAssociation(assoc);
 }
 
@@ -522,7 +551,7 @@ void createGeneralization(UMLClassifier *child, UMLClassifier *parent)
  */
 void createGeneralization(UMLClassifier *child, const QString &parentName)
 {
-    UMLObject *parentObj = createUMLObject( Uml::ot_Class, parentName );
+    UMLObject *parentObj = createUMLObject( UMLObject::ot_Class, parentName );
     UMLClassifier *parent = static_cast<UMLClassifier*>(parentObj);
     createGeneralization(child, parent);
 }
@@ -557,8 +586,8 @@ void addIncludePath(const QString& path)
  */
 bool isDatatype(const QString& name, UMLPackage *parentPkg)
 {
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
-    UMLObject * o = umldoc->findUMLObject(name, Uml::ot_Datatype, parentPkg);
+    UMLDoc *umldoc = UMLApp::app()->document();
+    UMLObject * o = umldoc->findUMLObject(name, UMLObject::ot_Datatype, parentPkg);
     return (o!=NULL);
 }
 
