@@ -17,11 +17,12 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include "lexer.h"
+#include "preprocesslexer.h"  //was lexer.h
+
 #include "lookup.h"
 #include "keywords.lut.h"
+#include "debug_utils.h"
 
-#include <kdebug.h>
 #include <klocale.h>
 
 #include <QtCore/QRegExp>
@@ -30,8 +31,8 @@
 
 #include <boost/bind.hpp>
 #include <boost/function.hpp>
-#include <boost/spirit/dynamic/if.hpp>
-#include <boost/spirit/phoenix/functions.hpp>
+#include <boost/spirit/include/classic_if.hpp>
+#include <boost/spirit/include/phoenix1_functions.hpp>
 
 #include "assignFunctor.hpp"
 
@@ -50,7 +51,7 @@ struct tilde : public std::unary_function<_Tp, _Tp> {
     }
 };
 
-using namespace boost::spirit;
+using namespace boost::spirit::classic;
 using phoenix::arg1;
 using phoenix::arg2;
 using phoenix::arg3;
@@ -66,9 +67,7 @@ SkipRule PreprocessLexer::m_SkipRule = nothing_p;
 class KDevTread: public QThread
 {
 public:
-    static void yield() {
-        msleep(0);
-    }
+    static void yield() { msleep(0); }
 };
 
 inline void qthread_yield()
@@ -100,8 +99,7 @@ struct constructQString_impl {
     }
 };
 
-const function<constructQString_impl> constructQString =
-    constructQString_impl();
+const function<constructQString_impl> constructQString = constructQString_impl();
 
 struct identifier :
             grammar<identifier, result_closure<QString>::context_t> {
@@ -200,7 +198,7 @@ struct numberLiteral :
 typedef std::pair<QString, int> Dependency;
 
 struct DependencyClosure
-            : boost::spirit::closure<DependencyClosure, QString, int> {
+            : boost::spirit::classic::closure<DependencyClosure, QString, int> {
     member1 m_word;
     member2 m_scope;
 };
@@ -406,7 +404,7 @@ void PreprocessLexer::nextToken(Token& tk)
                    [boost::bind(&PreprocessLexer::output, this, _1, _2)]);
     QChar ch = m_source.currentChar();
     if (ch.isNull() || ch.isSpace()) {
-        /* skip */
+        // skip
     } else if (m_source.parse
                (
                    if_p(var(m_recordComments))
@@ -427,7 +425,6 @@ void PreprocessLexer::nextToken(Token& tk)
         if (m_preprocessorEnabled && m_driver->hasMacro(ide) &&
                 (k == -1 || !m_driver->macro(ide).body().isEmpty())) {
 
-
             bool preproc = m_preprocessorEnabled;
             m_preprocessorEnabled = false;
 
@@ -546,7 +543,7 @@ void PreprocessLexer::nextToken(Token& tk)
 #endif
                     m_preprocessedString += QString(" ") + (*pos).second + QString(" ");
                 }
-            } else if (/*qt_rx.exactMatch(ide) ||*/
+            } else if (//qt_rx.exactMatch(ide) ||
                 ide.endsWith(QLatin1String("EXPORT")) ||
                 (ide.startsWith(QLatin1String("Q_EXPORT")) && ide != "Q_EXPORT_INTERFACE") ||
                 ide.startsWith(QLatin1String("QM_EXPORT")) ||
@@ -836,7 +833,8 @@ int PreprocessLexer::macroPrimary()
 int PreprocessLexer::macroMultiplyDivide()
 {
     int result = macroPrimary();
-    int iresult, op;
+    int iresult = 0;
+    int op = 0;
     for (;;) {
         m_source.parse(*gr_whiteSpace);
         if (m_source.parse(
