@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -12,6 +12,7 @@
 #include "classgenpage.h"
 
 // app includes
+#include "debug_utils.h"
 #include "umlobject.h"
 #include "objectwidget.h"
 #include "uml.h"
@@ -28,7 +29,6 @@
 
 // kde includes
 #include <klocale.h>
-#include <kdebug.h>
 #include <kmessagebox.h>
 #include <kcombobox.h>
 #include <klineedit.h>
@@ -54,39 +54,39 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
 
     // setup name
     QString name;
-    Uml::Object_Type t = o->getBaseType();
+    UMLObject::ObjectType t = o->baseType();
     switch (t) {
-    case Uml::ot_Class:
+    case UMLObject::ot_Class:
         name = i18n("Class &name:");
         break;
-    case Uml::ot_Actor:
+    case UMLObject::ot_Actor:
         name = i18n("Actor &name:");
         break;
-    case  Uml::ot_Package:
+    case  UMLObject::ot_Package:
         name = i18n("Package &name:");
         break;
-    case  Uml::ot_UseCase:
+    case  UMLObject::ot_UseCase:
         name = i18n("Use case &name:");
         break;
-    case  Uml::ot_Interface:
+    case  UMLObject::ot_Interface:
         name = i18n("Interface &name:");
         break;
-    case  Uml::ot_Component:
+    case  UMLObject::ot_Component:
         name = i18n("Component &name:");
         break;
-    case  Uml::ot_Node:
+    case  UMLObject::ot_Node:
         name = i18n("Node &name:");
         break;
-    case  Uml::ot_Artifact:
+    case  UMLObject::ot_Artifact:
         name = i18n("Artifact &name:");
         break;
-    case  Uml::ot_Enum:
+    case  UMLObject::ot_Enum:
         name = i18n("Enum &name:");
         break;
-    case  Uml::ot_Datatype:
+    case  UMLObject::ot_Datatype:
         name = i18n("Datatype &name:");
         break;
-    case  Uml::ot_Entity:
+    case  UMLObject::ot_Entity:
         name = i18n("Entity &name:");
         break;
     default:
@@ -116,14 +116,14 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
     m_pStereoTypeCB = new KComboBox(true, this);
     m_pNameLayout->addWidget(m_pStereoTypeCB, 1, 1);
 
-    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), o->getStereotype() );
+    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), o->stereotype() );
     m_pStereoTypeL->setBuddy(m_pStereoTypeCB);
 
-    if (t == Uml::ot_Interface || t == Uml::ot_Datatype || t == Uml::ot_Enum) {
+    if (t == UMLObject::ot_Interface || t == UMLObject::ot_Datatype || t == UMLObject::ot_Enum) {
         m_pStereoTypeCB->setEditable(false);
     }
 
-    if (t == Uml::ot_Class || t == Uml::ot_Interface) {
+    if (t == UMLObject::ot_Class || t == UMLObject::ot_Interface) {
         m_pPackageL = new QLabel(i18n("Package name:"), this);
         m_pNameLayout->addWidget(m_pPackageL, 2, 0);
 
@@ -131,42 +131,44 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
         m_pPackageCB->setEditable(true);
         m_pNameLayout->addWidget(m_pPackageCB, 2, 1);
 
-        UMLPackageList packageList = m_pUmldoc->getPackages();
+        UMLPackageList packageList = m_pUmldoc->packages();
         QStringList packages;
         foreach( UMLPackage* package, packageList ) {
-            packages << package->getName();
+            packages << package->name();
         }
         packages.sort();
         m_pPackageCB->insertItems(-1, packages);
-        UMLPackage* parentPackage = o->getUMLPackage();
+	QString packagePath = o->package();
+        UMLPackage* parentPackage = o->umlPackage();
 
         // if parent package == NULL
         // or if the parent package is the Logical View folder
-        if ( parentPackage == NULL || parentPackage== static_cast<UMLPackage*>(m_pUmldoc->getRootFolder(Uml::mt_Logical)))
+        if ( parentPackage == NULL ||
+             parentPackage == static_cast<UMLPackage*>(m_pUmldoc->rootFolder(Uml::ModelType::Logical)))
             m_pPackageCB->setEditText( QString() );
         else
-            m_pPackageCB->setEditText(parentPackage->getName());
+            m_pPackageCB->setEditText(packagePath);
     }
 
-    if (t == Uml::ot_Class || t == Uml::ot_UseCase ) {
+    if (t == UMLObject::ot_Class || t == UMLObject::ot_UseCase ) {
         QString abstractCaption;
-        if ( t == Uml::ot_Class  ) {
+        if ( t == UMLObject::ot_Class  ) {
             abstractCaption = i18n("A&bstract class");
         } else {
             abstractCaption = i18n("A&bstract use case");
         }
         m_pAbstractCB = new QCheckBox( abstractCaption, this );
-        m_pAbstractCB->setChecked( o->getAbstract() );
+        m_pAbstractCB->setChecked( o->isAbstract() );
         m_pNameLayout->addWidget( m_pAbstractCB, 3, 0 );
     }
 
-    if (t == Uml::ot_Component) {
+    if (t == UMLObject::ot_Component) {
         m_pExecutableCB = new QCheckBox(i18nc("component is executable", "&Executable"), this);
         m_pExecutableCB->setChecked( (static_cast<UMLComponent*>(o))->getExecutable() );
         m_pNameLayout->addWidget( m_pExecutableCB, 3, 0 );
     }
 
-    if (t == Uml::ot_Artifact) {
+    if (t == UMLObject::ot_Artifact) {
         // setup artifact draw as
         m_pDrawAsGB = new QGroupBox(i18n("Draw As"), this);
         QHBoxLayout* drawAsLayout = new QHBoxLayout(m_pDrawAsGB);
@@ -219,19 +221,19 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
     topLayout->addWidget(m_pButtonGB);
 
     // setup documentation
-    m_pDocGB = new QGroupBox(this);
-    QHBoxLayout * docLayout = new QHBoxLayout(m_pDocGB);
+    m_docGB = new QGroupBox(this);
+    QHBoxLayout * docLayout = new QHBoxLayout(m_docGB);
     docLayout->setMargin(margin);
-    m_pDocGB->setTitle(i18n("Documentation"));
+    m_docGB->setTitle(i18n("Documentation"));
 
-    m_pDoc = new KTextEdit(m_pDocGB);
-    docLayout->addWidget(m_pDoc);
-    topLayout->addWidget(m_pDocGB);
+    m_doc = new KTextEdit(m_docGB);
+    docLayout->addWidget(m_doc);
+    topLayout->addWidget(m_docGB);
 
     // setup fields
-    m_pClassNameLE->setText(o->getName());
-    m_pDoc->setText(o->getDoc());
-    Uml::Visibility s = o->getVisibility();
+    m_pClassNameLE->setText(o->name());
+    m_doc->setText(o->doc());
+    Uml::Visibility s = o->visibility();
     if (s == Uml::Visibility::Public)
         m_pPublicRB->setChecked(true);
     else if (s == Uml::Visibility::Private)
@@ -244,9 +246,9 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
     // manage stereotypes
     m_pStereoTypeCB->setDuplicatesEnabled(false);  // only allow one of each type in box
     m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
-    insertStereotypesSorted(m_pObject->getStereotype());
+    insertStereotypesSorted(m_pObject->stereotype());
 
-    m_pDoc->setLineWrapMode(QTextEdit::WidgetWidth);
+    m_doc->setLineWrapMode(QTextEdit::WidgetWidth);
 }
 
 ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
@@ -280,13 +282,13 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
     m_pInstanceLE = new KLineEdit(this);
     m_pInstanceLE->setText(o->instanceName());
     m_pNameLayout->addWidget(m_pInstanceLE, 1, 1);
-    UMLView *view = UMLApp::app()->getCurrentView();
+    UMLView *view = UMLApp::app()->currentView();
 
     m_pDrawActorCB = new QCheckBox( i18n( "Draw as actor" ) , this );
     m_pDrawActorCB->setChecked( o->drawAsActor() );
     m_pNameLayout->addWidget( m_pDrawActorCB, 2, 0 );
 
-    if (view->getType() == Uml::dt_Collaboration) {
+    if (view->type() == Uml::DiagramType::Collaboration) {
         m_pMultiCB = new QCheckBox(i18n("Multiple instance"), this);
         m_pMultiCB->setChecked(o->multipleInstance());
         m_pNameLayout->addWidget(m_pMultiCB, 2,1);
@@ -298,18 +300,18 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
         m_pNameLayout->addWidget(m_pDeconCB, 2,1);
     }
     // setup documentation
-    m_pDocGB = new QGroupBox(this);
-    topLayout->addWidget(m_pDocGB, 1, 0);
-    QHBoxLayout * docLayout = new QHBoxLayout(m_pDocGB);
+    m_docGB = new QGroupBox(this);
+    topLayout->addWidget(m_docGB, 1, 0);
+    QHBoxLayout * docLayout = new QHBoxLayout(m_docGB);
     docLayout->setMargin(margin);
-    m_pDocGB->setTitle(i18n("Documentation"));
+    m_docGB->setTitle(i18n("Documentation"));
 
-    m_pDoc = new KTextEdit(m_pDocGB);
-    m_pDoc->setLineWrapMode(QTextEdit::WidgetWidth);
-    m_pDoc->setText(o->documentation());
-    docLayout->addWidget(m_pDoc);
+    m_doc = new KTextEdit(m_docGB);
+    m_doc->setLineWrapMode(QTextEdit::WidgetWidth);
+    m_doc->setText(o->documentation());
+    docLayout->addWidget(m_doc);
     if (m_pMultiCB) {
-        connect( m_pDrawActorCB, SIGNAL( toggled( bool ) ), this, SLOT( slotActorToggled( bool ) ) );
+        connect( m_pDrawActorCB, SIGNAL(toggled(bool)), this, SLOT(slotActorToggled(bool)));
     }
 }
 
@@ -330,9 +332,9 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget)
     m_pNameLayout->setSpacing(6);
     topLayout->addLayout(m_pNameLayout, 3, 2);
     m_pNameL = new QLabel(this);
-    if (widget->baseType() == Uml::wt_Component) {
+    if (widget->baseType() == WidgetBase::wt_Component) {
         m_pNameL->setText(i18n("Component name:"));
-    } else if (widget->baseType() == Uml::wt_Node) {
+    } else if (widget->baseType() == WidgetBase::wt_Node) {
         m_pNameL->setText(i18n("Node name:"));
     } else {
         uWarning() << "ClassGenPage called on unknown widget type";
@@ -349,7 +351,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget)
     m_pStereoTypeCB = new KComboBox(true, this);
     m_pNameLayout->addWidget(m_pStereoTypeCB, 1, 1);
 
-    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), widget->umlObject()->getStereotype() );
+    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), widget->umlObject()->stereotype() );
     m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
 
     m_pInstanceL = new QLabel(this);
@@ -361,16 +363,16 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget)
     m_pNameLayout->addWidget(m_pInstanceLE, 2, 1);
 
     //setup documentation
-    m_pDocGB = new QGroupBox(this);
-    topLayout->addWidget(m_pDocGB, 1, 0);
-    QHBoxLayout* docLayout = new QHBoxLayout(m_pDocGB);
+    m_docGB = new QGroupBox(this);
+    topLayout->addWidget(m_docGB, 1, 0);
+    QHBoxLayout* docLayout = new QHBoxLayout(m_docGB);
     docLayout->setMargin(margin);
-    m_pDocGB->setTitle(i18n("Documentation"));
+    m_docGB->setTitle(i18n("Documentation"));
 
-    m_pDoc = new KTextEdit(m_pDocGB);
-    m_pDoc->setLineWrapMode(QTextEdit::WidgetWidth);
-    m_pDoc->setText(widget->documentation());
-    docLayout->addWidget(m_pDoc);
+    m_doc = new KTextEdit(m_docGB);
+    m_doc->setLineWrapMode(QTextEdit::WidgetWidth);
+    m_doc->setText(widget->documentation());
+    docLayout->addWidget(m_doc);
 }
 
 ClassGenPage::~ClassGenPage()
@@ -381,8 +383,8 @@ void ClassGenPage::insertStereotypesSorted(const QString& type)
 {
     QStringList types;
     types << "";  // an empty stereotype is the default
-    foreach (UMLStereotype* ust, m_pUmldoc->getStereotypes()) {
-        types << ust->getName();
+    foreach (UMLStereotype* ust, m_pUmldoc->stereotypes()) {
+        types << ust->name();
     }
     // add the given parameter
     if ( !types.contains(type) ) {
@@ -410,23 +412,23 @@ void ClassGenPage::updateObject()
     if (m_pObject) {
         QString name = m_pClassNameLE->text();
 
-        m_pObject->setDoc(m_pDoc->toPlainText());
+        m_pObject->setDoc(m_doc->toPlainText());
 
         if (m_pStereoTypeCB) {
             m_pObject->setStereotype(m_pStereoTypeCB->currentText());
         }
 
-        Uml::Object_Type t = m_pObject->getBaseType();
-        if (t == Uml::ot_Class || t == Uml::ot_Interface) {
+        UMLObject::ObjectType t = m_pObject->baseType();
+        if (t == UMLObject::ot_Class || t == UMLObject::ot_Interface) {
             QString packageName = m_pPackageCB->currentText().trimmed();
             UMLObject* newPackage = NULL;
 
             if ( !packageName.isEmpty()) {
-                if ( ( newPackage = m_pUmldoc->findUMLObject(packageName, Uml::ot_Package) ) == NULL ) {
-                    newPackage = Import_Utils::createUMLObject(Uml::ot_Package, packageName);
+                if ( ( newPackage = m_pUmldoc->findUMLObject(packageName, UMLObject::ot_Package) ) == NULL ) {
+                    newPackage = Import_Utils::createUMLObject(UMLObject::ot_Package, packageName);
                 }
             } else {
-                newPackage = m_pUmldoc->getRootFolder( Uml::mt_Logical );
+                newPackage = m_pUmldoc->rootFolder( Uml::ModelType::Logical );
             }
 
             // adjust list view items
@@ -441,8 +443,8 @@ void ClassGenPage::updateObject()
         UMLObject *o = m_pUmldoc->findUMLObject(name);
         if (o && m_pObject != o) {
              KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
-                                i18n("Name is Not Unique"), false);
-             m_pClassNameLE->setText( m_pObject->getName() );
+                                i18n("Name is Not Unique"), 0);
+             m_pClassNameLE->setText( m_pObject->name() );
         } else {
              m_pObject->setName(name);
         }
@@ -458,11 +460,11 @@ void ClassGenPage::updateObject()
             s = Uml::Visibility::Implementation;
         m_pObject->setVisibility(s);
 
-        if (m_pObject->getBaseType() == Uml::ot_Component) {
+        if (m_pObject->baseType() == UMLObject::ot_Component) {
             (static_cast<UMLComponent*>(m_pObject))->setExecutable( m_pExecutableCB->isChecked() );
         }
 
-        if (m_pObject->getBaseType() == Uml::ot_Artifact) {
+        if (m_pObject->baseType() == UMLObject::ot_Artifact) {
             UMLArtifact::Draw_Type drawAsType;
             if ( m_pFileRB->isChecked() ) {
                 drawAsType = UMLArtifact::file;
@@ -487,12 +489,12 @@ void ClassGenPage::updateObject()
             m_pWidget->setShowDestruction( m_pDeconCB->isChecked() );
         }
         QString name = m_pClassNameLE->text();
-        m_pWidget->setDocumentation(m_pDoc->toPlainText());
+        m_pWidget->setDocumentation(m_doc->toPlainText());
         UMLObject * o = m_pWidget->umlObject();
         UMLObject * old = m_pUmldoc->findUMLObject(name);
         if (old && o != old) {
             KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
-                               i18n("Name is Not Unique"), false);
+                               i18n("Name is Not Unique"), 0);
         } else {
             o->setName(name);
         }
@@ -500,12 +502,12 @@ void ClassGenPage::updateObject()
     else if (m_pInstanceWidget) {
         m_pInstanceWidget->setInstanceName(m_pInstanceLE->text());
         QString name = m_pClassNameLE->text();
-        m_pInstanceWidget->setDocumentation(m_pDoc->toPlainText());
+        m_pInstanceWidget->setDocumentation(m_doc->toPlainText());
         UMLObject* o = m_pInstanceWidget->umlObject();
         UMLObject* old = m_pUmldoc->findUMLObject(name);
         if (old && o != old) {
             KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
-                               i18n("Name is Not Unique"), false);
+                               i18n("Name is Not Unique"), 0);
         } else {
             o->setName(name);
         }
