@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2009                                               *
+ *   copyright (C) 2006-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -12,15 +12,16 @@
 #include "folder.h"
 
 // app includes
+#include "debug_utils.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umlview.h"
 #include "optionstate.h"
 #include "object_factory.h"
 #include "model_utils.h"
+#include "umlscene.h"
 
 // kde includes
-#include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
@@ -34,9 +35,10 @@
  *                if this argument is left away.
  */
 UMLFolder::UMLFolder(const QString & name, Uml::IDType id)
-        : UMLPackage(name, id)
+  : UMLPackage(name, id)
 {
-    init();
+    m_BaseType = UMLObject::ot_Folder;
+    UMLObject::setStereotype("folder");
 }
 
 /**
@@ -44,21 +46,8 @@ UMLFolder::UMLFolder(const QString & name, Uml::IDType id)
  */
 UMLFolder::~UMLFolder()
 {
-    // TODO : check if safe
-    while ( !m_diagrams.isEmpty() ) {
-        delete m_diagrams.takeFirst();
-    }
-}
-
-/**
- * Initializes key variables of the class.
- */
-void UMLFolder::init()
-{
-    m_BaseType = Uml::ot_Folder;
-    // Porting to QList. No autodelete supported. TODO: check if all elements of m_diagrams are properly disposed
-    //m_diagrams.setAutoDelete(true);
-    UMLObject::setStereotype("folder");
+    qDeleteAll(m_diagrams);
+    m_diagrams.clear();
 }
 
 /**
@@ -86,7 +75,7 @@ void UMLFolder::setLocalName(const QString& localName)
  * Return the localized name of this folder.
  * Only useful for the predefined root folders.
  */
-QString UMLFolder::getLocalName()
+QString UMLFolder::localName() const
 {
     return m_localName;
 }
@@ -104,7 +93,6 @@ void UMLFolder::addView(UMLView *view)
  */
 void UMLFolder::removeView(UMLView *view)
 {
-    // m_diagrams is set to autodelete!
     m_diagrams.removeAll(view);
     delete view;
 }
@@ -119,14 +107,15 @@ void UMLFolder::appendViews(UMLViewList& viewList, bool includeNested)
 {
     if (includeNested) {
         foreach (UMLObject* o, m_objects ) {
-            if (o->getBaseType() == Uml::ot_Folder) {
+            if (o->baseType() == UMLObject::ot_Folder) {
                 UMLFolder *f = static_cast<UMLFolder*>(o);
                 f->appendViews(viewList);
             }
         }
     }
-    foreach (UMLView* v, m_diagrams )
+    foreach (UMLView* v, m_diagrams) {
         viewList.append(v);
+    }
 }
 
 /**
@@ -137,18 +126,18 @@ void UMLFolder::appendViews(UMLViewList& viewList, bool includeNested)
 void UMLFolder::activateViews()
 {
     foreach (UMLObject* o, m_objects ) {
-        if (o->getBaseType() == Uml::ot_Folder) {
+        if (o->baseType() == UMLObject::ot_Folder) {
             UMLFolder *f = static_cast<UMLFolder*>(o);
             f->activateViews();
         }
     }
 
     foreach (UMLView* v, m_diagrams) {
-        v->activateAfterLoad();
+        v->umlScene()->activateAfterLoad();
     }
     // Make sure we have a treeview item for each diagram.
     // It may happen that we are missing them after switching off tabbed widgets.
-    Settings::OptionState optionState = Settings::getOptionState();
+    Settings::OptionState optionState = Settings::optionState();
     if (optionState.generalState.tabdiagrams) {
         return;
     }
@@ -163,18 +152,21 @@ void UMLFolder::activateViews()
 UMLView *UMLFolder::findView(Uml::IDType id)
 {
     foreach (UMLView* v, m_diagrams ) {
-        if (v->getID() == id)
+        if (v->umlScene()->getID() == id) {
             return v;
+        }
     }
 
-    UMLView* v = NULL;
+    UMLView* v = 0;
     foreach (UMLObject* o, m_objects ) {
-        if (o->getBaseType() != Uml::ot_Folder)
+        if (o->baseType() != UMLObject::ot_Folder) {
             continue;
+        }
         UMLFolder *f = static_cast<UMLFolder*>(o);
         v = f->findView(id);
-        if (v)
+        if (v) {
             break;
+        }
     }
     return v;
 }
@@ -186,22 +178,25 @@ UMLView *UMLFolder::findView(Uml::IDType id)
  * @param searchAllScopes   Search in all subfolders (default: true.)
  * @return  Pointer to the view found, or NULL if not found.
  */
-UMLView *UMLFolder::findView(Uml::Diagram_Type type, const QString &name, bool searchAllScopes)
+UMLView *UMLFolder::findView(Uml::DiagramType type, const QString &name, bool searchAllScopes)
 {
-    foreach (UMLView* v, m_diagrams ) {
-        if (v->getType() == type && v->getName() == name)
+    foreach (UMLView* v, m_diagrams) {
+        if (v->umlScene()->type() == type && v->umlScene()->name() == name) {
             return v;
+        }
     }
 
-    UMLView* v = NULL;
+    UMLView* v = 0;
     if (searchAllScopes) {
         foreach (UMLObject* o, m_objects  ) {
-            if (o->getBaseType() != Uml::ot_Folder)
+            if (o->baseType() != UMLObject::ot_Folder) {
                 continue;
+            }
             UMLFolder *f = static_cast<UMLFolder*>(o);
             v = f->findView(type, name, searchAllScopes);
-            if (v)
+            if (v) {
                 break;
+            }
         }
     }
     return v;
@@ -213,8 +208,9 @@ UMLView *UMLFolder::findView(Uml::Diagram_Type type, const QString &name, bool s
 void UMLFolder::setViewOptions(const Settings::OptionState& optionState)
 {
     // for each view update settings
-    foreach (UMLView* v, m_diagrams )
-        v->setOptionState(optionState);
+    foreach (UMLView* v, m_diagrams ) {
+        v->umlScene()->setOptionState(optionState);
+    }
 }
 
 /**
@@ -223,7 +219,7 @@ void UMLFolder::setViewOptions(const Settings::OptionState& optionState)
 void UMLFolder::removeAllViews()
 {
     foreach (UMLObject* o, m_objects) {
-        if (o->getBaseType() != Uml::ot_Folder)
+        if (o->baseType() != UMLObject::ot_Folder)
             continue;
         UMLFolder *f = static_cast<UMLFolder*>(o);
         f->removeAllViews();
@@ -231,17 +227,15 @@ void UMLFolder::removeAllViews()
 
     foreach (UMLView* v, m_diagrams ) {
         // TODO ------------------ check this code - bad: calling back to UMLDoc::removeView()
-        v->removeAllAssociations(); // note : It may not be apparent, but when we remove all associations
+        v->umlScene()->removeAllAssociations(); // note : It may not be apparent, but when we remove all associations
         // from a view, it also causes any UMLAssociations that lack parent
         // association widgets (but once had them) to remove themselves from
         // this document.
-        UMLApp::app()->getDocument()->removeView(v, false);
+        UMLApp::app()->document()->removeView(v, false);
     }
 
-    // m_diagrams.clear()
-    while ( !m_diagrams.empty() ) {
-        delete m_diagrams.takeFirst();
-    }
+    qDeleteAll(m_diagrams);
+    m_diagrams.clear();
 }
 
 /**
@@ -255,7 +249,7 @@ void UMLFolder::setFolderFile(const QString& fileName)
 /**
  * Get the folder file name for a separate submodel.
  */
-QString UMLFolder::getFolderFile()
+QString UMLFolder::folderFile() const
 {
     return m_folderFile;
 }
@@ -268,7 +262,7 @@ QString UMLFolder::getFolderFile()
 void UMLFolder::saveContents(QDomDocument& qDoc, QDomElement& qElement)
 {
     QDomElement ownedElement = qDoc.createElement("UML:Namespace.ownedElement");
-    UMLObject *obj = NULL;
+    UMLObject *obj = 0;
     // Save contained objects if any.
     for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
         obj = oit.next();
@@ -285,7 +279,7 @@ void UMLFolder::saveContents(QDomDocument& qDoc, QDomElement& qElement)
         QDomElement diagramsElement = qDoc.createElement("diagrams");
 
         foreach (UMLView* pView, m_diagrams ) {
-            pView->saveToXMI(qDoc, diagramsElement);
+            pView->umlScene()->saveToXMI(qDoc, diagramsElement);
         }
         QDomElement extension = qDoc.createElement("XMI.extension");
         extension.setAttribute("xmi.extender", "umbrello");
@@ -302,10 +296,10 @@ void UMLFolder::saveContents(QDomDocument& qDoc, QDomElement& qElement)
  */
 void UMLFolder::save(QDomDocument& qDoc, QDomElement& qElement)
 {
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLDoc *umldoc = UMLApp::app()->document();
     QString elementName("UML:Package");
-    const Uml::Model_Type mt = umldoc->rootFolderType(this);
-    if (mt != Uml::N_MODELTYPES)
+    const Uml::ModelType mt = umldoc->rootFolderType(this);
+    if (mt != Uml::ModelType::N_MODELTYPES)
         elementName = "UML:Model";
     QDomElement folderElement = UMLObject::save(elementName, qDoc);
     saveContents(qDoc, folderElement);
@@ -325,7 +319,7 @@ void UMLFolder::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
     }
     // See if we can create the external file.
     // If not then internalize the folder.
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLDoc *umldoc = UMLApp::app()->document();
     QString fileName = umldoc->url().directory() + '/' + m_folderFile;
     QFile file(fileName);
     if (!file.open(QIODevice::WriteOnly)) {
@@ -353,11 +347,11 @@ void UMLFolder::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
                                               "version=\"1.0\" encoding=\"UTF-8\"");
     folderDoc.appendChild(xmlHeading);
     folderRoot = folderDoc.createElement("external_file");
-    folderRoot.setAttribute("name", m_Name);
+    folderRoot.setAttribute("name", name());
     folderRoot.setAttribute("filename", m_folderFile);
     folderRoot.setAttribute("mainModel", umldoc->url().fileName());
-    folderRoot.setAttribute("parentId", ID2STR(m_pUMLPackage->getID()));
-    folderRoot.setAttribute("parent", m_pUMLPackage->getFullyQualifiedName("::", true));
+    folderRoot.setAttribute("parentId", ID2STR(m_pUMLPackage->id()));
+    folderRoot.setAttribute("parent", m_pUMLPackage->fullyQualifiedName("::", true));
     saveContents(folderDoc, folderRoot);
     folderDoc.appendChild(folderRoot);
     QTextStream stream(&file);
@@ -372,8 +366,8 @@ void UMLFolder::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
  */
 bool UMLFolder::loadDiagramsFromXMI(QDomNode& diagrams)
 {
-    const Settings::OptionState optionState = Settings::getOptionState();
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    const Settings::OptionState optionState = Settings::optionState();
+    UMLDoc *umldoc = UMLApp::app()->document();
     bool totalSuccess = true;
     for (QDomElement diagram = diagrams.toElement(); !diagram.isNull();
          diagrams = diagrams.nextSibling(), diagram = diagrams.toElement()) {
@@ -383,8 +377,8 @@ bool UMLFolder::loadDiagramsFromXMI(QDomNode& diagrams)
             continue;
         }
         UMLView * pView = new UMLView(this);
-        pView->setOptionState(optionState);
-        if (pView->loadFromXMI(diagram)) {
+        pView->umlScene()->setOptionState(optionState);
+        if (pView->umlScene()->loadFromXMI(diagram)) {
             pView->hide();
             umldoc->addView(pView);
         } else {
@@ -448,7 +442,7 @@ bool UMLFolder::loadFolderFile(const QString& path)
  */
 bool UMLFolder::load(QDomElement& element)
 {
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLDoc *umldoc = UMLApp::app()->document();
     bool totalSuccess = true;
     for (QDomNode node = element.firstChild(); !node.isNull();
             node = node.nextSibling()) {
@@ -458,14 +452,14 @@ bool UMLFolder::load(QDomElement& element)
         QString type = tempElement.tagName();
         if (Model_Utils::isCommonXMIAttribute(type))
             continue;
-        if (Uml::tagEq(type, "Namespace.ownedElement") ||
-                Uml::tagEq(type, "Namespace.contents")) {
+        if (UMLDoc::tagEq(type, "Namespace.ownedElement") ||
+                UMLDoc::tagEq(type, "Namespace.contents")) {
             //CHECK: Umbrello currently assumes that nested elements
             // are ownedElements anyway.
             // Therefore these tags are not further interpreted.
             if (! load(tempElement)) {
                 uDebug() << "An error happened while loading the " << type
-                    << " of the " << m_Name;
+                    << " of the " << name();
                 totalSuccess = false;
             }
             continue;
@@ -485,7 +479,7 @@ bool UMLFolder::load(QDomElement& element)
                     if (loadFolderFile(path))
                         m_folderFile = fileName;
                 } else {
-                    uDebug() << m_Name << ": ignoring XMI.extension " << xtag;
+                    uDebug() << name() << ": ignoring XMI.extension " << xtag;
                     continue;
                 }
             }
@@ -493,17 +487,17 @@ bool UMLFolder::load(QDomElement& element)
         }
         // Do not re-create the predefined Datatypes folder in the Logical View,
         // it already exists.
-        UMLFolder *logicalView = umldoc->getRootFolder(Uml::mt_Logical);
-        if (this == logicalView && Uml::tagEq(type, "Package")) {
+        UMLFolder *logicalView = umldoc->rootFolder(Uml::ModelType::Logical);
+        if (this == logicalView && UMLDoc::tagEq(type, "Package")) {
             QString thisName = tempElement.attribute("name", "");
             if (thisName == "Datatypes") {
-                UMLFolder *datatypeFolder = umldoc->getDatatypeFolder();
+                UMLFolder *datatypeFolder = umldoc->datatypeFolder();
                 if (!datatypeFolder->loadFromXMI(tempElement))
                     totalSuccess = false;
                 continue;
             }
         }
-        UMLObject *pObject = NULL;
+        UMLObject *pObject = 0;
         // Avoid duplicate creation of forward declared object
         QString idStr = tempElement.attribute("xmi.id", "");
         if (!idStr.isEmpty()) {
@@ -513,7 +507,7 @@ bool UMLFolder::load(QDomElement& element)
                 uDebug() << "object " << idStr << "already exists";
             }
         }
-        if (pObject == NULL) {
+        if (pObject == 0) {
             QString stereoID = tempElement.attribute("stereotype", "");
             pObject = Object_Factory::makeObjectFromXMI(type, stereoID);
             if (!pObject) {
@@ -531,4 +525,15 @@ bool UMLFolder::load(QDomElement& element)
     return totalSuccess;
 }
 
+/**
+ * Overloading operator for debugging output.
+ */
+QDebug operator<<(QDebug out, const UMLFolder& item)
+{
+    out.nospace() << "UMLFolder: localName=" << item.m_localName
+        << ", folderFile=" << item.m_folderFile
+        << ", diagrams=" << item.m_diagrams.count();
+    return out.space();
+}
+
 #include "folder.moc"
