@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2008                                               *
+ *   copyright (C) 2002-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -12,68 +12,90 @@
 #include "umlobject.h"
 
 // app includes
+#include "debug_utils.h"
 #include "uniqueid.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umllistview.h"
-#include "umllistviewitem.h"
 #include "package.h"
 #include "folder.h"
 #include "stereotype.h"
 #include "object_factory.h"
 #include "model_utils.h"
-#include "codeimport/import_utils.h"
+#include "import_utils.h"
 #include "docwindow.h"
 #include "classpropdlg.h"
 #include "cmds.h"
 
 // kde includes
-#include <kdebug.h>
+#include <klocale.h>
 
 // qt includes
-#include <QApplication>
+#include <QtCore/QPointer>
+#include <QtGui/QApplication>
 
 using namespace Uml;
 
-UMLObject::UMLObject(UMLObject * parent, const QString &name, Uml::IDType id)
-        : QObject(parent)
-{
-    setObjectName("UMLObject");
-    init();
-    if (id == Uml::id_None)
-        m_nId = UniqueID::gen();
-    else
-        m_nId = id;
-    m_Name = name;
-}
-
-UMLObject::UMLObject(const QString &name, Uml::IDType id)
-        :  QObject(UMLApp::app()->getDocument())
+/**
+ * Creates a UMLObject.
+ * @param parent   The parent of the object.
+ * @param name     The name of the object.
+ * @param id       The ID of the object (optional.) If omitted
+ *                 then a new ID will be assigned internally.
+ */
+UMLObject::UMLObject(UMLObject* parent, const QString& name, Uml::IDType id)
+  : QObject(parent),
+    m_nId(id),
+    m_name(name)
 {
     init();
     if (id == Uml::id_None)
         m_nId = UniqueID::gen();
-    else
-        m_nId = id;
-    m_Name = name;
 }
 
+/**
+ * Creates a UMLObject.
+ * @param name     The name of the object.
+ * @param id       The ID of the object (optional.) If omitted
+ *                 then a new ID will be assigned internally.
+ */
+UMLObject::UMLObject(const QString& name, Uml::IDType id)
+  : QObject(UMLApp::app()->document()),
+    m_nId(id),
+    m_name(name)
+{
+    init();
+    if (id == Uml::id_None)
+        m_nId = UniqueID::gen();
+}
+
+/**
+ * Creates a UMLObject.
+ * @param   parent   The parent of the object.
+ */
 UMLObject::UMLObject(UMLObject * parent)
-        : QObject(parent)
+  : QObject(parent),
+    m_nId(Uml::id_None),
+    m_name(QString())
 {
     init();
 }
 
+/**
+ * Standard destructor.
+ */
 UMLObject::~UMLObject()
 {
 }
 
+/**
+ * Initializes key variables of the class.
+ */
 void UMLObject::init()
 {
-    m_BaseType = Uml::ot_UMLObject;
-    m_nId = Uml::id_None;
+    setObjectName("UMLObject");
+    m_BaseType = ot_UMLObject;
     m_pUMLPackage = 0;
-    m_Name.clear();
     m_Vis = Uml::Visibility::Public;
     m_pStereotype = 0;
     m_Doc.clear();
@@ -84,75 +106,124 @@ void UMLObject::init()
     m_pSecondary = 0;
 }
 
-bool UMLObject::showProperties(int page, bool assoc)
+/**
+ * This method is called if you wish to see the properties of a
+ * UMLObject.  A dialog box will be displayed from which you
+ * can change the object's properties.
+ *
+ * @param page    The page to show.
+ * @param assoc   Whether to show association page.
+ * @return        True if we modified the object.
+ */
+bool UMLObject::showPropertiesPagedDialog(int page, bool assoc)
 {
     Q_UNUSED(page);
-    DocWindow *docwindow = UMLApp::app()->getDocWindow();
+    DocWindow *docwindow = UMLApp::app()->docWindow();
     docwindow->updateDocumentation(false);
-    ClassPropDlg* dlg = new ClassPropDlg((QWidget*)UMLApp::app(), this, assoc);
+    QPointer<ClassPropDlg> dlg = new ClassPropDlg((QWidget*)UMLApp::app(), this, assoc);
     bool modified = false;
     if (dlg->exec()) {
         docwindow->showDocumentation(this, true);
-        UMLApp::app()->getDocument()->setModified(true);
+        UMLApp::app()->document()->setModified(true);
         modified = true;
     }
     dlg->close();
+    delete dlg;
     return modified;
 }
 
-bool UMLObject::acceptAssociationType(Uml::Association_Type)
+/**
+ * This should be reimplemented by subclasses if they wish to
+ * accept certain types of associations. Note that this only
+ * tells if this UMLObject can accept the association
+ * type. When creating an association another check is made to
+ * see if the association is valid. For example a UMLClass
+ * (UMLClassifier) can accept generalizations and should
+ * return true. If while creating a generalization the
+ * superclass is already subclassed from this, the association
+ * is not valid and will not be created.  The default accepts
+ * nothing (returns false)
+ */
+bool UMLObject::acceptAssociationType(Uml::AssociationType type)
 {
+    Q_UNUSED(type);
     // A UMLObject accepts nothing. This should be reimplemented by the subclasses
     return false;
 }
 
+/**
+ * Assigns a new Id to the object
+ */
 void UMLObject::setID(Uml::IDType NewID)
 {
     m_nId = NewID;
     emitModified();
 }
 
+/**
+ * Set the UMLObject's name
+ */
 void UMLObject::setName(const QString &strName)
 {
     UMLApp::app()->executeCommand(new Uml::CmdRenameUMLObject(this, strName));
 }
 
-void UMLObject::setNamecmd(const QString &strName)
+/**
+ * Method used by setName: it is called by  cmdSetName, Don't use it!
+ */
+void UMLObject::setNameCmd(const QString &strName)
 {
-    m_Name = strName;
+    m_name = strName;
     emitModified();
 }
 
-QString UMLObject::getName() const
+/**
+ * Returns a copy of m_name
+ */
+QString UMLObject::name() const
 {
-    return m_Name;
+    return m_name;
 }
 
-QString UMLObject::getFullyQualifiedName(const QString& separator,
+/**
+ * Returns the fully qualified name, i.e. all package prefixes and then m_name.
+ *
+ * @param separator  The separator string to use (optional.)
+ *                   If not given then the separator is chosen according
+ *                   to the currently selected active programming language
+ *                   of import and code generation.
+ * @param includeRoot  Whether to prefix the root folder name to the FQN.
+ *                     See UMLDoc::getRootFolder(). Default: false.
+ * @return  The fully qualified name of this UMLObject.
+ */
+QString UMLObject::fullyQualifiedName(const QString& separator,
         bool includeRoot /* = false */) const
 {
     QString fqn;
     if (m_pUMLPackage && m_pUMLPackage != this) {
         bool skipPackage = false;
         if (!includeRoot) {
-            UMLDoc *umldoc = UMLApp::app()->getDocument();
-            if (umldoc->rootFolderType(m_pUMLPackage) != Uml::N_MODELTYPES ||
-                    m_pUMLPackage == umldoc->getDatatypeFolder())
+            UMLDoc *umldoc = UMLApp::app()->document();
+            if (umldoc->rootFolderType(m_pUMLPackage) != Uml::ModelType::N_MODELTYPES ||
+                    m_pUMLPackage == umldoc->datatypeFolder())
                 skipPackage = true;
         }
         if (!skipPackage) {
             QString tempSeparator = separator;
             if (tempSeparator.isEmpty())
                 tempSeparator = UMLApp::app()->activeLanguageScopeSeparator();
-            fqn = m_pUMLPackage->getFullyQualifiedName(tempSeparator, includeRoot);
+            fqn = m_pUMLPackage->fullyQualifiedName(tempSeparator, includeRoot);
             fqn.append(tempSeparator);
         }
     }
-    fqn.append(m_Name);
+    fqn.append(m_name);
     return fqn;
 }
 
-bool UMLObject::operator==(const UMLObject & rhs)
+/**
+ * Overloaded '==' operator
+ */
+bool UMLObject::operator==(const UMLObject & rhs) const
 {
     if (this == &rhs)
         return true;
@@ -163,7 +234,7 @@ bool UMLObject::operator==(const UMLObject & rhs)
     //***** Currently some operator== in umbrello compare the IDs
     //***** while others don't.
 
-    if (m_Name != rhs.m_Name)
+    if (m_name != rhs.m_name)
         return false;
 
     // Packages create different namespaces, therefore they should be
@@ -207,6 +278,10 @@ bool UMLObject::operator==(const UMLObject & rhs)
     return true;
 }
 
+/**
+ * Copy the internal presentation of this object into the new
+ * object.
+ */
 void UMLObject::copyInto(UMLObject *lhs) const
 {
     // Data members with copy constructor
@@ -219,7 +294,7 @@ void UMLObject::copyInto(UMLObject *lhs) const
     lhs->m_pUMLPackage = m_pUMLPackage;
 
     // We don't want the same name existing twice.
-    lhs->m_Name = Model_Utils::uniqObjectName(m_BaseType, m_pUMLPackage, m_Name);
+    lhs->m_name = Model_Utils::uniqObjectName(m_BaseType, m_pUMLPackage, m_name);
 
     // Create a new ID.
     lhs->m_nId = UniqueID::gen();
@@ -229,11 +304,17 @@ void UMLObject::copyInto(UMLObject *lhs) const
         uDebug() << "copyInto has a wrong parent";
 }
 
-bool UMLObject::getAbstract() const
+/**
+ * Returns the abstract state of the object.
+ */
+bool UMLObject::isAbstract() const
 {
     return m_bAbstract;
 }
 
+/**
+ * Sets the paste state of the object.
+ */
 void UMLObject::setAbstract(bool bAbstract)
 {
     m_bAbstract = bAbstract;
@@ -245,66 +326,133 @@ void UMLObject::setInPaste(bool bInPaste /* =true */)
     m_bInPaste = bInPaste;
 }
 
-bool UMLObject::getStatic() const
+/**
+ * Returns true if this UMLObject has classifier scope,
+ * otherwise false (the default).
+ */
+bool UMLObject::isStatic() const
 {
     return m_bStatic;
 }
 
+/**
+ * Sets the value for m_bStatic.
+ */
 void UMLObject::setStatic(bool bStatic)
 {
     m_bStatic = bStatic;
     emitModified();
 }
 
+/**
+ * Forces the emission of the modified signal.  Useful when
+ * updating several attributes at a time: you can block the
+ * signals, update all atts, and then force the signal.
+ */
 void UMLObject::emitModified()
 {
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
+    UMLDoc *umldoc = UMLApp::app()->document();
     if (!umldoc->loading() && !umldoc->closing())
         emit modified();
 }
 
+/**
+ * Sets the documentation for the object.
+ *
+ * @param d The documentation for the object.
+ */
 void UMLObject::setDoc(const QString &d)
 {
     m_Doc = d;
     //emit modified();  No, this is done centrally at DocWindow::updateDocumentation()
 }
 
-Uml::Object_Type UMLObject::getBaseType() const
+/**
+ * Returns the type of the object.
+ *
+ * @return  Returns the type of the object.
+ */
+UMLObject::ObjectType UMLObject::baseType() const
 {
     return m_BaseType;
 }
 
-void UMLObject::setBaseType(Uml::Object_Type ot)
+/**
+ * @return The type used for rtti as string.
+ */
+QLatin1String UMLObject::baseTypeStr() const
+{
+    return QLatin1String(ENUM_NAME(UMLObject, ObjectType, m_BaseType));
+}
+
+/**
+ * Set the type of the object.
+ *
+ * @param ot The ObjectType to set.
+ */
+void UMLObject::setBaseType(ObjectType ot)
 {
     m_BaseType = ot;
 }
 
-Uml::IDType UMLObject::getID() const
+/**
+ * Returns the ID of the object.
+ *
+ * @return  Returns the ID of the object.
+ */
+Uml::IDType UMLObject::id() const
 {
     return m_nId;
 }
 
-QString UMLObject::getDoc() const
+/**
+ * Returns the documentation for the object.
+ *
+ * @return  Returns the documentation for the object.
+ */
+QString UMLObject::doc() const
 {
     return m_Doc;
 }
 
-Uml::Visibility UMLObject::getVisibility() const
+/**
+ * Returns the visibility of the object.
+ *
+ * @return  Returns the visibility of the object.
+ */
+Uml::Visibility UMLObject::visibility() const
 {
     return m_Vis;
 }
 
+/**
+ * Sets the visibility of the object.
+ *
+ * @param s   The visibility of the object.
+ */
 void UMLObject::setVisibility(Uml::Visibility s)
 {
     UMLApp::app()->executeCommand(new CmdSetVisibility(this, s));
 }
 
-void UMLObject::setVisibilitycmd(Uml::Visibility s)
+/**
+ * Method used by setVisibility: it is called by  cmdSetVisibility, Don't use it!
+ */
+void UMLObject::setVisibilityCmd(Uml::Visibility s)
 {
     m_Vis = s;
     emitModified();
 }
 
+/**
+ * Sets the class' UMLStereotype. Adjusts the reference counts
+ * at the previously set stereotype and at the new stereotype.
+ * If the previously set UMLStereotype's reference count drops
+ * to zero then the UMLStereotype is removed at the UMLDoc and
+ * it is then physically deleted.
+ *
+ * @param stereo Sets the classes UMLStereotype.
+ */
 void UMLObject::setUMLStereotype(UMLStereotype *stereo)
 {
     if (stereo == m_pStereotype)
@@ -315,7 +463,7 @@ void UMLObject::setUMLStereotype(UMLStereotype *stereo)
     if (m_pStereotype) {
         m_pStereotype->decrRefCount();
         if (m_pStereotype->refCount() == 0) {
-            UMLDoc *pDoc = UMLApp::app()->getDocument();
+            UMLDoc *pDoc = UMLApp::app()->document();
             pDoc->removeStereotype(m_pStereotype);
             delete m_pStereotype;
         }
@@ -325,129 +473,227 @@ void UMLObject::setUMLStereotype(UMLStereotype *stereo)
     emitModified();
 }
 
+/**
+ * Sets the classes stereotype name.
+ * Internally uses setUMLStereotype().
+ *
+ * @param _name     Sets the classes stereotype name.
+ */
 void UMLObject::setStereotype(const QString &_name)
 {
-    // UMLDoc* pDoc = UMLApp::app()->getDocument();
+    // UMLDoc* pDoc = UMLApp::app()->document();
     // pDoc->executeCommand(new cmdSetStereotype(this,_name));
     if (_name.isEmpty()) {
         setUMLStereotype(NULL);
         return;
     }
-    UMLDoc *pDoc = UMLApp::app()->getDocument();
+    UMLDoc *pDoc = UMLApp::app()->document();
     UMLStereotype *s = pDoc->findOrCreateStereotype(_name);
     setUMLStereotype(s);
 }
 
-void UMLObject::setStereotypecmd(const QString& /*_name*/)
+void UMLObject::setStereotypeCmd(const QString& /*_name*/)
 {
 //TODO: put SetStereotype into QundoStack
 }
 
+/**
+ * Sets the classes Package.
+ * DEPRECATED - use SetUMLPackage instead.
+ *
+ * @param _name   The classes Package name.
+ */
 void UMLObject::setPackage(const QString &_name)
 {
     UMLObject *pkgObj = NULL;
     if (!_name.isEmpty()) {
-        UMLDoc* umldoc = UMLApp::app()->getDocument();
+        UMLDoc* umldoc = UMLApp::app()->document();
         pkgObj = umldoc->findUMLObject(_name);
         if (pkgObj == NULL) {
-            uDebug() << "creating UMLPackage " << _name << " for " << m_Name;
-            pkgObj = Import_Utils::createUMLObject(Uml::ot_Package, _name);
+            uDebug() << "creating UMLPackage " << _name << " for " << m_name;
+            pkgObj = Import_Utils::createUMLObject(ot_Package, _name);
         } else {
-            const Uml::Object_Type ot = pkgObj->getBaseType();
-            if (ot != Uml::ot_Package && ot != Uml::ot_Folder && ot != Uml::ot_Component) {
-                uError() << m_Name << ": " << "existing " << _name << " is not a container";
+            const ObjectType ot = pkgObj->baseType();
+            if (ot != ot_Package && ot != ot_Folder && ot != ot_Component) {
+                uError() << m_name << ": " << "existing " << _name << " is not a container";
                 // This should not happen - if it does, there may be further problems.
                 // A container name should not overlap with another name in the same scope.
-                pkgObj = Import_Utils::createUMLObject(Uml::ot_Package, _name);
+                pkgObj = Import_Utils::createUMLObject(ot_Package, _name);
             }
         }
     }
     setUMLPackage(static_cast<UMLPackage *>(pkgObj));
 }
 
-void UMLObject::setUMLPackage(UMLPackage* pPkg)
+/**
+ * Sets the UMLPackage in which this class is located.
+ *
+ * @param pPkg   Pointer to the class' UMLPackage.
+ */
+bool UMLObject::setUMLPackage(UMLPackage* pPkg)
 {
+    if (pPkg == this) {
+        uDebug() << "setting parent to myself is not allowed";
+        return false;
+    }
+
+    if (pPkg == NULL) {
+        // Allow setting to NULL for stereotypes
+        m_pUMLPackage = pPkg;
+        return true;
+    }
+
+    if (pPkg->umlPackage() == this) {
+        uDebug() << "setting parent to an object of which I'm already the parent is not allowed";
+        return false;
+    }
+
     m_pUMLPackage = pPkg;
     emitModified();
+    return true;
 }
 
-const UMLStereotype * UMLObject::getUMLStereotype()
+/**
+ * Returns the classes UMLStereotype object.
+ *
+ * @return   Returns the classes UMLStereotype object.
+ */
+const UMLStereotype * UMLObject::umlStereotype()
 {
     return m_pStereotype;
 }
 
-QString UMLObject::getStereotype(bool includeAdornments /* = false */) const
+/**
+ * Returns the stereotype.
+ */
+QString UMLObject::stereotype(bool includeAdornments /* = false */) const
 {
     if (m_pStereotype == NULL)
         return "";
-    QString name = m_pStereotype->getName();
+    QString name = m_pStereotype->name();
     if (includeAdornments)
         name = QString::fromUtf8("«") + name + QString::fromUtf8("»");
     return name;
 }
 
-QString UMLObject::getPackage(const QString& separator, bool includeRoot)
+/**
+ * Return the package(s) in which this UMLObject is contained
+ * as a text.
+ *
+ * @param separator Separator string for joining together the
+ *                  individual package prefixes (optional.)
+ *                  If no separator is given then the separator
+ *                  of the currently selected language is used.
+ * @param includeRoot  Whether to prefix the root folder name.
+ *                     Default: false.
+ * @return  The UMLObject's enclosing package(s) as a text.
+ */
+QString UMLObject::package(const QString& separator, bool includeRoot)
 {
     QString tempSeparator = separator;
     if (tempSeparator.isEmpty())
         tempSeparator = UMLApp::app()->activeLanguageScopeSeparator();
-    QString fqn = getFullyQualifiedName(tempSeparator, includeRoot);
+    QString fqn = fullyQualifiedName(tempSeparator, includeRoot);
     if (!fqn.contains(tempSeparator))
         return "";
-    QString scope = fqn.left(fqn.length() - tempSeparator.length() - m_Name.length());
+    QString scope = fqn.left(fqn.length() - tempSeparator.length() - m_name.length());
     return scope;
 }
 
-UMLPackageList UMLObject::getPackages(bool includeRoot) const
+/**
+ * Return a list of the packages in which this class is embedded.
+ * The outermost package is first in the list.
+ *
+ * @param includeRoot  Whether to prefix the root folder name.
+ *                     Default: false.
+ * @return  UMLPackageList of the containing packages.
+ */
+UMLPackageList UMLObject::packages(bool includeRoot) const
 {
     UMLPackageList pkgList;
     UMLPackage* pkg = m_pUMLPackage;
     while (pkg != NULL) {
         pkgList.prepend(pkg);
-        pkg = pkg->getUMLPackage();
+        pkg = pkg->umlPackage();
     }
     if (!includeRoot)
         pkgList.removeFirst();
     return pkgList;
 }
 
-UMLPackage* UMLObject::getUMLPackage()
+/**
+ * Returns the UMLPackage that this class is located in.
+ *
+ * @return  Pointer to the UMLPackage of this class.
+ */
+UMLPackage* UMLObject::umlPackage()
 {
     return m_pUMLPackage;
 }
 
-QString UMLObject::getSecondaryId() const
+/**
+ * Return secondary ID. Required by resolveRef().
+ */
+QString UMLObject::secondaryId() const
 {
     return m_SecondaryId;
 }
 
+/**
+ * Set the secondary ID.
+ * Currently only required by petalTree2Uml(); all other setting of the
+ * m_SecondaryID is internal to the UMLObject class hierarchy.
+ */
 void UMLObject::setSecondaryId(const QString& id)
 {
     m_SecondaryId = id;
 }
 
-QString UMLObject::getSecondaryFallback() const
+/**
+ * Return secondary ID fallback.
+ * Required by resolveRef() for imported model files.
+ */
+QString UMLObject::secondaryFallback() const
 {
     return m_SecondaryFallback;
 }
 
+/**
+ * Set the secondary ID fallback.
+ * Currently only used by petalTree2Uml().
+ */
 void UMLObject::setSecondaryFallback(const QString& id)
 {
     m_SecondaryFallback = id;
 }
 
+/**
+ * Calls UMLDoc::signalUMLObjectCreated() if m_BaseType affords
+ * doing so.
+ */
 void UMLObject::maybeSignalObjectCreated()
 {
     if (!m_bCreationWasSignalled &&
-            m_BaseType != Uml::ot_Stereotype &&
-            m_BaseType != Uml::ot_Association &&
-            m_BaseType != Uml::ot_Role) {
+            m_BaseType != ot_Stereotype &&
+            m_BaseType != ot_Association &&
+            m_BaseType != ot_Role) {
         m_bCreationWasSignalled = true;
-        UMLDoc* umldoc = UMLApp::app()->getDocument();
+        UMLDoc* umldoc = UMLApp::app()->document();
         umldoc->signalUMLObjectCreated(this);
     }
 }
 
+/**
+ * Resolve referenced objects (if any.)
+ * Needs to be called after all UML objects are loaded from file.
+ * This needs to be done after all model objects are loaded because
+ * some of the xmi.id's might be forward references, i.e. they may
+ * identify model objects which were not yet loaded at the point of
+ * reference.
+ * The default implementation attempts resolution of the m_SecondaryId.
+ *
+ * @return   True for success.
+ */
 bool UMLObject::resolveRef()
 {
     if (m_pSecondary || (m_SecondaryId.isEmpty() && m_SecondaryFallback.isEmpty())) {
@@ -455,15 +701,15 @@ bool UMLObject::resolveRef()
         return true;
     }
 #ifdef VERBOSE_DEBUGGING
-    uDebug() << m_Name << ": m_SecondaryId is " << m_SecondaryId;
+    uDebug() << m_name << ": m_SecondaryId is " << m_SecondaryId;
 #endif
-    UMLDoc *pDoc = UMLApp::app()->getDocument();
+    UMLDoc *pDoc = UMLApp::app()->document();
     // In the new, XMI standard compliant save format,
     // the type is the xmi.id of a UMLClassifier.
     if (! m_SecondaryId.isEmpty()) {
         m_pSecondary = pDoc->findObjectById(STR2ID(m_SecondaryId));
         if (m_pSecondary != NULL) {
-            if (m_pSecondary->getBaseType() == Uml::ot_Stereotype) {
+            if (m_pSecondary->baseType() == ot_Stereotype) {
                 m_pStereotype = static_cast<UMLStereotype*>(m_pSecondary);
                 m_pStereotype->incrRefCount();
                 m_pSecondary = NULL;
@@ -474,24 +720,24 @@ bool UMLObject::resolveRef()
         }
         if (m_SecondaryFallback.isEmpty()) {
             uDebug() << "object with xmi.id=" << m_SecondaryId << " not found, setting to undef";
-            UMLFolder *datatypes = pDoc->getDatatypeFolder();
-            m_pSecondary = Object_Factory::createUMLObject(Uml::ot_Datatype, "undef", datatypes, false);
+            UMLFolder *datatypes = pDoc->datatypeFolder();
+            m_pSecondary = Object_Factory::createUMLObject(ot_Datatype, "undef", datatypes, false);
             return true;
         }
     }
     if (m_SecondaryFallback.isEmpty()) {
-        uError() << m_Name << ": cannot find type with id " << m_SecondaryId;
+        uError() << m_name << ": cannot find type with id " << m_SecondaryId;
         return false;
     }
 #ifdef VERBOSE_DEBUGGING
-    uDebug() << m_Name << ": could not resolve secondary ID " << m_SecondaryId
+    uDebug() << m_name << ": could not resolve secondary ID " << m_SecondaryId
              << ", using secondary fallback " << m_SecondaryFallback;
 #endif
     m_SecondaryId = m_SecondaryFallback;
     // Assume we're dealing with the older Umbrello format where
     // the type name was saved in the "type" attribute rather
     // than the xmi.id of the model object of the attribute type.
-    m_pSecondary = pDoc->findUMLObject(m_SecondaryId, Uml::ot_UMLObject, this);
+    m_pSecondary = pDoc->findUMLObject(m_SecondaryId, ot_UMLObject, this);
     if (m_pSecondary) {
         m_SecondaryId = "";
         maybeSignalObjectCreated();
@@ -501,7 +747,7 @@ bool UMLObject::resolveRef()
     // of on-the-fly scope creation:
     if (m_SecondaryId.contains("::")) {
         // TODO: Merge Import_Utils::createUMLObject() into Object_Factory::createUMLObject()
-        m_pSecondary = Import_Utils::createUMLObject(Uml::ot_UMLObject, m_SecondaryId, m_pUMLPackage);
+        m_pSecondary = Import_Utils::createUMLObject(ot_UMLObject, m_SecondaryId, m_pUMLPackage);
         if (m_pSecondary) {
             if (Import_Utils::newUMLObjectWasCreated()) {
                 maybeSignalObjectCreated();
@@ -525,12 +771,12 @@ bool UMLObject::resolveRef()
     // typedefs of ref types.
     bool isReferenceType = (m_SecondaryId.contains('*') ||
                             m_SecondaryId.contains('&'));
-    Uml::Object_Type ot = Uml::ot_Class;
+    ObjectType ot = ot_Class;
     if (isReferenceType) {
-        ot = Uml::ot_Datatype;
+        ot = ot_Datatype;
     } else {
         if (Model_Utils::isCommonDataType(m_SecondaryId))
-            ot = Uml::ot_Datatype;
+            ot = ot_Datatype;
     }
     m_pSecondary = Object_Factory::createUMLObject(ot, m_SecondaryId, NULL);
     if (m_pSecondary == NULL)
@@ -541,6 +787,12 @@ bool UMLObject::resolveRef()
     return true;
 }
 
+/**
+ * Auxiliary to saveToXMI.
+ * Create a QDomElement with the given tag, and save the XMI attributes
+ * that are common to all child classes to the newly created element.
+ * This method does not need to be overridden by child classes.
+ */
 QDomElement UMLObject::save(const QString &tag, QDomDocument & qDoc)
 {
     /*
@@ -549,9 +801,9 @@ QDomElement UMLObject::save(const QString &tag, QDomDocument & qDoc)
     */
     QDomElement qElement = qDoc.createElement(tag);
     qElement.setAttribute("isSpecification", "false");
-    if (m_BaseType != Uml::ot_Association &&
-            m_BaseType != Uml::ot_Role &&
-            m_BaseType != Uml::ot_Attribute) {
+    if (m_BaseType != ot_Association &&
+        m_BaseType != ot_Role &&
+        m_BaseType != ot_Attribute) {
         qElement.setAttribute("isLeaf", "false");
         qElement.setAttribute("isRoot", "false");
         if (m_bAbstract)
@@ -560,15 +812,15 @@ QDomElement UMLObject::save(const QString &tag, QDomDocument & qDoc)
             qElement.setAttribute("isAbstract", "false");
     }
     qElement.setAttribute("xmi.id", ID2STR(m_nId));
-    qElement.setAttribute("name", m_Name);
-    if (m_BaseType != Uml::ot_Operation &&
-            m_BaseType != Uml::ot_Role &&
-            m_BaseType != Uml::ot_Attribute) {
+    qElement.setAttribute("name", m_name);
+    if (m_BaseType != ot_Operation &&
+        m_BaseType != ot_Role &&
+        m_BaseType != ot_Attribute) {
         Uml::IDType nmSpc;
         if (m_pUMLPackage)
-            nmSpc = m_pUMLPackage->getID();
+            nmSpc = m_pUMLPackage->id();
         else
-            nmSpc = UMLApp::app()->getDocument()->getModelID();
+            nmSpc = UMLApp::app()->document()->modelID();
         qElement.setAttribute("namespace", ID2STR(nmSpc));
     }
     if (! m_Doc.isEmpty())
@@ -580,7 +832,7 @@ QDomElement UMLObject::save(const QString &tag, QDomDocument & qDoc)
     QString visibility = m_Vis.toString(false);
     qElement.setAttribute("visibility", visibility);
     if (m_pStereotype != NULL)
-        qElement.setAttribute("stereotype", ID2STR(m_pStereotype->getID()));
+        qElement.setAttribute("stereotype", ID2STR(m_pStereotype->id()));
     if (m_bStatic)
         qElement.setAttribute("ownerScope", "classifier");
     /* else
@@ -589,6 +841,12 @@ QDomElement UMLObject::save(const QString &tag, QDomDocument & qDoc)
     return qElement;
 }
 
+/**
+ * Auxiliary to loadFromXMI.
+ * This method is usually overridden by child classes.
+ * It is responsible for loading the specific XMI structure
+ * of the child class.
+ */
 bool UMLObject::load(QDomElement&)
 {
     // This body is not usually executed because child classes
@@ -596,10 +854,16 @@ bool UMLObject::load(QDomElement&)
     return true;
 }
 
+/**
+ * Analyzes the given QDomElement for a reference to a stereotype.
+ *
+ * @param element   QDomElement to analyze.
+ * @return          True if a stereotype reference was found, else false.
+ */
 bool UMLObject::loadStereotype(QDomElement & element)
 {
     QString tag = element.tagName();
-    if (!Uml::tagEq(tag, "stereotype"))
+    if (!UMLDoc::tagEq(tag, "stereotype"))
         return false;
     QString stereo = element.attribute("xmi.value", "");
     if (stereo.isEmpty() && element.hasChildNodes()) {
@@ -611,14 +875,14 @@ bool UMLObject::loadStereotype(QDomElement & element)
         QDomNode stereoNode = element.firstChild();
         QDomElement stereoElem = stereoNode.toElement();
         tag = stereoElem.tagName();
-        if (Uml::tagEq(tag, "Stereotype")) {
+        if (UMLDoc::tagEq(tag, "Stereotype")) {
             stereo = stereoElem.attribute("xmi.idref", "");
         }
     }
     if (stereo.isEmpty())
         return false;
     Uml::IDType stereoID = STR2ID(stereo);
-    UMLDoc *pDoc = UMLApp::app()->getDocument();
+    UMLDoc *pDoc = UMLApp::app()->document();
     m_pStereotype = pDoc->findStereotypeById(stereoID);
     if (m_pStereotype)
         m_pStereotype->incrRefCount();
@@ -627,39 +891,48 @@ bool UMLObject::loadStereotype(QDomElement & element)
     return true;
 }
 
+/**
+ * This method loads the generic parts of the XMI common to most model
+ * classes.  It is not usually reimplemented by child classes.
+ * Instead, it invokes the load() method which implements the loading
+ * of the specifics of each child class.
+ *
+ * @param element   The QDomElement from which to load.
+ */
 bool UMLObject::loadFromXMI(QDomElement & element)
 {
-    UMLDoc* umldoc = UMLApp::app()->getDocument();
+    UMLDoc* umldoc = UMLApp::app()->document();
     if (umldoc == 0) {
         uError() << "umldoc is NULL";
         return false;
     }
     // Read the name first so that if we encounter a problem, the error
     // message can say the name.
-    m_Name = element.attribute("name", "");
+    m_name = element.attribute("name", "");
     QString id = element.attribute("xmi.id", "");
     if (id.isEmpty() || id == "-1") {
-        if (m_BaseType == Uml::ot_Role) {
+        if (m_BaseType == ot_Role) {
             // Before version 1.4, Umbrello did not save the xmi.id
             // of UMLRole objects.
             m_nId = UniqueID::gen();
         } else {
-            uError() << m_Name << ": nonexistent or illegal xmi.id";
+            uError() << m_name << ": nonexistent or illegal xmi.id";
             return false;
         }
     } else {
-        m_nId = STR2ID(id);
-        if (m_BaseType == Uml::ot_Role) {
+        Uml::IDType nId = STR2ID(id);
+        if (m_BaseType == ot_Role) {
             // Some older Umbrello versions had a problem with xmi.id's
             // of other objects being reused for the UMLRole, see e.g.
             // attachment 21179 at http://bugs.kde.org/147988 .
             // If the xmi.id is already being used then we generate a new one.
-            UMLObject *o = umldoc->findObjectById(m_nId);
+            UMLObject *o = umldoc->findObjectById(nId);
             if (o) {
                 uError() << "loadFromXMI(UMLRole): id " << id
                          << " is already in use!!! Please fix your XMI file.";
             }
         }
+        m_nId = nId;
     }
 
     if (element.hasAttribute("documentation"))  // for bkwd compat.
@@ -687,7 +960,7 @@ bool UMLObject::loadFromXMI(QDomElement & element)
                 m_Vis = Uml::Visibility::Protected;
                 break;
             default:
-                uError() << m_Name << ": illegal scope " << nScope;
+                uError() << m_name << ": illegal scope " << nScope;
             }
         }
     } else {
@@ -709,7 +982,7 @@ bool UMLObject::loadFromXMI(QDomElement & element)
         if (m_pStereotype) {
             m_pStereotype->incrRefCount();
         } else {
-            uDebug() << m_Name << ": UMLStereotype " << ID2STR(stereoID)
+            uDebug() << m_name << ": UMLStereotype " << ID2STR(stereoID)
                      << " not found, creating now.";
             setStereotype(stereo);
         }
@@ -740,11 +1013,11 @@ bool UMLObject::loadFromXMI(QDomElement & element)
         QDomElement elem = node.toElement();
         while (!elem.isNull()) {
             QString tag = elem.tagName();
-            if (Uml::tagEq(tag, "name")) {
-                m_Name = elem.attribute("xmi.value", "");
-                if (m_Name.isEmpty())
-                    m_Name = elem.text();
-            } else if (Uml::tagEq(tag, "visibility")) {
+            if (UMLDoc::tagEq(tag, "name")) {
+                m_name = elem.attribute("xmi.value", "");
+                if (m_name.isEmpty())
+                    m_name = elem.text();
+            } else if (UMLDoc::tagEq(tag, "visibility")) {
                 QString vis = elem.attribute("xmi.value", "");
                 if (vis.isEmpty())
                     vis = elem.text();
@@ -754,12 +1027,12 @@ bool UMLObject::loadFromXMI(QDomElement & element)
                     m_Vis = Uml::Visibility::Protected;
                 else if (vis == "implementation")
                     m_Vis = Uml::Visibility::Implementation;
-            } else if (Uml::tagEq(tag, "isAbstract")) {
+            } else if (UMLDoc::tagEq(tag, "isAbstract")) {
                 QString isAbstract = elem.attribute("xmi.value", "");
                 if (isAbstract.isEmpty())
                     isAbstract = elem.text();
                 m_bAbstract = (isAbstract == "true");
-            } else if (Uml::tagEq(tag, "ownerScope")) {
+            } else if (UMLDoc::tagEq(tag, "ownerScope")) {
                 QString ownerScope = elem.attribute("xmi.value", "");
                 if (ownerScope.isEmpty())
                     ownerScope = elem.text();
@@ -776,39 +1049,44 @@ bool UMLObject::loadFromXMI(QDomElement & element)
 
     // Operations, attributes, enum literals, templates, stereotypes,
     // and association role objects get added and signaled elsewhere.
-    if (m_BaseType != Uml::ot_Operation && m_BaseType != Uml::ot_Attribute &&
-            m_BaseType != Uml::ot_EnumLiteral && m_BaseType != Uml::ot_EntityAttribute &&
-            m_BaseType != Uml::ot_Template && m_BaseType != Uml::ot_Stereotype &&
-            m_BaseType != Uml::ot_Role && m_BaseType != Uml::ot_UniqueConstraint &&
-            m_BaseType != Uml::ot_ForeignKeyConstraint) {
+    if (m_BaseType != ot_Operation && m_BaseType != ot_Attribute &&
+        m_BaseType != ot_EnumLiteral && m_BaseType != ot_EntityAttribute &&
+        m_BaseType != ot_Template && m_BaseType != ot_Stereotype &&
+        m_BaseType != ot_Role && m_BaseType != ot_UniqueConstraint &&
+        m_BaseType != ot_ForeignKeyConstraint) {
         if (m_bInPaste) {
-            m_pUMLPackage = NULL;  // forget any old parent
-            UMLListView *listView = UMLApp::app()->getListView();
-            UMLListViewItem *parentItem = (UMLListViewItem*)listView->currentItem();
-            if (parentItem) {
-                Uml::ListView_Type lvt = parentItem->getType();
-                if (Model_Utils::typeIsContainer(lvt) ||
-                        lvt == Uml::lvt_Class ||
-                        lvt == Uml::lvt_Interface) {
-                    UMLObject *o = parentItem->getUMLObject();
-                    m_pUMLPackage = static_cast<UMLPackage*>(o);
-                }
-            }
+            m_pUMLPackage = Model_Utils::treeViewGetPackageFromCurrent();
         }
         if (m_pUMLPackage) {
             m_pUMLPackage->addObject(this);
-        } else if (umldoc->rootFolderType(this) == Uml::N_MODELTYPES) {
+        } else if (umldoc->rootFolderType(this) == Uml::ModelType::N_MODELTYPES) {
             // m_pUMLPackage is not set on the root folders.
-            uDebug() << m_Name << ": m_pUMLPackage is not set";
+            uDebug() << m_name << ": m_pUMLPackage is not set";
         }
     }
     return load(element);
 }
 
-QDebug operator<< (QDebug s, const UMLObject& a)
+/**
+ * Helper function for debug output.
+ * Returns the given enum value as string.
+ * @param ot   ObjectType of which a string representation is wanted
+ * @return   the ObjectType as string
+ */
+QString UMLObject::toString(ObjectType ot)
 {
-    s << a.getName();
-    return s;
+    return QLatin1String(ENUM_NAME(UMLObject, ObjectType, ot));
+}
+
+/**
+ * Print UML Object to debug output stream, so it can be used like
+ *   uDebug() << "This object shouldn't be here: " << illegalObject;
+ */
+QDebug operator<<(QDebug out, const UMLObject& obj)
+{
+    out.nospace() << "UMLObject: name= " << obj.name()
+        << ", type= " << UMLObject::toString(obj.m_BaseType);
+    return out.space();
 }
 
 #include "umlobject.moc"
