@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -14,15 +14,8 @@
 // system includes
 #include <kurl.h>
 #include <qdom.h>
-#include <q3canvas.h>
-//Added by qt3to4:
-#include <QPixmap>
-#include <QHideEvent>
-#include <QCloseEvent>
-#include <QDropEvent>
-#include <QShowEvent>
-#include <QDragEnterEvent>
-#include <QMouseEvent>
+#include <umlviewcanvas.h>
+#include <QtGui/QPixmap>
 
 //local includes
 #include "umlobjectlist.h"
@@ -35,9 +28,11 @@
 // forward declarations
 class ClassOptionsPage;
 class IDChangeLog;
-class ListPopupMenu;
 class FloatingTextWidget;
+class ListPopupMenu;
 class ObjectWidget;
+class ToolBarState;
+class ToolBarStateFactory;
 class UMLFolder;
 class UMLApp;
 class UMLDoc;
@@ -48,9 +43,14 @@ class UMLViewImageExporter;
 class UMLForeignKeyConstraint;
 class UMLEntity;
 
+class QCloseEvent;
+class QDragEnterEvent;
+class QDropEvent;
+class QHideEvent;
+class QMouseEvent;
 class QPrinter;
-class ToolBarState;
-class ToolBarStateFactory;
+class QShowEvent;
+class UMLScene;
 
 /**
  * UMLView instances represent diagrams.
@@ -68,14 +68,7 @@ class UMLView : public Q3CanvasView
 public:
     friend class UMLViewImageExporterModel;
 
-    /**
-     * Constructor
-     */
     UMLView(UMLFolder *parentFolder);
-
-    /**
-     * Destructor
-     */
     virtual ~UMLView();
 
     /**
@@ -84,8 +77,8 @@ public:
      * TODO: Check if we should pass an UMLScene instead of an UMLView
      *       at places where we see "view->umlScene()->doSomething()".
      */
-    UMLView* umlScene() {
-        return this;
+    UMLScene* umlScene() {
+        return m_scene;
     }
 
     // Accessors and other methods dealing with loaded/saved data
@@ -93,7 +86,7 @@ public:
     /**
      * Return the UMLFolder in which this diagram lives.
      */
-    UMLFolder *getFolder() {
+    UMLFolder *folder() {
         return m_pFolder;
     }
 
@@ -107,45 +100,38 @@ public:
     /**
      * Return the documentation of the diagram.
      */
-    QString getDoc() const {
+    QString documentation() const {
         return m_Documentation;
     }
 
     /**
      * Set the documentation of the diagram.
      */
-    void setDoc( const QString &doc ) {
+    void setDocumentation(const QString &doc) {
         m_Documentation = doc;
     }
 
-    /**
-     * Return the name of the diagram.
-     */
-    QString getName() const;
-
-    /**
-     * Set the name of the diagram.
-     */
+    QString name() const;
     void setName(const QString &name);
 
     /**
      * Returns the type of the diagram.
      */
-    Uml::Diagram_Type getType() const {
+    Uml::DiagramType type() const {
         return m_Type;
     }
 
     /**
      * Set the type of diagram.
      */
-    void setType( Uml::Diagram_Type type ) {
+    void setType( Uml::DiagramType type ) {
         m_Type = type;
     }
 
     /**
      * Returns the fill color to use.
      */
-    QColor getFillColor() const;
+    QColor fillColor() const;
 
     /**
      * Set the background color.
@@ -157,7 +143,7 @@ public:
     /**
      * Returns the line color to use.
      */
-    QColor getLineColor() const;
+    QColor lineColor() const;
 
     /**
      * Sets the line color.
@@ -169,7 +155,7 @@ public:
     /**
      * Returns the line width to use.
      */
-    uint getLineWidth() const;
+    uint lineWidth() const;
 
     /**
      * Sets the line width.
@@ -195,7 +181,7 @@ public:
     /**
      * Returns the zoom of the diagram.
      */
-    int getZoom() const {
+    int zoom() const {
         return m_nZoom;
     }
 
@@ -293,7 +279,7 @@ public:
     /**
      * Returns whether to use the fill/background color
      */
-    bool getUseFillColor() const;
+    bool useFillColor() const;
 
     /**
      * Sets whether to use the fill/background color
@@ -323,7 +309,7 @@ public:
     /**
      * Returns the options being used.
      */
-    const Settings::OptionState& getOptionState() const {
+    const Settings::OptionState& optionState() const {
         return m_Options;
     }
 
@@ -355,6 +341,9 @@ public:
         return m_MessageList;
     }
 
+    bool isOpen() const;
+    void setIsOpen(bool isOpen);
+
     // End of accessors and methods that only deal with loaded/saved data
     ////////////////////////////////////////////////////////////////////////
 
@@ -405,13 +394,13 @@ public:
     /**
      * Finds an association widget with the given type and widgets.
      *
-     * @param at  The Association_Type of the widget to find.
+     * @param at  The AssociationType of the widget to find.
      * @param pWidgetA Pointer to the UMLWidget of role A.
      * @param pWidgetB Pointer to the UMLWidget of role B.
      *
      * @return Returns the widget found, returns 0 if no widget found.
      */
-    AssociationWidget * findAssocWidget(Uml::Association_Type at,
+    AssociationWidget * findAssocWidget(Uml::AssociationType at,
                                         UMLWidget *pWidgetA, UMLWidget *pWidgetB);
 
     /**
@@ -438,6 +427,7 @@ public:
 
     /**
      * Sets a widget to a selected state and adds it to a list of selected widgets.
+     * This method also sets the state of the cut and copy menu entries.
      *
      * @param w The widget to set to selected.
      * @param me The mouse event containing the information about the selection.
@@ -579,7 +569,7 @@ public:
     /**
      * Returns a List of all the UMLObjects(Use Cases, Concepts and Actors) in the View
      */
-    UMLObjectList getUMLObjects();
+    UMLObjectList umlObjects();
 
     /**
      * Activate all the objects and associations after a load from the clipboard
@@ -874,6 +864,16 @@ public:
      */
     void selectWidgets(int px, int py, int qx, int qy);
 
+    /**
+     * Selects all the widgets of the given association widget.
+     */
+    void selectWidgetsOfAssoc (AssociationWidget * a);
+
+    /**
+     * Selects all the widgets from a list.
+     */
+    void selectWidgets(UMLWidgetList &widgets);
+
     /**
      * Determine whether on a sequence diagram we have clicked on a line
      * of an Object.
@@ -906,7 +906,7 @@ public:
      * Returns NULL if the point is not inside any widget.
      * Does not use or modify the m_pOnWidget member.
      */
-    UMLWidget *getWidgetAt(const QPoint& p);
+    UMLWidget *widgetAt(const QPoint& p);
 
     /**
      * Initialize and announce a newly created widget.
@@ -944,7 +944,7 @@ public:
      * Return the UMLDoc pointer
      */
     UMLDoc* getUMLDoc() {
-        return m_pDoc;
+        return m_doc;
     }
 
 protected:
@@ -952,11 +952,8 @@ protected:
     // Methods and members related to loading/saving
 
     bool loadWidgetsFromXMI( QDomElement & qElement );
-
     bool loadMessagesFromXMI( QDomElement & qElement );
-
     bool loadAssociationsFromXMI( QDomElement & qElement );
-
     bool loadUisDiagramPresentation(QDomElement & qElement);
 
     /**
@@ -973,7 +970,7 @@ protected:
     /**
      * The type of diagram to represent.
      */
-    Uml::Diagram_Type m_Type;
+    Uml::DiagramType m_Type;
 
     /**
      * The name of the diagram.
@@ -1031,6 +1028,11 @@ protected:
      */
     bool m_bShowSnapGrid;
 
+    /**
+     * Determines whether the view is shown to the user, i.e. opened in a tab.
+     */
+    bool m_isOpen;
+
     /**
      * The zoom level in percent, default 100
      */
@@ -1049,32 +1051,12 @@ protected:
     // End of methods and members related to loading/saving
     ////////////////////////////////////////////////////////////////////////
 
-    /**
-     * Override standard method.
-     */
-    void closeEvent ( QCloseEvent * e );
-
-    /**
-     * Override standard method.
-     */
+    void closeEvent(QCloseEvent * e);
     void dragEnterEvent(QDragEnterEvent* enterEvent);
-
-    /**
-     * Override standard method.
-     */
     void dragMoveEvent(QDragMoveEvent* moveEvent);
-
-    /**
-     * Override standard method.
-     */
     void dropEvent(QDropEvent* dropEvent);
 
-    /**
-     * Gets the smallest area to print.
-     *
-     * @return Returns the smallest area to print.
-     */
-    QRect getDiagramRect();
+    QRect diagramRect();
 
     /**
      * Overrides the standard operation.
@@ -1100,12 +1082,6 @@ protected:
      */
     void contentsMousePressEvent(QMouseEvent* mouseEvent);
 
-
-    /**
-     * Selects all the widgets of the given association widget.
-     */
-    void selectWidgetsOfAssoc (AssociationWidget * a);
-
     /**
      * Calls setSelected on the given UMLWidget and enters
      * it into the m_SelectedList while making sure it is
@@ -1157,6 +1133,10 @@ protected:
     bool m_bStartedCut;
 
 private:
+    /**
+     * The folder in which this UMLView is contained
+     */
+    UMLScene *m_scene;
     /**
      * The folder in which this UMLView is contained
      */
@@ -1197,7 +1177,7 @@ private:
     /**
      * Pointer to the UMLDoc
      */
-    UMLDoc* m_pDoc;
+    UMLDoc* m_doc;
 
     /**
      * The UMLViewImageExporter used to export the view.
@@ -1291,9 +1271,9 @@ private:
     void sortWidgetList(UMLWidgetList &widgetList, Compare comp);
 
 public slots:
-
     void zoomIn();
     void zoomOut();
+    void show();
 
     /**
      * Changes the current tool to the selected tool.
@@ -1336,12 +1316,6 @@ public slots:
      */
     void slotShowView();
 
-    /**
-     * Overrides standard method from QWidget to resize canvas when
-     * it's shown.
-     */
-    void show();
-
     /**
      * Left Alignment
      */
