@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2009                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -13,10 +13,10 @@
 
 // kde includes
 #include <klocale.h>
-#include <kdebug.h>
 #include <kinputdialog.h>
 
 // app includes
+#include "debug_utils.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "docwindow.h"
@@ -29,15 +29,14 @@
 // qt includes
 #include <QtGui/QPainter>
 
-PreconditionWidget::PreconditionWidget(UMLView * view, ObjectWidget* a, Uml::IDType id )
-  : UMLWidget(view, id)
+PreconditionWidget::PreconditionWidget(UMLScene * scene, ObjectWidget* a, Uml::IDType id )
+  : UMLWidget(scene, WidgetBase::wt_Precondition, id)
 {
     init();
     m_pOw = a;
     int y = getY();
     m_nY = y;
     //updateResizability();
-    updateComponentSize();
    // calculateWidget();
     y = y < getMinY() ? getMinY() : y;
     y = y > getMaxY() ? getMaxY() : y;
@@ -51,16 +50,15 @@ PreconditionWidget::~PreconditionWidget()
 
 void PreconditionWidget::init()
 {
-    UMLWidget::setBaseType(Uml::wt_Precondition);
-    m_bIgnoreSnapToGrid = true;
-    m_bIgnoreSnapComponentSizeToGrid = true;
-    m_bResizable =  true ;
+    m_ignoreSnapToGrid = true;
+    m_ignoreSnapComponentSizeToGrid = true;
+    m_resizable =  true ;
     m_pOw = NULL;
     m_nY = 0;
     setVisible(true);
 }
 
-void PreconditionWidget::draw(QPainter & p, int /*offsetX*/, int offsetY)
+void PreconditionWidget::paint(QPainter & p, int /*offsetX*/, int offsetY)
 {
     int w = width();
     int h = height();
@@ -79,8 +77,8 @@ void PreconditionWidget::draw(QPainter & p, int /*offsetX*/, int offsetY)
     }
     setY(y);
     setPenFromSettings(p);
-    if ( UMLWidget::getUseFillColour() ) {
-        p.setBrush( UMLWidget::getFillColour() );
+    if ( UMLWidget::useFillColor() ) {
+        p.setBrush( UMLWidget::fillColor() );
     }
     {
         const QFontMetrics &fm = getFontMetrics(FT_NORMAL);
@@ -94,11 +92,11 @@ void PreconditionWidget::draw(QPainter & p, int /*offsetX*/, int offsetY)
         p.drawText(x + PRECONDITION_MARGIN, y + textStartY,
                        w - PRECONDITION_MARGIN * 2, fontHeight, Qt::AlignCenter, precondition_value);
     }
-    if(m_bSelected)
+    if(m_selected)
         drawSelected(&p, x, y);
 }
 
-QSize PreconditionWidget::calculateSize()
+UMLSceneSize PreconditionWidget::minimumSize()
 {
     int width = 10, height = 10;
     const QFontMetrics &fm = getFontMetrics(FT_NORMAL);
@@ -110,7 +108,7 @@ QSize PreconditionWidget::calculateSize()
     width += PRECONDITION_MARGIN * 2;
     height += PRECONDITION_MARGIN * 2;
 
-    return QSize(width, height);
+    return UMLSceneSize(width, height);
 }
 
 void PreconditionWidget::slotMenuSelection(QAction* action)
@@ -118,7 +116,7 @@ void PreconditionWidget::slotMenuSelection(QAction* action)
     bool ok = false;
     QString name = m_Text;
 
-    ListPopupMenu::Menu_Type sel = m_pMenu->getMenuType(action);
+    ListPopupMenu::MenuType sel = m_pMenu->getMenuType(action);
     switch( sel ) {
     case ListPopupMenu::mt_Rename:
         name = KInputDialog::getText( i18n("Enter Precondition Name"), i18n("Enter the precondition :"), m_Text, &ok );
@@ -144,7 +142,7 @@ void PreconditionWidget::calculateWidget()
 
 bool PreconditionWidget::activate(IDChangeLog * Log /*= 0*/)
 {
-    m_pView->resetPastePoint();
+    m_scene->resetPastePoint();
     UMLWidget::activate(Log);
     if (m_pOw == NULL) {
         uDebug() << "cannot make precondition";
@@ -167,7 +165,7 @@ void PreconditionWidget::calculateDimensions()
 
     x1 += w1;
 
-    QSize q = calculateSize();
+    QSize q = minimumSize();
     w = q.width() > width() ? q.width() : width();
     h = q.height() > height() ? q.height() : height();
 
@@ -192,7 +190,7 @@ void PreconditionWidget::slotWidgetMoved(Uml::IDType id)
         m_nY = getMaxY();
 
     calculateDimensions();
-    if (m_pView->getSelectCount(true) > 1)
+    if (m_scene->getSelectCount(true) > 1)
         return;
 
 }
@@ -239,7 +237,7 @@ bool PreconditionWidget::loadFromXMI( QDomElement & qElement )
 
     Uml::IDType aId = STR2ID(widgetaid);
 
-    UMLWidget *pWA = m_pView -> findWidget( aId );
+    UMLWidget *pWA = m_scene -> findWidget( aId );
     if (pWA == NULL) {
         uDebug() << "role A object " << ID2STR(aId) << " not found";
         return false;
